%%
%% %CopyrightBegin%
%%
%% Copyright Ericsson AB 2008-2016. All Rights Reserved.
%%
%% Licensed under the Apache License, Version 2.0 (the "License");
%% you may not use this file except in compliance with the License.
%% You may obtain a copy of the License at
%%
%%     http://www.apache.org/licenses/LICENSE-2.0
%%
%% Unless required by applicable law or agreed to in writing, software
%% distributed under the License is distributed on an "AS IS" BASIS,
%% WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
%% See the License for the specific language governing permissions and
%% limitations under the License.
%%
%% %CopyrightEnd%
%% This file is generated DO NOT EDIT

wxdebug_table() ->
[
 {0, {wx, internal_batch_start, 0}},
 {1, {wx, internal_batch_end, 0}},
 {4, {wxObject, internal_destroy, 1}},
 {100, {wxEvtHandler, connect, 2}},
 {101, {wxEvtHandler, disconnect_2, 2}},
 {102, {wxEvtHandler, disconnect_1, 1}},
 {103, {wxEvtHandler, disconnect_0, 0}},
 {105, {wxWindow, new_0, 0}},
 {106, {wxWindow, new_3, 3}},
 {108, {wxWindow, destruct, 0}},
 {109, {wxWindow, cacheBestSize, 1}},
 {110, {wxWindow, captureMouse, 0}},
 {111, {wxWindow, center, 1}},
 {112, {wxWindow, centerOnParent, 1}},
 {113, {wxWindow, centre, 1}},
 {114, {wxWindow, centreOnParent, 1}},
 {115, {wxWindow, clearBackground, 0}},
 {116, {wxWindow, clientToScreen_2, 2}},
 {117, {wxWindow, clientToScreen_1, 1}},
 {118, {wxWindow, close, 1}},
 {120, {wxWindow, convertDialogToPixels, 1}},
 {122, {wxWindow, convertPixelsToDialog, 1}},
 {123, {wxWindow, 'Destroy', 0}},
 {124, {wxWindow, destroyChildren, 0}},
 {125, {wxWindow, disable, 0}},
 {126, {wxWindow, dragAcceptFiles, 1}},
 {127, {wxWindow, enable, 1}},
 {128, {wxWindow, findFocus, 0}},
 {129, {wxWindow, findWindow_1_0, 1}},
 {130, {wxWindow, findWindow_1_1, 1}},
 {131, {wxWindow, findWindowById, 2}},
 {132, {wxWindow, findWindowByName, 2}},
 {133, {wxWindow, findWindowByLabel, 2}},
 {134, {wxWindow, fit, 0}},
 {135, {wxWindow, fitInside, 0}},
 {136, {wxWindow, freeze, 0}},
 {137, {wxWindow, getAcceleratorTable, 0}},
 {138, {wxWindow, getBackgroundColour, 0}},
 {139, {wxWindow, getBackgroundStyle, 0}},
 {140, {wxWindow, getBestSize, 0}},
 {142, {wxWindow, getCaret, 0}},
 {143, {wxWindow, getCapture, 0}},
 {144, {wxWindow, getCharHeight, 0}},
 {145, {wxWindow, getCharWidth, 0}},
 {146, {wxWindow, getChildren, 0}},
 {149, {wxWindow, getClientSize, 0}},
 {150, {wxWindow, getContainingSizer, 0}},
 {151, {wxWindow, getCursor, 0}},
 {152, {wxWindow, getDropTarget, 0}},
 {153, {wxWindow, getEventHandler, 0}},
 {154, {wxWindow, getExtraStyle, 0}},
 {155, {wxWindow, getFont, 0}},
 {156, {wxWindow, getForegroundColour, 0}},
 {157, {wxWindow, getGrandParent, 0}},
 {158, {wxWindow, getHandle, 0}},
 {159, {wxWindow, getHelpText, 0}},
 {160, {wxWindow, getId, 0}},
 {161, {wxWindow, getLabel, 0}},
 {162, {wxWindow, getMaxSize, 0}},
 {163, {wxWindow, getMinSize, 0}},
 {164, {wxWindow, getName, 0}},
 {165, {wxWindow, getParent, 0}},
 {167, {wxWindow, getPosition, 0}},
 {168, {wxWindow, getRect, 0}},
 {170, {wxWindow, getScreenPosition, 0}},
 {171, {wxWindow, getScreenRect, 0}},
 {172, {wxWindow, getScrollPos, 1}},
 {173, {wxWindow, getScrollRange, 1}},
 {174, {wxWindow, getScrollThumb, 1}},
 {176, {wxWindow, getSize, 0}},
 {177, {wxWindow, getSizer, 0}},
 {178, {wxWindow, getTextExtent, 4}},
 {179, {wxWindow, getToolTip, 0}},
 {180, {wxWindow, getUpdateRegion, 0}},
 {182, {wxWindow, getVirtualSize, 0}},
 {184, {wxWindow, getWindowStyleFlag, 0}},
 {185, {wxWindow, getWindowVariant, 0}},
 {186, {wxWindow, hasCapture, 0}},
 {187, {wxWindow, hasScrollbar, 1}},
 {188, {wxWindow, hasTransparentBackground, 0}},
 {189, {wxWindow, hide, 0}},
 {190, {wxWindow, inheritAttributes, 0}},
 {191, {wxWindow, initDialog, 0}},
 {192, {wxWindow, invalidateBestSize, 0}},
 {193, {wxWindow, isEnabled, 0}},
 {194, {wxWindow, isExposed_2, 2}},
 {195, {wxWindow, isExposed_4, 4}},
 {196, {wxWindow, isExposed_1_0, 1}},
 {197, {wxWindow, isExposed_1_1, 1}},
 {198, {wxWindow, isRetained, 0}},
 {199, {wxWindow, isShown, 0}},
 {200, {wxWindow, isTopLevel, 0}},
 {201, {wxWindow, layout, 0}},
 {202, {wxWindow, lineDown, 0}},
 {203, {wxWindow, lineUp, 0}},
 {204, {wxWindow, lower, 0}},
 {205, {wxWindow, makeModal, 1}},
 {206, {wxWindow, move_3, 3}},
 {207, {wxWindow, move_2, 2}},
 {208, {wxWindow, moveAfterInTabOrder, 1}},
 {209, {wxWindow, moveBeforeInTabOrder, 1}},
 {210, {wxWindow, navigate, 1}},
 {211, {wxWindow, pageDown, 0}},
 {212, {wxWindow, pageUp, 0}},
 {213, {wxWindow, popEventHandler, 1}},
 {214, {wxWindow, popupMenu_2, 2}},
 {215, {wxWindow, popupMenu_3, 3}},
 {216, {wxWindow, raise, 0}},
 {217, {wxWindow, refresh, 1}},
 {218, {wxWindow, refreshRect, 2}},
 {219, {wxWindow, releaseMouse, 0}},
 {220, {wxWindow, removeChild, 1}},
 {221, {wxWindow, reparent, 1}},
 {222, {wxWindow, screenToClient_2, 2}},
 {223, {wxWindow, screenToClient_1, 1}},
 {225, {wxWindow, scrollLines, 1}},
 {227, {wxWindow, scrollPages, 1}},
 {228, {wxWindow, scrollWindow, 3}},
 {229, {wxWindow, setAcceleratorTable, 1}},
 {230, {wxWindow, setAutoLayout, 1}},
 {231, {wxWindow, setBackgroundColour, 1}},
 {232, {wxWindow, setBackgroundStyle, 1}},
 {233, {wxWindow, setCaret, 1}},
 {234, {wxWindow, setClientSize_2, 2}},
 {235, {wxWindow, setClientSize_1_0, 1}},
 {236, {wxWindow, setClientSize_1_1, 1}},
 {237, {wxWindow, setContainingSizer, 1}},
 {238, {wxWindow, setCursor, 1}},
 {239, {wxWindow, setMaxSize, 1}},
 {240, {wxWindow, setMinSize, 1}},
 {241, {wxWindow, setOwnBackgroundColour, 1}},
 {242, {wxWindow, setOwnFont, 1}},
 {243, {wxWindow, setOwnForegroundColour, 1}},
 {244, {wxWindow, setDropTarget, 1}},
 {245, {wxWindow, setExtraStyle, 1}},
 {246, {wxWindow, setFocus, 0}},
 {247, {wxWindow, setFocusFromKbd, 0}},
 {248, {wxWindow, setFont, 1}},
 {249, {wxWindow, setForegroundColour, 1}},
 {250, {wxWindow, setHelpText, 1}},
 {251, {wxWindow, setId, 1}},
 {253, {wxWindow, setLabel, 1}},
 {254, {wxWindow, setName, 1}},
 {255, {wxWindow, setPalette, 1}},
 {256, {wxWindow, setScrollbar, 5}},
 {257, {wxWindow, setScrollPos, 3}},
 {258, {wxWindow, setSize_5, 5}},
 {259, {wxWindow, setSize_2_0, 2}},
 {260, {wxWindow, setSize_1, 1}},
 {261, {wxWindow, setSize_2_1, 2}},
 {262, {wxWindow, setSizeHints_3, 3}},
 {263, {wxWindow, setSizeHints_2, 2}},
 {264, {wxWindow, setSizer, 2}},
 {265, {wxWindow, setSizerAndFit, 2}},
 {266, {wxWindow, setThemeEnabled, 1}},
 {267, {wxWindow, setToolTip_1_0, 1}},
 {268, {wxWindow, setToolTip_1_1, 1}},
 {269, {wxWindow, setVirtualSize_1, 1}},
 {270, {wxWindow, setVirtualSize_2, 2}},
 {271, {wxWindow, setVirtualSizeHints_3, 3}},
 {272, {wxWindow, setVirtualSizeHints_2, 2}},
 {273, {wxWindow, setWindowStyle, 1}},
 {274, {wxWindow, setWindowStyleFlag, 1}},
 {275, {wxWindow, setWindowVariant, 1}},
 {276, {wxWindow, shouldInheritColours, 0}},
 {277, {wxWindow, show, 1}},
 {278, {wxWindow, thaw, 0}},
 {279, {wxWindow, transferDataFromWindow, 0}},
 {280, {wxWindow, transferDataToWindow, 0}},
 {281, {wxWindow, update, 0}},
 {282, {wxWindow, updateWindowUI, 1}},
 {283, {wxWindow, validate, 0}},
 {284, {wxWindow, warpPointer, 2}},
 {285, {wxWindow, setTransparent, 1}},
 {286, {wxWindow, canSetTransparent, 0}},
 {287, {wxWindow, isDoubleBuffered, 0}},
 {288, {wxWindow, setDoubleBuffered, 1}},
 {289, {wxWindow, getContentScaleFactor, 0}},
 {290, {wxTopLevelWindow, getIcon, 0}},
 {291, {wxTopLevelWindow, getIcons, 0}},
 {292, {wxTopLevelWindow, getTitle, 0}},
 {293, {wxTopLevelWindow, isActive, 0}},
 {294, {wxTopLevelWindow, iconize, 1}},
 {295, {wxTopLevelWindow, isFullScreen, 0}},
 {296, {wxTopLevelWindow, isIconized, 0}},
 {297, {wxTopLevelWindow, isMaximized, 0}},
 {298, {wxTopLevelWindow, maximize, 1}},
 {299, {wxTopLevelWindow, requestUserAttention, 1}},
 {300, {wxTopLevelWindow, setIcon, 1}},
 {301, {wxTopLevelWindow, setIcons, 1}},
 {302, {wxTopLevelWindow, centerOnScreen, 1}},
 {303, {wxTopLevelWindow, centreOnScreen, 1}},
 {305, {wxTopLevelWindow, setShape, 1}},
 {306, {wxTopLevelWindow, setTitle, 1}},
 {307, {wxTopLevelWindow, showFullScreen, 2}},
 {309, {wxFrame, new_4, 4}},
 {310, {wxFrame, new_0, 0}},
 {312, {wxFrame, destruct, 0}},
 {313, {wxFrame, create, 4}},
 {314, {wxFrame, createStatusBar, 1}},
 {315, {wxFrame, createToolBar, 1}},
 {316, {wxFrame, getClientAreaOrigin, 0}},
 {317, {wxFrame, getMenuBar, 0}},
 {318, {wxFrame, getStatusBar, 0}},
 {319, {wxFrame, getStatusBarPane, 0}},
 {320, {wxFrame, getToolBar, 0}},
 {321, {wxFrame, processCommand, 1}},
 {322, {wxFrame, sendSizeEvent, 0}},
 {323, {wxFrame, setMenuBar, 1}},
 {324, {wxFrame, setStatusBar, 1}},
 {325, {wxFrame, setStatusBarPane, 1}},
 {326, {wxFrame, setStatusText, 2}},
 {327, {wxFrame, setStatusWidths, 2}},
 {328, {wxFrame, setToolBar, 1}},
 {329, {wxMiniFrame, new_0, 0}},
 {330, {wxMiniFrame, new_4, 4}},
 {331, {wxMiniFrame, create, 4}},
 {332, {wxMiniFrame, 'Destroy', undefined}},
 {333, {wxSplashScreen, new_0, 0}},
 {334, {wxSplashScreen, new_6, 6}},
 {335, {wxSplashScreen, destruct, 0}},
 {336, {wxSplashScreen, getSplashStyle, 0}},
 {337, {wxSplashScreen, getTimeout, 0}},
 {338, {wxPanel, new_0, 0}},
 {339, {wxPanel, new_6, 6}},
 {340, {wxPanel, new_2, 2}},
 {341, {wxPanel, destruct, 0}},
 {342, {wxPanel, initDialog, 0}},
 {343, {wxPanel, setFocusIgnoringChildren, 0}},
 {344, {wxScrolledWindow, new_0, 0}},
 {345, {wxScrolledWindow, new_2, 2}},
 {346, {wxScrolledWindow, destruct, 0}},
 {347, {wxScrolledWindow, calcScrolledPosition_4, 4}},
 {348, {wxScrolledWindow, calcScrolledPosition_1, 1}},
 {349, {wxScrolledWindow, calcUnscrolledPosition_4, 4}},
 {350, {wxScrolledWindow, calcUnscrolledPosition_1, 1}},
 {351, {wxScrolledWindow, enableScrolling, 2}},
 {352, {wxScrolledWindow, getScrollPixelsPerUnit, 2}},
 {353, {wxScrolledWindow, getViewStart, 2}},
 {354, {wxScrolledWindow, doPrepareDC, 1}},
 {355, {wxScrolledWindow, prepareDC, 1}},
 {356, {wxScrolledWindow, scroll, 2}},
 {357, {wxScrolledWindow, setScrollbars, 5}},
 {358, {wxScrolledWindow, setScrollRate, 2}},
 {359, {wxScrolledWindow, setTargetWindow, 1}},
 {360, {wxSashWindow, new_0, 0}},
 {361, {wxSashWindow, new_2, 2}},
 {362, {wxSashWindow, destruct, 0}},
 {363, {wxSashWindow, getSashVisible, 1}},
 {364, {wxSashWindow, getMaximumSizeX, 0}},
 {365, {wxSashWindow, getMaximumSizeY, 0}},
 {366, {wxSashWindow, getMinimumSizeX, 0}},
 {367, {wxSashWindow, getMinimumSizeY, 0}},
 {368, {wxSashWindow, setMaximumSizeX, 1}},
 {369, {wxSashWindow, setMaximumSizeY, 1}},
 {370, {wxSashWindow, setMinimumSizeX, 1}},
 {371, {wxSashWindow, setMinimumSizeY, 1}},
 {372, {wxSashWindow, setSashVisible, 2}},
 {373, {wxSashLayoutWindow, new_0, 0}},
 {374, {wxSashLayoutWindow, new_2, 2}},
 {375, {wxSashLayoutWindow, create, 2}},
 {376, {wxSashLayoutWindow, getAlignment, 0}},
 {377, {wxSashLayoutWindow, getOrientation, 0}},
 {378, {wxSashLayoutWindow, setAlignment, 1}},
 {379, {wxSashLayoutWindow, setDefaultSize, 1}},
 {380, {wxSashLayoutWindow, setOrientation, 1}},
 {381, {wxSashLayoutWindow, 'Destroy', undefined}},
 {382, {wxGrid, new_0, 0}},
 {383, {wxGrid, new_3, 3}},
 {384, {wxGrid, new_4, 4}},
 {385, {wxGrid, destruct, 0}},
 {386, {wxGrid, appendCols, 1}},
 {387, {wxGrid, appendRows, 1}},
 {388, {wxGrid, autoSize, 0}},
 {389, {wxGrid, autoSizeColumn, 2}},
 {390, {wxGrid, autoSizeColumns, 1}},
 {391, {wxGrid, autoSizeRow, 2}},
 {392, {wxGrid, autoSizeRows, 1}},
 {393, {wxGrid, beginBatch, 0}},
 {394, {wxGrid, blockToDeviceRect, 2}},
 {395, {wxGrid, canDragColSize, 0}},
 {396, {wxGrid, canDragRowSize, 0}},
 {397, {wxGrid, canDragGridSize, 0}},
 {398, {wxGrid, canEnableCellControl, 0}},
 {399, {wxGrid, cellToRect_2, 2}},
 {400, {wxGrid, cellToRect_1, 1}},
 {401, {wxGrid, clearGrid, 0}},
 {402, {wxGrid, clearSelection, 0}},
 {403, {wxGrid, createGrid, 3}},
 {404, {wxGrid, deleteCols, 1}},
 {405, {wxGrid, deleteRows, 1}},
 {406, {wxGrid, disableCellEditControl, 0}},
 {407, {wxGrid, disableDragColSize, 0}},
 {408, {wxGrid, disableDragGridSize, 0}},
 {409, {wxGrid, disableDragRowSize, 0}},
 {410, {wxGrid, enableCellEditControl, 1}},
 {411, {wxGrid, enableDragColSize, 1}},
 {412, {wxGrid, enableDragGridSize, 1}},
 {413, {wxGrid, enableDragRowSize, 1}},
 {414, {wxGrid, enableEditing, 1}},
 {415, {wxGrid, enableGridLines, 1}},
 {416, {wxGrid, endBatch, 0}},
 {417, {wxGrid, fit, 0}},
 {418, {wxGrid, forceRefresh, 0}},
 {419, {wxGrid, getBatchCount, 0}},
 {420, {wxGrid, getCellAlignment, 4}},
 {421, {wxGrid, getCellBackgroundColour, 2}},
 {422, {wxGrid, getCellEditor, 2}},
 {423, {wxGrid, getCellFont, 2}},
 {424, {wxGrid, getCellRenderer, 2}},
 {425, {wxGrid, getCellTextColour, 2}},
 {426, {wxGrid, getCellValue_2, 2}},
 {427, {wxGrid, getCellValue_1, 1}},
 {428, {wxGrid, getColLabelAlignment, 2}},
 {429, {wxGrid, getColLabelSize, 0}},
 {430, {wxGrid, getColLabelValue, 1}},
 {431, {wxGrid, getColMinimalAcceptableWidth, 0}},
 {432, {wxGrid, getDefaultCellAlignment, 2}},
 {433, {wxGrid, getDefaultCellBackgroundColour, 0}},
 {434, {wxGrid, getDefaultCellFont, 0}},
 {435, {wxGrid, getDefaultCellTextColour, 0}},
 {436, {wxGrid, getDefaultColLabelSize, 0}},
 {437, {wxGrid, getDefaultColSize, 0}},
 {438, {wxGrid, getDefaultEditor, 0}},
 {439, {wxGrid, getDefaultEditorForCell_2, 2}},
 {440, {wxGrid, getDefaultEditorForCell_1, 1}},
 {441, {wxGrid, getDefaultEditorForType, 1}},
 {442, {wxGrid, getDefaultRenderer, 0}},
 {443, {wxGrid, getDefaultRendererForCell, 2}},
 {444, {wxGrid, getDefaultRendererForType, 1}},
 {445, {wxGrid, getDefaultRowLabelSize, 0}},
 {446, {wxGrid, getDefaultRowSize, 0}},
 {447, {wxGrid, getGridCursorCol, 0}},
 {448, {wxGrid, getGridCursorRow, 0}},
 {449, {wxGrid, getGridLineColour, 0}},
 {450, {wxGrid, gridLinesEnabled, 0}},
 {451, {wxGrid, getLabelBackgroundColour, 0}},
 {452, {wxGrid, getLabelFont, 0}},
 {453, {wxGrid, getLabelTextColour, 0}},
 {454, {wxGrid, getNumberCols, 0}},
 {455, {wxGrid, getNumberRows, 0}},
 {456, {wxGrid, getOrCreateCellAttr, 2}},
 {457, {wxGrid, getRowMinimalAcceptableHeight, 0}},
 {458, {wxGrid, getRowLabelAlignment, 2}},
 {459, {wxGrid, getRowLabelSize, 0}},
 {460, {wxGrid, getRowLabelValue, 1}},
 {461, {wxGrid, getRowSize, 1}},
 {462, {wxGrid, getScrollLineX, 0}},
 {463, {wxGrid, getScrollLineY, 0}},
 {464, {wxGrid, getSelectedCells, 0}},
 {465, {wxGrid, getSelectedCols, 0}},
 {466, {wxGrid, getSelectedRows, 0}},
 {467, {wxGrid, getSelectionBackground, 0}},
 {468, {wxGrid, getSelectionBlockTopLeft, 0}},
 {469, {wxGrid, getSelectionBlockBottomRight, 0}},
 {470, {wxGrid, getSelectionForeground, 0}},
 {471, {wxGrid, getViewWidth, 0}},
 {472, {wxGrid, getGridWindow, 0}},
 {473, {wxGrid, getGridRowLabelWindow, 0}},
 {474, {wxGrid, getGridColLabelWindow, 0}},
 {475, {wxGrid, getGridCornerLabelWindow, 0}},
 {476, {wxGrid, hideCellEditControl, 0}},
 {477, {wxGrid, insertCols, 1}},
 {478, {wxGrid, insertRows, 1}},
 {479, {wxGrid, isCellEditControlEnabled, 0}},
 {480, {wxGrid, isCurrentCellReadOnly, 0}},
 {481, {wxGrid, isEditable, 0}},
 {482, {wxGrid, isInSelection_2, 2}},
 {483, {wxGrid, isInSelection_1, 1}},
 {484, {wxGrid, isReadOnly, 2}},
 {485, {wxGrid, isSelection, 0}},
 {486, {wxGrid, isVisible_3, 3}},
 {487, {wxGrid, isVisible_2, 2}},
 {488, {wxGrid, makeCellVisible_2, 2}},
 {489, {wxGrid, makeCellVisible_1, 1}},
 {490, {wxGrid, moveCursorDown, 1}},
 {491, {wxGrid, moveCursorLeft, 1}},
 {492, {wxGrid, moveCursorRight, 1}},
 {493, {wxGrid, moveCursorUp, 1}},
 {494, {wxGrid, moveCursorDownBlock, 1}},
 {495, {wxGrid, moveCursorLeftBlock, 1}},
 {496, {wxGrid, moveCursorRightBlock, 1}},
 {497, {wxGrid, moveCursorUpBlock, 1}},
 {498, {wxGrid, movePageDown, 0}},
 {499, {wxGrid, movePageUp, 0}},
 {500, {wxGrid, registerDataType, 3}},
 {501, {wxGrid, saveEditControlValue, 0}},
 {502, {wxGrid, selectAll, 0}},
 {503, {wxGrid, selectBlock_5, 5}},
 {504, {wxGrid, selectBlock_3, 3}},
 {505, {wxGrid, selectCol, 2}},
 {506, {wxGrid, selectRow, 2}},
 {507, {wxGrid, setCellAlignment_4, 4}},
 {508, {wxGrid, setCellAlignment_3, 3}},
 {509, {wxGrid, setCellAlignment_1, 1}},
 {510, {wxGrid, setCellBackgroundColour_3_0, 3}},
 {511, {wxGrid, setCellBackgroundColour_1, 1}},
 {512, {wxGrid, setCellBackgroundColour_3_1, 3}},
 {513, {wxGrid, setCellEditor, 3}},
 {514, {wxGrid, setCellFont, 3}},
 {515, {wxGrid, setCellRenderer, 3}},
 {516, {wxGrid, setCellTextColour_3_0, 3}},
 {517, {wxGrid, setCellTextColour_3_1, 3}},
 {518, {wxGrid, setCellTextColour_1, 1}},
 {519, {wxGrid, setCellValue_3_0, 3}},
 {520, {wxGrid, setCellValue_2, 2}},
 {521, {wxGrid, setCellValue_3_1, 3}},
 {522, {wxGrid, setColAttr, 2}},
 {523, {wxGrid, setColFormatBool, 1}},
 {524, {wxGrid, setColFormatNumber, 1}},
 {525, {wxGrid, setColFormatFloat, 2}},
 {526, {wxGrid, setColFormatCustom, 2}},
 {527, {wxGrid, setColLabelAlignment, 2}},
 {528, {wxGrid, setColLabelSize, 1}},
 {529, {wxGrid, setColLabelValue, 2}},
 {530, {wxGrid, setColMinimalWidth, 2}},
 {531, {wxGrid, setColMinimalAcceptableWidth, 1}},
 {532, {wxGrid, setColSize, 2}},
 {533, {wxGrid, setDefaultCellAlignment, 2}},
 {534, {wxGrid, setDefaultCellBackgroundColour, 1}},
 {535, {wxGrid, setDefaultCellFont, 1}},
 {536, {wxGrid, setDefaultCellTextColour, 1}},
 {537, {wxGrid, setDefaultEditor, 1}},
 {538, {wxGrid, setDefaultRenderer, 1}},
 {539, {wxGrid, setDefaultColSize, 2}},
 {540, {wxGrid, setDefaultRowSize, 2}},
 {541, {wxGrid, setGridCursor, 2}},
 {542, {wxGrid, setGridLineColour, 1}},
 {543, {wxGrid, setLabelBackgroundColour, 1}},
 {544, {wxGrid, setLabelFont, 1}},
 {545, {wxGrid, setLabelTextColour, 1}},
 {546, {wxGrid, setMargins, 2}},
 {547, {wxGrid, setReadOnly, 3}},
 {548, {wxGrid, setRowAttr, 2}},
 {549, {wxGrid, setRowLabelAlignment, 2}},
 {550, {wxGrid, setRowLabelSize, 1}},
 {551, {wxGrid, setRowLabelValue, 2}},
 {552, {wxGrid, setRowMinimalHeight, 2}},
 {553, {wxGrid, setRowMinimalAcceptableHeight, 1}},
 {554, {wxGrid, setRowSize, 2}},
 {555, {wxGrid, setScrollLineX, 1}},
 {556, {wxGrid, setScrollLineY, 1}},
 {557, {wxGrid, setSelectionBackground, 1}},
 {558, {wxGrid, setSelectionForeground, 1}},
 {559, {wxGrid, setSelectionMode, 1}},
 {560, {wxGrid, showCellEditControl, 0}},
 {561, {wxGrid, xToCol, 2}},
 {562, {wxGrid, xToEdgeOfCol, 1}},
 {563, {wxGrid, yToEdgeOfRow, 1}},
 {564, {wxGrid, yToRow, 1}},
 {565, {wxGridCellRenderer, draw, 7}},
 {566, {wxGridCellRenderer, getBestSize, 5}},
 {567, {wxGridCellEditor, create, 3}},
 {568, {wxGridCellEditor, isCreated, 0}},
 {569, {wxGridCellEditor, setSize, 1}},
 {570, {wxGridCellEditor, show, 2}},
 {571, {wxGridCellEditor, paintBackground, 2}},
 {572, {wxGridCellEditor, beginEdit, 3}},
 {573, {wxGridCellEditor, endEdit, 3}},
 {574, {wxGridCellEditor, reset, 0}},
 {575, {wxGridCellEditor, startingKey, 1}},
 {576, {wxGridCellEditor, startingClick, 0}},
 {577, {wxGridCellEditor, handleReturn, 1}},
 {578, {wxGridCellBoolRenderer, new, 0}},
 {579, {wxGridCellBoolRenderer, 'Destroy', undefined}},
 {580, {wxGridCellBoolEditor, new, 0}},
 {581, {wxGridCellBoolEditor, isTrueValue, 1}},
 {582, {wxGridCellBoolEditor, useStringValues, 1}},
 {583, {wxGridCellBoolEditor, 'Destroy', undefined}},
 {584, {wxGridCellFloatRenderer, new, 1}},
 {585, {wxGridCellFloatRenderer, getPrecision, 0}},
 {586, {wxGridCellFloatRenderer, getWidth, 0}},
 {587, {wxGridCellFloatRenderer, setParameters, 1}},
 {588, {wxGridCellFloatRenderer, setPrecision, 1}},
 {589, {wxGridCellFloatRenderer, setWidth, 1}},
 {590, {wxGridCellFloatRenderer, 'Destroy', undefined}},
 {591, {wxGridCellFloatEditor, new, 1}},
 {592, {wxGridCellFloatEditor, setParameters, 1}},
 {593, {wxGridCellFloatEditor, 'Destroy', undefined}},
 {594, {wxGridCellStringRenderer, new, 0}},
 {595, {wxGridCellStringRenderer, 'Destroy', undefined}},
 {596, {wxGridCellTextEditor, new, 0}},
 {597, {wxGridCellTextEditor, setParameters, 1}},
 {598, {wxGridCellTextEditor, 'Destroy', undefined}},
 {600, {wxGridCellChoiceEditor, new, 2}},
 {601, {wxGridCellChoiceEditor, setParameters, 1}},
 {602, {wxGridCellChoiceEditor, 'Destroy', undefined}},
 {603, {wxGridCellNumberRenderer, new, 0}},
 {604, {wxGridCellNumberRenderer, 'Destroy', undefined}},
 {605, {wxGridCellNumberEditor, new, 1}},
 {606, {wxGridCellNumberEditor, getValue, 0}},
 {607, {wxGridCellNumberEditor, setParameters, 1}},
 {608, {wxGridCellNumberEditor, 'Destroy', undefined}},
 {609, {wxGridCellAttr, setTextColour, 1}},
 {610, {wxGridCellAttr, setBackgroundColour, 1}},
 {611, {wxGridCellAttr, setFont, 1}},
 {612, {wxGridCellAttr, setAlignment, 2}},
 {613, {wxGridCellAttr, setReadOnly, 1}},
 {614, {wxGridCellAttr, setRenderer, 1}},
 {615, {wxGridCellAttr, setEditor, 1}},
 {616, {wxGridCellAttr, hasTextColour, 0}},
 {617, {wxGridCellAttr, hasBackgroundColour, 0}},
 {618, {wxGridCellAttr, hasFont, 0}},
 {619, {wxGridCellAttr, hasAlignment, 0}},
 {620, {wxGridCellAttr, hasRenderer, 0}},
 {621, {wxGridCellAttr, hasEditor, 0}},
 {622, {wxGridCellAttr, getTextColour, 0}},
 {623, {wxGridCellAttr, getBackgroundColour, 0}},
 {624, {wxGridCellAttr, getFont, 0}},
 {625, {wxGridCellAttr, getAlignment, 2}},
 {626, {wxGridCellAttr, getRenderer, 3}},
 {627, {wxGridCellAttr, getEditor, 3}},
 {628, {wxGridCellAttr, isReadOnly, 0}},
 {629, {wxGridCellAttr, setDefAttr, 1}},
 {630, {wxDC, blit, 5}},
 {631, {wxDC, calcBoundingBox, 2}},
 {632, {wxDC, clear, 0}},
 {633, {wxDC, computeScaleAndOrigin, 0}},
 {634, {wxDC, crossHair, 1}},
 {635, {wxDC, destroyClippingRegion, 0}},
 {636, {wxDC, deviceToLogicalX, 1}},
 {637, {wxDC, deviceToLogicalXRel, 1}},
 {638, {wxDC, deviceToLogicalY, 1}},
 {639, {wxDC, deviceToLogicalYRel, 1}},
 {640, {wxDC, drawArc, 3}},
 {641, {wxDC, drawBitmap, 3}},
 {642, {wxDC, drawCheckMark, 1}},
 {643, {wxDC, drawCircle, 2}},
 {645, {wxDC, drawEllipse_2, 2}},
 {646, {wxDC, drawEllipse_1, 1}},
 {647, {wxDC, drawEllipticArc, 4}},
 {648, {wxDC, drawIcon, 2}},
 {649, {wxDC, drawLabel, 3}},
 {650, {wxDC, drawLine, 2}},
 {651, {wxDC, drawLines, 3}},
 {653, {wxDC, drawPolygon, 3}},
 {655, {wxDC, drawPoint, 1}},
 {657, {wxDC, drawRectangle_2, 2}},
 {658, {wxDC, drawRectangle_1, 1}},
 {659, {wxDC, drawRotatedText, 3}},
 {661, {wxDC, drawRoundedRectangle_3, 3}},
 {662, {wxDC, drawRoundedRectangle_2, 2}},
 {663, {wxDC, drawText, 2}},
 {664, {wxDC, endDoc, 0}},
 {665, {wxDC, endPage, 0}},
 {666, {wxDC, floodFill, 3}},
 {667, {wxDC, getBackground, 0}},
 {668, {wxDC, getBackgroundMode, 0}},
 {669, {wxDC, getBrush, 0}},
 {670, {wxDC, getCharHeight, 0}},
 {671, {wxDC, getCharWidth, 0}},
 {672, {wxDC, getClippingBox, 4}},
 {674, {wxDC, getFont, 0}},
 {675, {wxDC, getLayoutDirection, 0}},
 {676, {wxDC, getLogicalFunction, 0}},
 {677, {wxDC, getMapMode, 0}},
 {678, {wxDC, getMultiLineTextExtent_4, 4}},
 {679, {wxDC, getMultiLineTextExtent_1, 1}},
 {680, {wxDC, getPartialTextExtents, 2}},
 {681, {wxDC, getPen, 0}},
 {682, {wxDC, getPixel, 2}},
 {683, {wxDC, getPPI, 0}},
 {685, {wxDC, getSize, 0}},
 {687, {wxDC, getSizeMM, 0}},
 {688, {wxDC, getTextBackground, 0}},
 {689, {wxDC, getTextExtent_4, 4}},
 {690, {wxDC, getTextExtent_1, 1}},
 {692, {wxDC, getTextForeground, 0}},
 {693, {wxDC, getUserScale, 2}},
 {694, {wxDC, gradientFillConcentric_3, 3}},
 {695, {wxDC, gradientFillConcentric_4, 4}},
 {696, {wxDC, gradientFillLinear, 4}},
 {697, {wxDC, logicalToDeviceX, 1}},
 {698, {wxDC, logicalToDeviceXRel, 1}},
 {699, {wxDC, logicalToDeviceY, 1}},
 {700, {wxDC, logicalToDeviceYRel, 1}},
 {701, {wxDC, maxX, 0}},
 {702, {wxDC, maxY, 0}},
 {703, {wxDC, minX, 0}},
 {704, {wxDC, minY, 0}},
 {705, {wxDC, isOk, 0}},
 {706, {wxDC, resetBoundingBox, 0}},
 {707, {wxDC, setAxisOrientation, 2}},
 {708, {wxDC, setBackground, 1}},
 {709, {wxDC, setBackgroundMode, 1}},
 {710, {wxDC, setBrush, 1}},
 {712, {wxDC, setClippingRegion_2, 2}},
 {713, {wxDC, setClippingRegion_1_1, 1}},
 {714, {wxDC, setClippingRegion_1_0, 1}},
 {715, {wxDC, setDeviceOrigin, 2}},
 {716, {wxDC, setFont, 1}},
 {717, {wxDC, setLayoutDirection, 1}},
 {718, {wxDC, setLogicalFunction, 1}},
 {719, {wxDC, setMapMode, 1}},
 {720, {wxDC, setPalette, 1}},
 {721, {wxDC, setPen, 1}},
 {722, {wxDC, setTextBackground, 1}},
 {723, {wxDC, setTextForeground, 1}},
 {724, {wxDC, setUserScale, 2}},
 {725, {wxDC, startDoc, 1}},
 {726, {wxDC, startPage, 0}},
 {727, {wxMirrorDC, new, 2}},
 {728, {wxMirrorDC, 'Destroy', undefined}},
 {729, {wxScreenDC, new, 0}},
 {730, {wxScreenDC, destruct, 0}},
 {731, {wxPostScriptDC, new_0, 0}},
 {732, {wxPostScriptDC, new_1, 1}},
 {733, {wxPostScriptDC, destruct, 0}},
 {734, {wxPostScriptDC, setResolution, 1}},
 {735, {wxPostScriptDC, getResolution, 0}},
 {736, {wxWindowDC, new_0, 0}},
 {737, {wxWindowDC, new_1, 1}},
 {738, {wxWindowDC, destruct, 0}},
 {739, {wxClientDC, new_0, 0}},
 {740, {wxClientDC, new_1, 1}},
 {741, {wxClientDC, 'Destroy', undefined}},
 {742, {wxPaintDC, new_0, 0}},
 {743, {wxPaintDC, new_1, 1}},
 {744, {wxPaintDC, 'Destroy', undefined}},
 {746, {wxMemoryDC, new_1_0, 1}},
 {747, {wxMemoryDC, new_1_1, 1}},
 {748, {wxMemoryDC, new_0, 0}},
 {750, {wxMemoryDC, destruct, 0}},
 {751, {wxMemoryDC, selectObject, 1}},
 {752, {wxMemoryDC, selectObjectAsSource, 1}},
 {753, {wxBufferedDC, new_0, 0}},
 {754, {wxBufferedDC, new_2, 2}},
 {755, {wxBufferedDC, new_3, 3}},
 {756, {wxBufferedDC, destruct, 0}},
 {757, {wxBufferedDC, init_2, 2}},
 {758, {wxBufferedDC, init_3, 3}},
 {759, {wxBufferedPaintDC, new_3, 3}},
 {760, {wxBufferedPaintDC, new_2, 2}},
 {761, {wxBufferedPaintDC, destruct, 0}},
 {762, {wxGraphicsObject, destruct, 0}},
 {763, {wxGraphicsObject, getRenderer, 0}},
 {764, {wxGraphicsObject, isNull, 0}},
 {765, {wxGraphicsContext, destruct, 0}},
 {766, {wxGraphicsContext, create_1_1, 1}},
 {767, {wxGraphicsContext, create_1_0, 1}},
 {768, {wxGraphicsContext, create_0, 0}},
 {769, {wxGraphicsContext, createPen, 1}},
 {770, {wxGraphicsContext, createBrush, 1}},
 {771, {wxGraphicsContext, createRadialGradientBrush, 7}},
 {772, {wxGraphicsContext, createLinearGradientBrush, 6}},
 {773, {wxGraphicsContext, createFont, 2}},
 {774, {wxGraphicsContext, createMatrix, 1}},
 {775, {wxGraphicsContext, createPath, 0}},
 {776, {wxGraphicsContext, clip_1, 1}},
 {777, {wxGraphicsContext, clip_4, 4}},
 {778, {wxGraphicsContext, resetClip, 0}},
 {779, {wxGraphicsContext, drawBitmap, 5}},
 {780, {wxGraphicsContext, drawEllipse, 4}},
 {781, {wxGraphicsContext, drawIcon, 5}},
 {782, {wxGraphicsContext, drawLines, 3}},
 {783, {wxGraphicsContext, drawPath, 2}},
 {784, {wxGraphicsContext, drawRectangle, 4}},
 {785, {wxGraphicsContext, drawRoundedRectangle, 5}},
 {786, {wxGraphicsContext, drawText_3, 3}},
 {787, {wxGraphicsContext, drawText_4_0, 4}},
 {788, {wxGraphicsContext, drawText_4_1, 4}},
 {789, {wxGraphicsContext, drawText_5, 5}},
 {790, {wxGraphicsContext, fillPath, 2}},
 {791, {wxGraphicsContext, strokePath, 1}},
 {792, {wxGraphicsContext, getPartialTextExtents, 2}},
 {793, {wxGraphicsContext, getTextExtent, 5}},
 {794, {wxGraphicsContext, rotate, 1}},
 {795, {wxGraphicsContext, scale, 2}},
 {796, {wxGraphicsContext, translate, 2}},
 {797, {wxGraphicsContext, getTransform, 0}},
 {798, {wxGraphicsContext, setTransform, 1}},
 {799, {wxGraphicsContext, concatTransform, 1}},
 {800, {wxGraphicsContext, setBrush_1_1, 1}},
 {801, {wxGraphicsContext, setBrush_1_0, 1}},
 {802, {wxGraphicsContext, setFont_1, 1}},
 {803, {wxGraphicsContext, setFont_2, 2}},
 {804, {wxGraphicsContext, setPen_1_0, 1}},
 {805, {wxGraphicsContext, setPen_1_1, 1}},
 {806, {wxGraphicsContext, strokeLine, 4}},
 {807, {wxGraphicsContext, strokeLines, 2}},
 {809, {wxGraphicsMatrix, concat, 1}},
 {811, {wxGraphicsMatrix, get, 1}},
 {812, {wxGraphicsMatrix, invert, 0}},
 {813, {wxGraphicsMatrix, isEqual, 1}},
 {815, {wxGraphicsMatrix, isIdentity, 0}},
 {816, {wxGraphicsMatrix, rotate, 1}},
 {817, {wxGraphicsMatrix, scale, 2}},
 {818, {wxGraphicsMatrix, translate, 2}},
 {819, {wxGraphicsMatrix, set, 1}},
 {820, {wxGraphicsMatrix, transformPoint, 2}},
 {821, {wxGraphicsMatrix, transformDistance, 2}},
 {822, {wxGraphicsPath, moveToPoint_2, 2}},
 {823, {wxGraphicsPath, moveToPoint_1, 1}},
 {824, {wxGraphicsPath, addArc_6, 6}},
 {825, {wxGraphicsPath, addArc_5, 5}},
 {826, {wxGraphicsPath, addArcToPoint, 5}},
 {827, {wxGraphicsPath, addCircle, 3}},
 {828, {wxGraphicsPath, addCurveToPoint_6, 6}},
 {829, {wxGraphicsPath, addCurveToPoint_3, 3}},
 {830, {wxGraphicsPath, addEllipse, 4}},
 {831, {wxGraphicsPath, addLineToPoint_2, 2}},
 {832, {wxGraphicsPath, addLineToPoint_1, 1}},
 {833, {wxGraphicsPath, addPath, 1}},
 {834, {wxGraphicsPath, addQuadCurveToPoint, 4}},
 {835, {wxGraphicsPath, addRectangle, 4}},
 {836, {wxGraphicsPath, addRoundedRectangle, 5}},
 {837, {wxGraphicsPath, closeSubpath, 0}},
 {838, {wxGraphicsPath, contains_3, 3}},
 {839, {wxGraphicsPath, contains_2, 2}},
 {841, {wxGraphicsPath, getBox, 0}},
 {843, {wxGraphicsPath, getCurrentPoint, 0}},
 {844, {wxGraphicsPath, transform, 1}},
 {845, {wxGraphicsRenderer, getDefaultRenderer, 0}},
 {846, {wxGraphicsRenderer, createContext_1_1, 1}},
 {847, {wxGraphicsRenderer, createContext_1_0, 1}},
 {848, {wxGraphicsRenderer, createPen, 1}},
 {849, {wxGraphicsRenderer, createBrush, 1}},
 {850, {wxGraphicsRenderer, createLinearGradientBrush, 6}},
 {851, {wxGraphicsRenderer, createRadialGradientBrush, 7}},
 {852, {wxGraphicsRenderer, createFont, 2}},
 {853, {wxGraphicsRenderer, createMatrix, 1}},
 {854, {wxGraphicsRenderer, createPath, 0}},
 {856, {wxMenuBar, new_1, 1}},
 {858, {wxMenuBar, new_0, 0}},
 {860, {wxMenuBar, destruct, 0}},
 {861, {wxMenuBar, append, 2}},
 {862, {wxMenuBar, check, 2}},
 {863, {wxMenuBar, enable_2, 2}},
 {864, {wxMenuBar, enable_1, 1}},
 {865, {wxMenuBar, enableTop, 2}},
 {866, {wxMenuBar, findMenu, 1}},
 {867, {wxMenuBar, findMenuItem, 2}},
 {868, {wxMenuBar, findItem, 2}},
 {869, {wxMenuBar, getHelpString, 1}},
 {870, {wxMenuBar, getLabel_1, 1}},
 {871, {wxMenuBar, getLabel_0, 0}},
 {872, {wxMenuBar, getLabelTop, 1}},
 {873, {wxMenuBar, getMenu, 1}},
 {874, {wxMenuBar, getMenuCount, 0}},
 {875, {wxMenuBar, insert, 3}},
 {876, {wxMenuBar, isChecked, 1}},
 {877, {wxMenuBar, isEnabled_1, 1}},
 {878, {wxMenuBar, isEnabled_0, 0}},
 {879, {wxMenuBar, remove, 1}},
 {880, {wxMenuBar, replace, 3}},
 {881, {wxMenuBar, setHelpString, 2}},
 {882, {wxMenuBar, setLabel_2, 2}},
 {883, {wxMenuBar, setLabel_1, 1}},
 {884, {wxMenuBar, setLabelTop, 2}},
 {885, {wxControl, getLabel, 0}},
 {886, {wxControl, setLabel, 1}},
 {887, {wxControlWithItems, append_1, 1}},
 {888, {wxControlWithItems, append_2, 2}},
 {889, {wxControlWithItems, appendStrings_1, 1}},
 {890, {wxControlWithItems, clear, 0}},
 {891, {wxControlWithItems, delete, 1}},
 {892, {wxControlWithItems, findString, 2}},
 {893, {wxControlWithItems, getClientData, 1}},
 {894, {wxControlWithItems, setClientData, 2}},
 {895, {wxControlWithItems, getCount, 0}},
 {896, {wxControlWithItems, getSelection, 0}},
 {897, {wxControlWithItems, getString, 1}},
 {898, {wxControlWithItems, getStringSelection, 0}},
 {899, {wxControlWithItems, insert_2, 2}},
 {900, {wxControlWithItems, insert_3, 3}},
 {901, {wxControlWithItems, isEmpty, 0}},
 {902, {wxControlWithItems, select, 1}},
 {903, {wxControlWithItems, setSelection, 1}},
 {904, {wxControlWithItems, setString, 2}},
 {905, {wxControlWithItems, setStringSelection, 1}},
 {908, {wxMenu, new_2, 2}},
 {909, {wxMenu, new_1, 1}},
 {911, {wxMenu, destruct, 0}},
 {912, {wxMenu, append_3, 3}},
 {913, {wxMenu, append_1, 1}},
 {914, {wxMenu, append_4_0, 4}},
 {915, {wxMenu, append_4_1, 4}},
 {916, {wxMenu, appendCheckItem, 3}},
 {917, {wxMenu, appendRadioItem, 3}},
 {918, {wxMenu, appendSeparator, 0}},
 {919, {wxMenu, break, 0}},
 {920, {wxMenu, check, 2}},
 {921, {wxMenu, delete_1_0, 1}},
 {922, {wxMenu, delete_1_1, 1}},
 {923, {wxMenu, destroy_1_0, 1}},
 {924, {wxMenu, destroy_1_1, 1}},
 {925, {wxMenu, enable, 2}},
 {926, {wxMenu, findItem_1, 1}},
 {927, {wxMenu, findItem_2, 2}},
 {928, {wxMenu, findItemByPosition, 1}},
 {929, {wxMenu, getHelpString, 1}},
 {930, {wxMenu, getLabel, 1}},
 {931, {wxMenu, getMenuItemCount, 0}},
 {932, {wxMenu, getMenuItems, 0}},
 {934, {wxMenu, getTitle, 0}},
 {935, {wxMenu, insert_2, 2}},
 {936, {wxMenu, insert_3, 3}},
 {937, {wxMenu, insert_5_1, 5}},
 {938, {wxMenu, insert_5_0, 5}},
 {939, {wxMenu, insertCheckItem, 4}},
 {940, {wxMenu, insertRadioItem, 4}},
 {941, {wxMenu, insertSeparator, 1}},
 {942, {wxMenu, isChecked, 1}},
 {943, {wxMenu, isEnabled, 1}},
 {944, {wxMenu, prepend_1, 1}},
 {945, {wxMenu, prepend_2, 2}},
 {946, {wxMenu, prepend_4_1, 4}},
 {947, {wxMenu, prepend_4_0, 4}},
 {948, {wxMenu, prependCheckItem, 3}},
 {949, {wxMenu, prependRadioItem, 3}},
 {950, {wxMenu, prependSeparator, 0}},
 {951, {wxMenu, remove_1_0, 1}},
 {952, {wxMenu, remove_1_1, 1}},
 {953, {wxMenu, setHelpString, 2}},
 {954, {wxMenu, setLabel, 2}},
 {955, {wxMenu, setTitle, 1}},
 {956, {wxMenuItem, new, 1}},
 {958, {wxMenuItem, destruct, 0}},
 {959, {wxMenuItem, check, 1}},
 {960, {wxMenuItem, enable, 1}},
 {961, {wxMenuItem, getBitmap, 0}},
 {962, {wxMenuItem, getHelp, 0}},
 {963, {wxMenuItem, getId, 0}},
 {964, {wxMenuItem, getKind, 0}},
 {965, {wxMenuItem, getLabel, 0}},
 {966, {wxMenuItem, getLabelFromText, 1}},
 {967, {wxMenuItem, getMenu, 0}},
 {968, {wxMenuItem, getText, 0}},
 {969, {wxMenuItem, getSubMenu, 0}},
 {970, {wxMenuItem, isCheckable, 0}},
 {971, {wxMenuItem, isChecked, 0}},
 {972, {wxMenuItem, isEnabled, 0}},
 {973, {wxMenuItem, isSeparator, 0}},
 {974, {wxMenuItem, isSubMenu, 0}},
 {975, {wxMenuItem, setBitmap, 1}},
 {976, {wxMenuItem, setHelp, 1}},
 {977, {wxMenuItem, setMenu, 1}},
 {978, {wxMenuItem, setSubMenu, 1}},
 {979, {wxMenuItem, setText, 1}},
 {980, {wxToolBar, addControl, 1}},
 {981, {wxToolBar, addSeparator, 0}},
 {982, {wxToolBar, addTool_5, 5}},
 {983, {wxToolBar, addTool_4_0, 4}},
 {984, {wxToolBar, addTool_1, 1}},
 {985, {wxToolBar, addTool_4_1, 4}},
 {986, {wxToolBar, addTool_3, 3}},
 {987, {wxToolBar, addTool_6, 6}},
 {988, {wxToolBar, addCheckTool, 4}},
 {989, {wxToolBar, addRadioTool, 4}},
 {990, {wxToolBar, addStretchableSpace, 0}},
 {991, {wxToolBar, insertStretchableSpace, 1}},
 {992, {wxToolBar, deleteTool, 1}},
 {993, {wxToolBar, deleteToolByPos, 1}},
 {994, {wxToolBar, enableTool, 2}},
 {995, {wxToolBar, findById, 1}},
 {996, {wxToolBar, findControl, 1}},
 {997, {wxToolBar, findToolForPosition, 2}},
 {998, {wxToolBar, getToolSize, 0}},
 {999, {wxToolBar, getToolBitmapSize, 0}},
 {1000, {wxToolBar, getMargins, 0}},
 {1001, {wxToolBar, getToolEnabled, 1}},
 {1002, {wxToolBar, getToolLongHelp, 1}},
 {1003, {wxToolBar, getToolPacking, 0}},
 {1004, {wxToolBar, getToolPos, 1}},
 {1005, {wxToolBar, getToolSeparation, 0}},
 {1006, {wxToolBar, getToolShortHelp, 1}},
 {1007, {wxToolBar, getToolState, 1}},
 {1008, {wxToolBar, insertControl, 2}},
 {1009, {wxToolBar, insertSeparator, 1}},
 {1010, {wxToolBar, insertTool_5, 5}},
 {1011, {wxToolBar, insertTool_2, 2}},
 {1012, {wxToolBar, insertTool_4, 4}},
 {1013, {wxToolBar, realize, 0}},
 {1014, {wxToolBar, removeTool, 1}},
 {1015, {wxToolBar, setMargins, 2}},
 {1016, {wxToolBar, setToolBitmapSize, 1}},
 {1017, {wxToolBar, setToolLongHelp, 2}},
 {1018, {wxToolBar, setToolPacking, 1}},
 {1019, {wxToolBar, setToolShortHelp, 2}},
 {1020, {wxToolBar, setToolSeparation, 1}},
 {1021, {wxToolBar, toggleTool, 2}},
 {1023, {wxStatusBar, new_0, 0}},
 {1024, {wxStatusBar, new_2, 2}},
 {1026, {wxStatusBar, destruct, 0}},
 {1027, {wxStatusBar, create, 2}},
 {1028, {wxStatusBar, getFieldRect, 2}},
 {1029, {wxStatusBar, getFieldsCount, 0}},
 {1030, {wxStatusBar, getStatusText, 1}},
 {1031, {wxStatusBar, popStatusText, 1}},
 {1032, {wxStatusBar, pushStatusText, 2}},
 {1033, {wxStatusBar, setFieldsCount, 2}},
 {1034, {wxStatusBar, setMinHeight, 1}},
 {1035, {wxStatusBar, setStatusText, 2}},
 {1036, {wxStatusBar, setStatusWidths, 2}},
 {1037, {wxStatusBar, setStatusStyles, 2}},
 {1038, {wxBitmap, new_0, 0}},
 {1039, {wxBitmap, new_3, 3}},
 {1040, {wxBitmap, new_4, 4}},
 {1041, {wxBitmap, new_2_0, 2}},
 {1042, {wxBitmap, new_2_1, 2}},
 {1043, {wxBitmap, destruct, 0}},
 {1044, {wxBitmap, convertToImage, 0}},
 {1045, {wxBitmap, copyFromIcon, 1}},
 {1046, {wxBitmap, create, 3}},
 {1047, {wxBitmap, getDepth, 0}},
 {1048, {wxBitmap, getHeight, 0}},
 {1049, {wxBitmap, getPalette, 0}},
 {1050, {wxBitmap, getMask, 0}},
 {1051, {wxBitmap, getWidth, 0}},
 {1052, {wxBitmap, getSubBitmap, 1}},
 {1053, {wxBitmap, loadFile, 2}},
 {1054, {wxBitmap, ok, 0}},
 {1055, {wxBitmap, saveFile, 3}},
 {1056, {wxBitmap, setDepth, 1}},
 {1057, {wxBitmap, setHeight, 1}},
 {1058, {wxBitmap, setMask, 1}},
 {1059, {wxBitmap, setPalette, 1}},
 {1060, {wxBitmap, setWidth, 1}},
 {1061, {wxIcon, new_0, 0}},
 {1062, {wxIcon, new_2, 2}},
 {1063, {wxIcon, new_1, 1}},
 {1064, {wxIcon, copyFromBitmap, 1}},
 {1065, {wxIcon, 'Destroy', undefined}},
 {1066, {wxIconBundle, new_0, 0}},
 {1067, {wxIconBundle, new_2, 2}},
 {1068, {wxIconBundle, new_1_0, 1}},
 {1069, {wxIconBundle, new_1_1, 1}},
 {1070, {wxIconBundle, destruct, 0}},
 {1071, {wxIconBundle, addIcon_2, 2}},
 {1072, {wxIconBundle, addIcon_1, 1}},
 {1073, {wxIconBundle, getIcon_1_1, 1}},
 {1074, {wxIconBundle, getIcon_1_0, 1}},
 {1075, {wxCursor, new_0, 0}},
 {1076, {wxCursor, new_1_0, 1}},
 {1077, {wxCursor, new_1_1, 1}},
 {1078, {wxCursor, new_4, 4}},
 {1079, {wxCursor, destruct, 0}},
 {1080, {wxCursor, ok, 0}},
 {1081, {wxMask, new_0, 0}},
 {1082, {wxMask, new_2_1, 2}},
 {1083, {wxMask, new_2_0, 2}},
 {1084, {wxMask, new_1, 1}},
 {1085, {wxMask, destruct, 0}},
 {1086, {wxMask, create_2_1, 2}},
 {1087, {wxMask, create_2_0, 2}},
 {1088, {wxMask, create_1, 1}},
 {1089, {wxImage, new_0, 0}},
 {1090, {wxImage, new_3_0, 3}},
 {1091, {wxImage, new_4, 4}},
 {1092, {wxImage, new_5, 5}},
 {1093, {wxImage, new_2, 2}},
 {1094, {wxImage, new_3_1, 3}},
 {1095, {wxImage, blur, 1}},
 {1096, {wxImage, blurHorizontal, 1}},
 {1097, {wxImage, blurVertical, 1}},
 {1098, {wxImage, convertAlphaToMask, 1}},
 {1099, {wxImage, convertToGreyscale, 1}},
 {1100, {wxImage, convertToMono, 3}},
 {1101, {wxImage, copy, 0}},
 {1102, {wxImage, create_3, 3}},
 {1103, {wxImage, create_4, 4}},
 {1104, {wxImage, create_5, 5}},
 {1105, {wxImage, 'Destroy', 0}},
 {1106, {wxImage, findFirstUnusedColour, 4}},
 {1107, {wxImage, getImageExtWildcard, 0}},
 {1108, {wxImage, getAlpha_2, 2}},
 {1109, {wxImage, getAlpha_0, 0}},
 {1110, {wxImage, getBlue, 2}},
 {1111, {wxImage, getData, 0}},
 {1112, {wxImage, getGreen, 2}},
 {1113, {wxImage, getImageCount, 2}},
 {1114, {wxImage, getHeight, 0}},
 {1115, {wxImage, getMaskBlue, 0}},
 {1116, {wxImage, getMaskGreen, 0}},
 {1117, {wxImage, getMaskRed, 0}},
 {1118, {wxImage, getOrFindMaskColour, 3}},
 {1119, {wxImage, getPalette, 0}},
 {1120, {wxImage, getRed, 2}},
 {1121, {wxImage, getSubImage, 1}},
 {1122, {wxImage, getWidth, 0}},
 {1123, {wxImage, hasAlpha, 0}},
 {1124, {wxImage, hasMask, 0}},
 {1125, {wxImage, getOption, 1}},
 {1126, {wxImage, getOptionInt, 1}},
 {1127, {wxImage, hasOption, 1}},
 {1128, {wxImage, initAlpha, 0}},
 {1129, {wxImage, initStandardHandlers, 0}},
 {1130, {wxImage, isTransparent, 3}},
 {1131, {wxImage, loadFile_2, 2}},
 {1132, {wxImage, loadFile_3, 3}},
 {1133, {wxImage, ok, 0}},
 {1134, {wxImage, removeHandler, 1}},
 {1135, {wxImage, mirror, 1}},
 {1136, {wxImage, replace, 6}},
 {1137, {wxImage, rescale, 3}},
 {1138, {wxImage, resize, 3}},
 {1139, {wxImage, rotate, 3}},
 {1140, {wxImage, rotateHue, 1}},
 {1141, {wxImage, rotate90, 1}},
 {1142, {wxImage, saveFile_1, 1}},
 {1143, {wxImage, saveFile_2_0, 2}},
 {1144, {wxImage, saveFile_2_1, 2}},
 {1145, {wxImage, scale, 3}},
 {1146, {wxImage, size, 3}},
 {1147, {wxImage, setAlpha_3, 3}},
 {1148, {wxImage, setAlpha_2, 2}},
 {1149, {wxImage, setData_2, 2}},
 {1150, {wxImage, setData_4, 4}},
 {1151, {wxImage, setMask, 1}},
 {1152, {wxImage, setMaskColour, 3}},
 {1153, {wxImage, setMaskFromImage, 4}},
 {1154, {wxImage, setOption_2_1, 2}},
 {1155, {wxImage, setOption_2_0, 2}},
 {1156, {wxImage, setPalette, 1}},
 {1157, {wxImage, setRGB_5, 5}},
 {1158, {wxImage, setRGB_4, 4}},
 {1159, {wxImage, 'Destroy', undefined}},
 {1160, {wxBrush, new_0, 0}},
 {1161, {wxBrush, new_2, 2}},
 {1162, {wxBrush, new_1, 1}},
 {1164, {wxBrush, destruct, 0}},
 {1165, {wxBrush, getColour, 0}},
 {1166, {wxBrush, getStipple, 0}},
 {1167, {wxBrush, getStyle, 0}},
 {1168, {wxBrush, isHatch, 0}},
 {1169, {wxBrush, isOk, 0}},
 {1170, {wxBrush, setColour_1, 1}},
 {1171, {wxBrush, setColour_3, 3}},
 {1172, {wxBrush, setStipple, 1}},
 {1173, {wxBrush, setStyle, 1}},
 {1174, {wxPen, new_0, 0}},
 {1175, {wxPen, new_2, 2}},
 {1176, {wxPen, destruct, 0}},
 {1177, {wxPen, getCap, 0}},
 {1178, {wxPen, getColour, 0}},
 {1179, {wxPen, getJoin, 0}},
 {1180, {wxPen, getStyle, 0}},
 {1181, {wxPen, getWidth, 0}},
 {1182, {wxPen, isOk, 0}},
 {1183, {wxPen, setCap, 1}},
 {1184, {wxPen, setColour_1, 1}},
 {1185, {wxPen, setColour_3, 3}},
 {1186, {wxPen, setJoin, 1}},
 {1187, {wxPen, setStyle, 1}},
 {1188, {wxPen, setWidth, 1}},
 {1189, {wxRegion, new_0, 0}},
 {1190, {wxRegion, new_4, 4}},
 {1191, {wxRegion, new_2, 2}},
 {1192, {wxRegion, new_1_1, 1}},
 {1194, {wxRegion, new_1_0, 1}},
 {1196, {wxRegion, destruct, 0}},
 {1197, {wxRegion, clear, 0}},
 {1198, {wxRegion, contains_2, 2}},
 {1199, {wxRegion, contains_1_0, 1}},
 {1200, {wxRegion, contains_4, 4}},
 {1201, {wxRegion, contains_1_1, 1}},
 {1202, {wxRegion, convertToBitmap, 0}},
 {1203, {wxRegion, getBox, 0}},
 {1204, {wxRegion, intersect_4, 4}},
 {1205, {wxRegion, intersect_1_1, 1}},
 {1206, {wxRegion, intersect_1_0, 1}},
 {1207, {wxRegion, isEmpty, 0}},
 {1208, {wxRegion, subtract_4, 4}},
 {1209, {wxRegion, subtract_1_1, 1}},
 {1210, {wxRegion, subtract_1_0, 1}},
 {1211, {wxRegion, offset_2, 2}},
 {1212, {wxRegion, offset_1, 1}},
 {1213, {wxRegion, union_4, 4}},
 {1214, {wxRegion, union_1_2, 1}},
 {1215, {wxRegion, union_1_1, 1}},
 {1216, {wxRegion, union_1_0, 1}},
 {1217, {wxRegion, union_3, 3}},
 {1218, {wxRegion, xor_4, 4}},
 {1219, {wxRegion, xor_1_1, 1}},
 {1220, {wxRegion, xor_1_0, 1}},
 {1221, {wxAcceleratorTable, new_0, 0}},
 {1222, {wxAcceleratorTable, new_2, 2}},
 {1223, {wxAcceleratorTable, destruct, 0}},
 {1224, {wxAcceleratorTable, ok, 0}},
 {1225, {wxAcceleratorEntry, new_1_0, 1}},
 {1226, {wxAcceleratorEntry, new_1_1, 1}},
 {1227, {wxAcceleratorEntry, getCommand, 0}},
 {1228, {wxAcceleratorEntry, getFlags, 0}},
 {1229, {wxAcceleratorEntry, getKeyCode, 0}},
 {1230, {wxAcceleratorEntry, set, 4}},
 {1231, {wxAcceleratorEntry, 'Destroy', undefined}},
 {1236, {wxCaret, new_3, 3}},
 {1237, {wxCaret, new_2, 2}},
 {1239, {wxCaret, destruct, 0}},
 {1240, {wxCaret, create_3, 3}},
 {1241, {wxCaret, create_2, 2}},
 {1242, {wxCaret, getBlinkTime, 0}},
 {1244, {wxCaret, getPosition, 0}},
 {1246, {wxCaret, getSize, 0}},
 {1247, {wxCaret, getWindow, 0}},
 {1248, {wxCaret, hide, 0}},
 {1249, {wxCaret, isOk, 0}},
 {1250, {wxCaret, isVisible, 0}},
 {1251, {wxCaret, move_2, 2}},
 {1252, {wxCaret, move_1, 1}},
 {1253, {wxCaret, setBlinkTime, 1}},
 {1254, {wxCaret, setSize_2, 2}},
 {1255, {wxCaret, setSize_1, 1}},
 {1256, {wxCaret, show, 1}},
 {1257, {wxSizer, add_2_1, 2}},
 {1258, {wxSizer, add_2_0, 2}},
 {1259, {wxSizer, add_3, 3}},
 {1260, {wxSizer, add_2_3, 2}},
 {1261, {wxSizer, add_2_2, 2}},
 {1262, {wxSizer, addSpacer, 1}},
 {1263, {wxSizer, addStretchSpacer, 1}},
 {1264, {wxSizer, calcMin, 0}},
 {1265, {wxSizer, clear, 1}},
 {1266, {wxSizer, detach_1_2, 1}},
 {1267, {wxSizer, detach_1_1, 1}},
 {1268, {wxSizer, detach_1_0, 1}},
 {1269, {wxSizer, fit, 1}},
 {1270, {wxSizer, fitInside, 1}},
 {1271, {wxSizer, getChildren, 0}},
 {1272, {wxSizer, getItem_2_1, 2}},
 {1273, {wxSizer, getItem_2_0, 2}},
 {1274, {wxSizer, getItem_1, 1}},
 {1275, {wxSizer, getSize, 0}},
 {1276, {wxSizer, getPosition, 0}},
 {1277, {wxSizer, getMinSize, 0}},
 {1278, {wxSizer, hide_2_0, 2}},
 {1279, {wxSizer, hide_2_1, 2}},
 {1280, {wxSizer, hide_1, 1}},
 {1281, {wxSizer, insert_3_1, 3}},
 {1282, {wxSizer, insert_3_0, 3}},
 {1283, {wxSizer, insert_4, 4}},
 {1284, {wxSizer, insert_3_3, 3}},
 {1285, {wxSizer, insert_3_2, 3}},
 {1286, {wxSizer, insert_2, 2}},
 {1287, {wxSizer, insertSpacer, 2}},
 {1288, {wxSizer, insertStretchSpacer, 2}},
 {1289, {wxSizer, isShown_1_2, 1}},
 {1290, {wxSizer, isShown_1_1, 1}},
 {1291, {wxSizer, isShown_1_0, 1}},
 {1292, {wxSizer, layout, 0}},
 {1293, {wxSizer, prepend_2_1, 2}},
 {1294, {wxSizer, prepend_2_0, 2}},
 {1295, {wxSizer, prepend_3, 3}},
 {1296, {wxSizer, prepend_2_3, 2}},
 {1297, {wxSizer, prepend_2_2, 2}},
 {1298, {wxSizer, prepend_1, 1}},
 {1299, {wxSizer, prependSpacer, 1}},
 {1300, {wxSizer, prependStretchSpacer, 1}},
 {1301, {wxSizer, recalcSizes, 0}},
 {1302, {wxSizer, remove_1_1, 1}},
 {1303, {wxSizer, remove_1_0, 1}},
 {1304, {wxSizer, replace_3_1, 3}},
 {1305, {wxSizer, replace_3_0, 3}},
 {1306, {wxSizer, replace_2, 2}},
 {1307, {wxSizer, setDimension, 4}},
 {1308, {wxSizer, setMinSize_2, 2}},
 {1309, {wxSizer, setMinSize_1, 1}},
 {1310, {wxSizer, setItemMinSize_3_2, 3}},
 {1311, {wxSizer, setItemMinSize_2_2, 2}},
 {1312, {wxSizer, setItemMinSize_3_1, 3}},
 {1313, {wxSizer, setItemMinSize_2_1, 2}},
 {1314, {wxSizer, setItemMinSize_3_0, 3}},
 {1315, {wxSizer, setItemMinSize_2_0, 2}},
 {1316, {wxSizer, setSizeHints, 1}},
 {1317, {wxSizer, setVirtualSizeHints, 1}},
 {1318, {wxSizer, show_2_2, 2}},
 {1319, {wxSizer, show_2_1, 2}},
 {1320, {wxSizer, show_2_0, 2}},
 {1321, {wxSizer, show_1, 1}},
 {1322, {wxSizerFlags, new, 1}},
 {1323, {wxSizerFlags, align, 1}},
 {1324, {wxSizerFlags, border_2, 2}},
 {1325, {wxSizerFlags, border_1, 1}},
 {1326, {wxSizerFlags, center, 0}},
 {1327, {wxSizerFlags, centre, 0}},
 {1328, {wxSizerFlags, expand, 0}},
 {1329, {wxSizerFlags, left, 0}},
 {1330, {wxSizerFlags, proportion, 1}},
 {1331, {wxSizerFlags, right, 0}},
 {1332, {wxSizerFlags, 'Destroy', undefined}},
 {1333, {wxSizerItem, new_5_1, 5}},
 {1334, {wxSizerItem, new_2_1, 2}},
 {1335, {wxSizerItem, new_5_0, 5}},
 {1336, {wxSizerItem, new_2_0, 2}},
 {1337, {wxSizerItem, new_6, 6}},
 {1338, {wxSizerItem, new_3, 3}},
 {1339, {wxSizerItem, new_0, 0}},
 {1340, {wxSizerItem, destruct, 0}},
 {1341, {wxSizerItem, calcMin, 0}},
 {1342, {wxSizerItem, deleteWindows, 0}},
 {1343, {wxSizerItem, detachSizer, 0}},
 {1344, {wxSizerItem, getBorder, 0}},
 {1345, {wxSizerItem, getFlag, 0}},
 {1346, {wxSizerItem, getMinSize, 0}},
 {1347, {wxSizerItem, getPosition, 0}},
 {1348, {wxSizerItem, getProportion, 0}},
 {1349, {wxSizerItem, getRatio, 0}},
 {1350, {wxSizerItem, getRect, 0}},
 {1351, {wxSizerItem, getSize, 0}},
 {1352, {wxSizerItem, getSizer, 0}},
 {1353, {wxSizerItem, getSpacer, 0}},
 {1354, {wxSizerItem, getUserData, 0}},
 {1355, {wxSizerItem, getWindow, 0}},
 {1356, {wxSizerItem, isSizer, 0}},
 {1357, {wxSizerItem, isShown, 0}},
 {1358, {wxSizerItem, isSpacer, 0}},
 {1359, {wxSizerItem, isWindow, 0}},
 {1360, {wxSizerItem, setBorder, 1}},
 {1361, {wxSizerItem, setDimension, 2}},
 {1362, {wxSizerItem, setFlag, 1}},
 {1363, {wxSizerItem, setInitSize, 2}},
 {1364, {wxSizerItem, setMinSize_1, 1}},
 {1365, {wxSizerItem, setMinSize_2, 2}},
 {1366, {wxSizerItem, setProportion, 1}},
 {1367, {wxSizerItem, setRatio_2, 2}},
 {1368, {wxSizerItem, setRatio_1_1, 1}},
 {1369, {wxSizerItem, setRatio_1_0, 1}},
 {1370, {wxSizerItem, setSizer, 1}},
 {1371, {wxSizerItem, setSpacer_1, 1}},
 {1372, {wxSizerItem, setSpacer_2, 2}},
 {1373, {wxSizerItem, setWindow, 1}},
 {1374, {wxSizerItem, show, 1}},
 {1375, {wxBoxSizer, new, 1}},
 {1376, {wxBoxSizer, getOrientation, 0}},
 {1377, {wxBoxSizer, 'Destroy', undefined}},
 {1378, {wxStaticBoxSizer, new_2, 2}},
 {1379, {wxStaticBoxSizer, new_3, 3}},
 {1380, {wxStaticBoxSizer, getStaticBox, 0}},
 {1381, {wxStaticBoxSizer, 'Destroy', undefined}},
 {1382, {wxGridSizer, new_4, 4}},
 {1383, {wxGridSizer, new_2, 2}},
 {1384, {wxGridSizer, getCols, 0}},
 {1385, {wxGridSizer, getHGap, 0}},
 {1386, {wxGridSizer, getRows, 0}},
 {1387, {wxGridSizer, getVGap, 0}},
 {1388, {wxGridSizer, setCols, 1}},
 {1389, {wxGridSizer, setHGap, 1}},
 {1390, {wxGridSizer, setRows, 1}},
 {1391, {wxGridSizer, setVGap, 1}},
 {1392, {wxGridSizer, 'Destroy', undefined}},
 {1393, {wxFlexGridSizer, new_4, 4}},
 {1394, {wxFlexGridSizer, new_2, 2}},
 {1395, {wxFlexGridSizer, addGrowableCol, 2}},
 {1396, {wxFlexGridSizer, addGrowableRow, 2}},
 {1397, {wxFlexGridSizer, getFlexibleDirection, 0}},
 {1398, {wxFlexGridSizer, getNonFlexibleGrowMode, 0}},
 {1399, {wxFlexGridSizer, removeGrowableCol, 1}},
 {1400, {wxFlexGridSizer, removeGrowableRow, 1}},
 {1401, {wxFlexGridSizer, setFlexibleDirection, 1}},
 {1402, {wxFlexGridSizer, setNonFlexibleGrowMode, 1}},
 {1403, {wxFlexGridSizer, 'Destroy', undefined}},
 {1404, {wxGridBagSizer, new, 1}},
 {1405, {wxGridBagSizer, add_3_2, 3}},
 {1406, {wxGridBagSizer, add_3_1, 3}},
 {1407, {wxGridBagSizer, add_4, 4}},
 {1408, {wxGridBagSizer, add_1_0, 1}},
 {1409, {wxGridBagSizer, add_2_1, 2}},
 {1410, {wxGridBagSizer, add_2_0, 2}},
 {1411, {wxGridBagSizer, add_3_0, 3}},
 {1412, {wxGridBagSizer, add_1_1, 1}},
 {1413, {wxGridBagSizer, calcMin, 0}},
 {1414, {wxGridBagSizer, checkForIntersection_2, 2}},
 {1415, {wxGridBagSizer, checkForIntersection_3, 3}},
 {1416, {wxGridBagSizer, findItem_1_1, 1}},
 {1417, {wxGridBagSizer, findItem_1_0, 1}},
 {1418, {wxGridBagSizer, findItemAtPoint, 1}},
 {1419, {wxGridBagSizer, findItemAtPosition, 1}},
 {1420, {wxGridBagSizer, findItemWithData, 1}},
 {1421, {wxGridBagSizer, getCellSize, 2}},
 {1422, {wxGridBagSizer, getEmptyCellSize, 0}},
 {1423, {wxGridBagSizer, getItemPosition_1_2, 1}},
 {1424, {wxGridBagSizer, getItemPosition_1_1, 1}},
 {1425, {wxGridBagSizer, getItemPosition_1_0, 1}},
 {1426, {wxGridBagSizer, getItemSpan_1_2, 1}},
 {1427, {wxGridBagSizer, getItemSpan_1_1, 1}},
 {1428, {wxGridBagSizer, getItemSpan_1_0, 1}},
 {1429, {wxGridBagSizer, setEmptyCellSize, 1}},
 {1430, {wxGridBagSizer, setItemPosition_2_2, 2}},
 {1431, {wxGridBagSizer, setItemPosition_2_1, 2}},
 {1432, {wxGridBagSizer, setItemPosition_2_0, 2}},
 {1433, {wxGridBagSizer, setItemSpan_2_2, 2}},
 {1434, {wxGridBagSizer, setItemSpan_2_1, 2}},
 {1435, {wxGridBagSizer, setItemSpan_2_0, 2}},
 {1436, {wxGridBagSizer, 'Destroy', undefined}},
 {1437, {wxStdDialogButtonSizer, new, 0}},
 {1438, {wxStdDialogButtonSizer, addButton, 1}},
 {1439, {wxStdDialogButtonSizer, realize, 0}},
 {1440, {wxStdDialogButtonSizer, setAffirmativeButton, 1}},
 {1441, {wxStdDialogButtonSizer, setCancelButton, 1}},
 {1442, {wxStdDialogButtonSizer, setNegativeButton, 1}},
 {1443, {wxStdDialogButtonSizer, 'Destroy', undefined}},
 {1444, {wxFont, new_0, 0}},
 {1445, {wxFont, new_1, 1}},
 {1446, {wxFont, new_5, 5}},
 {1448, {wxFont, destruct, 0}},
 {1449, {wxFont, isFixedWidth, 0}},
 {1450, {wxFont, getDefaultEncoding, 0}},
 {1451, {wxFont, getFaceName, 0}},
 {1452, {wxFont, getFamily, 0}},
 {1453, {wxFont, getNativeFontInfoDesc, 0}},
 {1454, {wxFont, getNativeFontInfoUserDesc, 0}},
 {1455, {wxFont, getPointSize, 0}},
 {1456, {wxFont, getStyle, 0}},
 {1457, {wxFont, getUnderlined, 0}},
 {1458, {wxFont, getWeight, 0}},
 {1459, {wxFont, ok, 0}},
 {1460, {wxFont, setDefaultEncoding, 1}},
 {1461, {wxFont, setFaceName, 1}},
 {1462, {wxFont, setFamily, 1}},
 {1463, {wxFont, setPointSize, 1}},
 {1464, {wxFont, setStyle, 1}},
 {1465, {wxFont, setUnderlined, 1}},
 {1466, {wxFont, setWeight, 1}},
 {1467, {wxToolTip, enable, 1}},
 {1468, {wxToolTip, setDelay, 1}},
 {1469, {wxToolTip, new, 1}},
 {1470, {wxToolTip, setTip, 1}},
 {1471, {wxToolTip, getTip, 0}},
 {1472, {wxToolTip, getWindow, 0}},
 {1473, {wxToolTip, 'Destroy', undefined}},
 {1475, {wxButton, new_3, 3}},
 {1476, {wxButton, new_0, 0}},
 {1477, {wxButton, destruct, 0}},
 {1478, {wxButton, create, 3}},
 {1479, {wxButton, getDefaultSize, 0}},
 {1480, {wxButton, setDefault, 0}},
 {1481, {wxButton, setLabel, 1}},
 {1483, {wxBitmapButton, new_4, 4}},
 {1484, {wxBitmapButton, new_0, 0}},
 {1485, {wxBitmapButton, create, 4}},
 {1486, {wxBitmapButton, getBitmapDisabled, 0}},
 {1488, {wxBitmapButton, getBitmapFocus, 0}},
 {1490, {wxBitmapButton, getBitmapLabel, 0}},
 {1492, {wxBitmapButton, getBitmapSelected, 0}},
 {1494, {wxBitmapButton, setBitmapDisabled, 1}},
 {1495, {wxBitmapButton, setBitmapFocus, 1}},
 {1496, {wxBitmapButton, setBitmapLabel, 1}},
 {1497, {wxBitmapButton, setBitmapSelected, 1}},
 {1498, {wxBitmapButton, 'Destroy', undefined}},
 {1499, {wxToggleButton, new_0, 0}},
 {1500, {wxToggleButton, new_4, 4}},
 {1501, {wxToggleButton, create, 4}},
 {1502, {wxToggleButton, getValue, 0}},
 {1503, {wxToggleButton, setValue, 1}},
 {1504, {wxToggleButton, 'Destroy', undefined}},
 {1505, {wxCalendarCtrl, new_0, 0}},
 {1506, {wxCalendarCtrl, new_3, 3}},
 {1507, {wxCalendarCtrl, create, 3}},
 {1508, {wxCalendarCtrl, destruct, 0}},
 {1509, {wxCalendarCtrl, setDate, 1}},
 {1510, {wxCalendarCtrl, getDate, 0}},
 {1511, {wxCalendarCtrl, enableYearChange, 1}},
 {1512, {wxCalendarCtrl, enableMonthChange, 1}},
 {1513, {wxCalendarCtrl, enableHolidayDisplay, 1}},
 {1514, {wxCalendarCtrl, setHeaderColours, 2}},
 {1515, {wxCalendarCtrl, getHeaderColourFg, 0}},
 {1516, {wxCalendarCtrl, getHeaderColourBg, 0}},
 {1517, {wxCalendarCtrl, setHighlightColours, 2}},
 {1518, {wxCalendarCtrl, getHighlightColourFg, 0}},
 {1519, {wxCalendarCtrl, getHighlightColourBg, 0}},
 {1520, {wxCalendarCtrl, setHolidayColours, 2}},
 {1521, {wxCalendarCtrl, getHolidayColourFg, 0}},
 {1522, {wxCalendarCtrl, getHolidayColourBg, 0}},
 {1523, {wxCalendarCtrl, getAttr, 1}},
 {1524, {wxCalendarCtrl, setAttr, 2}},
 {1525, {wxCalendarCtrl, setHoliday, 1}},
 {1526, {wxCalendarCtrl, resetAttr, 1}},
 {1527, {wxCalendarCtrl, hitTest, 2}},
 {1528, {wxCalendarDateAttr, new_0, 0}},
 {1529, {wxCalendarDateAttr, new_2_1, 2}},
 {1530, {wxCalendarDateAttr, new_2_0, 2}},
 {1531, {wxCalendarDateAttr, setTextColour, 1}},
 {1532, {wxCalendarDateAttr, setBackgroundColour, 1}},
 {1533, {wxCalendarDateAttr, setBorderColour, 1}},
 {1534, {wxCalendarDateAttr, setFont, 1}},
 {1535, {wxCalendarDateAttr, setBorder, 1}},
 {1536, {wxCalendarDateAttr, setHoliday, 1}},
 {1537, {wxCalendarDateAttr, hasTextColour, 0}},
 {1538, {wxCalendarDateAttr, hasBackgroundColour, 0}},
 {1539, {wxCalendarDateAttr, hasBorderColour, 0}},
 {1540, {wxCalendarDateAttr, hasFont, 0}},
 {1541, {wxCalendarDateAttr, hasBorder, 0}},
 {1542, {wxCalendarDateAttr, isHoliday, 0}},
 {1543, {wxCalendarDateAttr, getTextColour, 0}},
 {1544, {wxCalendarDateAttr, getBackgroundColour, 0}},
 {1545, {wxCalendarDateAttr, getBorderColour, 0}},
 {1546, {wxCalendarDateAttr, getFont, 0}},
 {1547, {wxCalendarDateAttr, getBorder, 0}},
 {1548, {wxCalendarDateAttr, 'Destroy', undefined}},
 {1550, {wxCheckBox, new_4, 4}},
 {1551, {wxCheckBox, new_0, 0}},
 {1552, {wxCheckBox, create, 4}},
 {1553, {wxCheckBox, getValue, 0}},
 {1554, {wxCheckBox, get3StateValue, 0}},
 {1555, {wxCheckBox, is3rdStateAllowedForUser, 0}},
 {1556, {wxCheckBox, is3State, 0}},
 {1557, {wxCheckBox, isChecked, 0}},
 {1558, {wxCheckBox, setValue, 1}},
 {1559, {wxCheckBox, set3StateValue, 1}},
 {1560, {wxCheckBox, 'Destroy', undefined}},
 {1561, {wxCheckListBox, new_0, 0}},
 {1563, {wxCheckListBox, new_3, 3}},
 {1564, {wxCheckListBox, check, 2}},
 {1565, {wxCheckListBox, isChecked, 1}},
 {1566, {wxCheckListBox, 'Destroy', undefined}},
 {1569, {wxChoice, new_3, 3}},
 {1570, {wxChoice, new_0, 0}},
 {1572, {wxChoice, destruct, 0}},
 {1574, {wxChoice, create, 6}},
 {1575, {wxChoice, delete, 1}},
 {1576, {wxChoice, getColumns, 0}},
 {1577, {wxChoice, setColumns, 1}},
 {1578, {wxComboBox, new_0, 0}},
 {1580, {wxComboBox, new_3, 3}},
 {1581, {wxComboBox, destruct, 0}},
 {1583, {wxComboBox, create, 7}},
 {1584, {wxComboBox, canCopy, 0}},
 {1585, {wxComboBox, canCut, 0}},
 {1586, {wxComboBox, canPaste, 0}},
 {1587, {wxComboBox, canRedo, 0}},
 {1588, {wxComboBox, canUndo, 0}},
 {1589, {wxComboBox, copy, 0}},
 {1590, {wxComboBox, cut, 0}},
 {1591, {wxComboBox, getInsertionPoint, 0}},
 {1592, {wxComboBox, getLastPosition, 0}},
 {1593, {wxComboBox, getValue, 0}},
 {1594, {wxComboBox, paste, 0}},
 {1595, {wxComboBox, redo, 0}},
 {1596, {wxComboBox, replace, 3}},
 {1597, {wxComboBox, remove, 2}},
 {1598, {wxComboBox, setInsertionPoint, 1}},
 {1599, {wxComboBox, setInsertionPointEnd, 0}},
 {1600, {wxComboBox, setSelection_1, 1}},
 {1601, {wxComboBox, setSelection_2, 2}},
 {1602, {wxComboBox, setValue, 1}},
 {1603, {wxComboBox, undo, 0}},
 {1604, {wxGauge, new_0, 0}},
 {1605, {wxGauge, new_4, 4}},
 {1606, {wxGauge, create, 4}},
 {1607, {wxGauge, getRange, 0}},
 {1608, {wxGauge, getValue, 0}},
 {1609, {wxGauge, isVertical, 0}},
 {1610, {wxGauge, setRange, 1}},
 {1611, {wxGauge, setValue, 1}},
 {1612, {wxGauge, pulse, 0}},
 {1613, {wxGauge, 'Destroy', undefined}},
 {1614, {wxGenericDirCtrl, new_0, 0}},
 {1615, {wxGenericDirCtrl, new_2, 2}},
 {1616, {wxGenericDirCtrl, destruct, 0}},
 {1617, {wxGenericDirCtrl, create, 2}},
 {1618, {wxGenericDirCtrl, init, 0}},
 {1619, {wxGenericDirCtrl, collapseTree, 0}},
 {1620, {wxGenericDirCtrl, expandPath, 1}},
 {1621, {wxGenericDirCtrl, getDefaultPath, 0}},
 {1622, {wxGenericDirCtrl, getPath, 0}},
 {1623, {wxGenericDirCtrl, getFilePath, 0}},
 {1624, {wxGenericDirCtrl, getFilter, 0}},
 {1625, {wxGenericDirCtrl, getFilterIndex, 0}},
 {1626, {wxGenericDirCtrl, getRootId, 0}},
 {1627, {wxGenericDirCtrl, getTreeCtrl, 0}},
 {1628, {wxGenericDirCtrl, reCreateTree, 0}},
 {1629, {wxGenericDirCtrl, setDefaultPath, 1}},
 {1630, {wxGenericDirCtrl, setFilter, 1}},
 {1631, {wxGenericDirCtrl, setFilterIndex, 1}},
 {1632, {wxGenericDirCtrl, setPath, 1}},
 {1634, {wxStaticBox, new_4, 4}},
 {1635, {wxStaticBox, new_0, 0}},
 {1636, {wxStaticBox, create, 4}},
 {1637, {wxStaticBox, 'Destroy', undefined}},
 {1639, {wxStaticLine, new_2, 2}},
 {1640, {wxStaticLine, new_0, 0}},
 {1641, {wxStaticLine, create, 2}},
 {1642, {wxStaticLine, isVertical, 0}},
 {1643, {wxStaticLine, getDefaultSize, 0}},
 {1644, {wxStaticLine, 'Destroy', undefined}},
 {1647, {wxListBox, new_3, 3}},
 {1648, {wxListBox, new_0, 0}},
 {1650, {wxListBox, destruct, 0}},
 {1652, {wxListBox, create, 6}},
 {1653, {wxListBox, deselect, 1}},
 {1654, {wxListBox, getSelections, 1}},
 {1655, {wxListBox, insertItems, 2}},
 {1656, {wxListBox, isSelected, 1}},
 {1657, {wxListBox, set, 1}},
 {1658, {wxListBox, hitTest, 1}},
 {1659, {wxListBox, setFirstItem_1_0, 1}},
 {1660, {wxListBox, setFirstItem_1_1, 1}},
 {1661, {wxListCtrl, new_0, 0}},
 {1662, {wxListCtrl, new_2, 2}},
 {1663, {wxListCtrl, arrange, 1}},
 {1664, {wxListCtrl, assignImageList, 2}},
 {1665, {wxListCtrl, clearAll, 0}},
 {1666, {wxListCtrl, create, 2}},
 {1667, {wxListCtrl, deleteAllItems, 0}},
 {1668, {wxListCtrl, deleteColumn, 1}},
 {1669, {wxListCtrl, deleteItem, 1}},
 {1670, {wxListCtrl, editLabel, 1}},
 {1671, {wxListCtrl, ensureVisible, 1}},
 {1672, {wxListCtrl, findItem_3_0, 3}},
 {1673, {wxListCtrl, findItem_3_1, 3}},
 {1674, {wxListCtrl, getColumn, 2}},
 {1675, {wxListCtrl, getColumnCount, 0}},
 {1676, {wxListCtrl, getColumnWidth, 1}},
 {1677, {wxListCtrl, getCountPerPage, 0}},
 {1678, {wxListCtrl, getEditControl, 0}},
 {1679, {wxListCtrl, getImageList, 1}},
 {1680, {wxListCtrl, getItem, 1}},
 {1681, {wxListCtrl, getItemBackgroundColour, 1}},
 {1682, {wxListCtrl, getItemCount, 0}},
 {1683, {wxListCtrl, getItemData, 1}},
 {1684, {wxListCtrl, getItemFont, 1}},
 {1685, {wxListCtrl, getItemPosition, 2}},
 {1686, {wxListCtrl, getItemRect, 3}},
 {1687, {wxListCtrl, getItemSpacing, 0}},
 {1688, {wxListCtrl, getItemState, 2}},
 {1689, {wxListCtrl, getItemText, 1}},
 {1690, {wxListCtrl, getItemTextColour, 1}},
 {1691, {wxListCtrl, getNextItem, 2}},
 {1692, {wxListCtrl, getSelectedItemCount, 0}},
 {1693, {wxListCtrl, getTextColour, 0}},
 {1694, {wxListCtrl, getTopItem, 0}},
 {1695, {wxListCtrl, getViewRect, 0}},
 {1696, {wxListCtrl, hitTest, 3}},
 {1697, {wxListCtrl, insertColumn_2, 2}},
 {1698, {wxListCtrl, insertColumn_3, 3}},
 {1699, {wxListCtrl, insertItem_1, 1}},
 {1700, {wxListCtrl, insertItem_2_1, 2}},
 {1701, {wxListCtrl, insertItem_2_0, 2}},
 {1702, {wxListCtrl, insertItem_3, 3}},
 {1703, {wxListCtrl, refreshItem, 1}},
 {1704, {wxListCtrl, refreshItems, 2}},
 {1705, {wxListCtrl, scrollList, 2}},
 {1706, {wxListCtrl, setBackgroundColour, 1}},
 {1707, {wxListCtrl, setColumn, 2}},
 {1708, {wxListCtrl, setColumnWidth, 2}},
 {1709, {wxListCtrl, setImageList, 2}},
 {1710, {wxListCtrl, setItem_1, 1}},
 {1711, {wxListCtrl, setItem_4, 4}},
 {1712, {wxListCtrl, setItemBackgroundColour, 2}},
 {1713, {wxListCtrl, setItemCount, 1}},
 {1714, {wxListCtrl, setItemData, 2}},
 {1715, {wxListCtrl, setItemFont, 2}},
 {1716, {wxListCtrl, setItemImage, 3}},
 {1717, {wxListCtrl, setItemColumnImage, 3}},
 {1718, {wxListCtrl, setItemPosition, 2}},
 {1719, {wxListCtrl, setItemState, 3}},
 {1720, {wxListCtrl, setItemText, 2}},
 {1721, {wxListCtrl, setItemTextColour, 2}},
 {1722, {wxListCtrl, setSingleStyle, 2}},
 {1723, {wxListCtrl, setTextColour, 1}},
 {1724, {wxListCtrl, setWindowStyleFlag, 1}},
 {1725, {wxListCtrl, sortItems, 2}},
 {1726, {wxListCtrl, 'Destroy', undefined}},
 {1727, {wxListView, clearColumnImage, 1}},
 {1728, {wxListView, focus, 1}},
 {1729, {wxListView, getFirstSelected, 0}},
 {1730, {wxListView, getFocusedItem, 0}},
 {1731, {wxListView, getNextSelected, 1}},
 {1732, {wxListView, isSelected, 1}},
 {1733, {wxListView, select, 2}},
 {1734, {wxListView, setColumnImage, 2}},
 {1735, {wxListItem, new_0, 0}},
 {1736, {wxListItem, new_1, 1}},
 {1737, {wxListItem, destruct, 0}},
 {1738, {wxListItem, clear, 0}},
 {1739, {wxListItem, getAlign, 0}},
 {1740, {wxListItem, getBackgroundColour, 0}},
 {1741, {wxListItem, getColumn, 0}},
 {1742, {wxListItem, getFont, 0}},
 {1743, {wxListItem, getId, 0}},
 {1744, {wxListItem, getImage, 0}},
 {1745, {wxListItem, getMask, 0}},
 {1746, {wxListItem, getState, 0}},
 {1747, {wxListItem, getText, 0}},
 {1748, {wxListItem, getTextColour, 0}},
 {1749, {wxListItem, getWidth, 0}},
 {1750, {wxListItem, setAlign, 1}},
 {1751, {wxListItem, setBackgroundColour, 1}},
 {1752, {wxListItem, setColumn, 1}},
 {1753, {wxListItem, setFont, 1}},
 {1754, {wxListItem, setId, 1}},
 {1755, {wxListItem, setImage, 1}},
 {1756, {wxListItem, setMask, 1}},
 {1757, {wxListItem, setState, 1}},
 {1758, {wxListItem, setStateMask, 1}},
 {1759, {wxListItem, setText, 1}},
 {1760, {wxListItem, setTextColour, 1}},
 {1761, {wxListItem, setWidth, 1}},
 {1762, {wxListItemAttr, new_0, 0}},
 {1763, {wxListItemAttr, new_3, 3}},
 {1764, {wxListItemAttr, getBackgroundColour, 0}},
 {1765, {wxListItemAttr, getFont, 0}},
 {1766, {wxListItemAttr, getTextColour, 0}},
 {1767, {wxListItemAttr, hasBackgroundColour, 0}},
 {1768, {wxListItemAttr, hasFont, 0}},
 {1769, {wxListItemAttr, hasTextColour, 0}},
 {1770, {wxListItemAttr, setBackgroundColour, 1}},
 {1771, {wxListItemAttr, setFont, 1}},
 {1772, {wxListItemAttr, setTextColour, 1}},
 {1773, {wxListItemAttr, 'Destroy', undefined}},
 {1774, {wxImageList, new_0, 0}},
 {1775, {wxImageList, new_3, 3}},
 {1776, {wxImageList, add_1, 1}},
 {1777, {wxImageList, add_2_0, 2}},
 {1778, {wxImageList, add_2_1, 2}},
 {1779, {wxImageList, create, 3}},
 {1781, {wxImageList, draw, 5}},
 {1782, {wxImageList, getBitmap, 1}},
 {1783, {wxImageList, getIcon, 1}},
 {1784, {wxImageList, getImageCount, 0}},
 {1785, {wxImageList, getSize, 3}},
 {1786, {wxImageList, remove, 1}},
 {1787, {wxImageList, removeAll, 0}},
 {1788, {wxImageList, replace_2, 2}},
 {1789, {wxImageList, replace_3, 3}},
 {1790, {wxImageList, 'Destroy', undefined}},
 {1791, {wxTextAttr, new_0, 0}},
 {1792, {wxTextAttr, new_2, 2}},
 {1793, {wxTextAttr, getAlignment, 0}},
 {1794, {wxTextAttr, getBackgroundColour, 0}},
 {1795, {wxTextAttr, getFont, 0}},
 {1796, {wxTextAttr, getLeftIndent, 0}},
 {1797, {wxTextAttr, getLeftSubIndent, 0}},
 {1798, {wxTextAttr, getRightIndent, 0}},
 {1799, {wxTextAttr, getTabs, 0}},
 {1800, {wxTextAttr, getTextColour, 0}},
 {1801, {wxTextAttr, hasBackgroundColour, 0}},
 {1802, {wxTextAttr, hasFont, 0}},
 {1803, {wxTextAttr, hasTextColour, 0}},
 {1804, {wxTextAttr, getFlags, 0}},
 {1805, {wxTextAttr, isDefault, 0}},
 {1806, {wxTextAttr, setAlignment, 1}},
 {1807, {wxTextAttr, setBackgroundColour, 1}},
 {1808, {wxTextAttr, setFlags, 1}},
 {1809, {wxTextAttr, setFont, 2}},
 {1810, {wxTextAttr, setLeftIndent, 2}},
 {1811, {wxTextAttr, setRightIndent, 1}},
 {1812, {wxTextAttr, setTabs, 1}},
 {1813, {wxTextAttr, setTextColour, 1}},
 {1814, {wxTextAttr, 'Destroy', undefined}},
 {1816, {wxTextCtrl, new_3, 3}},
 {1817, {wxTextCtrl, new_0, 0}},
 {1819, {wxTextCtrl, destruct, 0}},
 {1820, {wxTextCtrl, appendText, 1}},
 {1821, {wxTextCtrl, canCopy, 0}},
 {1822, {wxTextCtrl, canCut, 0}},
 {1823, {wxTextCtrl, canPaste, 0}},
 {1824, {wxTextCtrl, canRedo, 0}},
 {1825, {wxTextCtrl, canUndo, 0}},
 {1826, {wxTextCtrl, clear, 0}},
 {1827, {wxTextCtrl, copy, 0}},
 {1828, {wxTextCtrl, create, 3}},
 {1829, {wxTextCtrl, cut, 0}},
 {1830, {wxTextCtrl, discardEdits, 0}},
 {1831, {wxTextCtrl, changeValue, 1}},
 {1832, {wxTextCtrl, emulateKeyPress, 1}},
 {1833, {wxTextCtrl, getDefaultStyle, 0}},
 {1834, {wxTextCtrl, getInsertionPoint, 0}},
 {1835, {wxTextCtrl, getLastPosition, 0}},
 {1836, {wxTextCtrl, getLineLength, 1}},
 {1837, {wxTextCtrl, getLineText, 1}},
 {1838, {wxTextCtrl, getNumberOfLines, 0}},
 {1839, {wxTextCtrl, getRange, 2}},
 {1840, {wxTextCtrl, getSelection, 2}},
 {1841, {wxTextCtrl, getStringSelection, 0}},
 {1842, {wxTextCtrl, getStyle, 2}},
 {1843, {wxTextCtrl, getValue, 0}},
 {1844, {wxTextCtrl, isEditable, 0}},
 {1845, {wxTextCtrl, isModified, 0}},
 {1846, {wxTextCtrl, isMultiLine, 0}},
 {1847, {wxTextCtrl, isSingleLine, 0}},
 {1848, {wxTextCtrl, loadFile, 2}},
 {1849, {wxTextCtrl, markDirty, 0}},
 {1850, {wxTextCtrl, paste, 0}},
 {1851, {wxTextCtrl, positionToXY, 3}},
 {1852, {wxTextCtrl, redo, 0}},
 {1853, {wxTextCtrl, remove, 2}},
 {1854, {wxTextCtrl, replace, 3}},
 {1855, {wxTextCtrl, saveFile, 1}},
 {1856, {wxTextCtrl, setDefaultStyle, 1}},
 {1857, {wxTextCtrl, setEditable, 1}},
 {1858, {wxTextCtrl, setInsertionPoint, 1}},
 {1859, {wxTextCtrl, setInsertionPointEnd, 0}},
 {1861, {wxTextCtrl, setMaxLength, 1}},
 {1862, {wxTextCtrl, setSelection, 2}},
 {1863, {wxTextCtrl, setStyle, 3}},
 {1864, {wxTextCtrl, setValue, 1}},
 {1865, {wxTextCtrl, showPosition, 1}},
 {1866, {wxTextCtrl, undo, 0}},
 {1867, {wxTextCtrl, writeText, 1}},
 {1868, {wxTextCtrl, xYToPosition, 2}},
 {1871, {wxNotebook, new_0, 0}},
 {1872, {wxNotebook, new_3, 3}},
 {1873, {wxNotebook, destruct, 0}},
 {1874, {wxNotebook, addPage, 3}},
 {1875, {wxNotebook, advanceSelection, 1}},
 {1876, {wxNotebook, assignImageList, 1}},
 {1877, {wxNotebook, create, 3}},
 {1878, {wxNotebook, deleteAllPages, 0}},
 {1879, {wxNotebook, deletePage, 1}},
 {1880, {wxNotebook, removePage, 1}},
 {1881, {wxNotebook, getCurrentPage, 0}},
 {1882, {wxNotebook, getImageList, 0}},
 {1884, {wxNotebook, getPage, 1}},
 {1885, {wxNotebook, getPageCount, 0}},
 {1886, {wxNotebook, getPageImage, 1}},
 {1887, {wxNotebook, getPageText, 1}},
 {1888, {wxNotebook, getRowCount, 0}},
 {1889, {wxNotebook, getSelection, 0}},
 {1890, {wxNotebook, getThemeBackgroundColour, 0}},
 {1892, {wxNotebook, hitTest, 2}},
 {1894, {wxNotebook, insertPage, 4}},
 {1895, {wxNotebook, setImageList, 1}},
 {1896, {wxNotebook, setPadding, 1}},
 {1897, {wxNotebook, setPageSize, 1}},
 {1898, {wxNotebook, setPageImage, 2}},
 {1899, {wxNotebook, setPageText, 2}},
 {1900, {wxNotebook, setSelection, 1}},
 {1901, {wxNotebook, changeSelection, 1}},
 {1902, {wxChoicebook, new_0, 0}},
 {1903, {wxChoicebook, new_3, 3}},
 {1904, {wxChoicebook, addPage, 3}},
 {1905, {wxChoicebook, advanceSelection, 1}},
 {1906, {wxChoicebook, assignImageList, 1}},
 {1907, {wxChoicebook, create, 3}},
 {1908, {wxChoicebook, deleteAllPages, 0}},
 {1909, {wxChoicebook, deletePage, 1}},
 {1910, {wxChoicebook, removePage, 1}},
 {1911, {wxChoicebook, getCurrentPage, 0}},
 {1912, {wxChoicebook, getImageList, 0}},
 {1914, {wxChoicebook, getPage, 1}},
 {1915, {wxChoicebook, getPageCount, 0}},
 {1916, {wxChoicebook, getPageImage, 1}},
 {1917, {wxChoicebook, getPageText, 1}},
 {1918, {wxChoicebook, getSelection, 0}},
 {1919, {wxChoicebook, hitTest, 2}},
 {1920, {wxChoicebook, insertPage, 4}},
 {1921, {wxChoicebook, setImageList, 1}},
 {1922, {wxChoicebook, setPageSize, 1}},
 {1923, {wxChoicebook, setPageImage, 2}},
 {1924, {wxChoicebook, setPageText, 2}},
 {1925, {wxChoicebook, setSelection, 1}},
 {1926, {wxChoicebook, changeSelection, 1}},
 {1927, {wxChoicebook, 'Destroy', undefined}},
 {1928, {wxToolbook, new_0, 0}},
 {1929, {wxToolbook, new_3, 3}},
 {1930, {wxToolbook, addPage, 3}},
 {1931, {wxToolbook, advanceSelection, 1}},
 {1932, {wxToolbook, assignImageList, 1}},
 {1933, {wxToolbook, create, 3}},
 {1934, {wxToolbook, deleteAllPages, 0}},
 {1935, {wxToolbook, deletePage, 1}},
 {1936, {wxToolbook, removePage, 1}},
 {1937, {wxToolbook, getCurrentPage, 0}},
 {1938, {wxToolbook, getImageList, 0}},
 {1940, {wxToolbook, getPage, 1}},
 {1941, {wxToolbook, getPageCount, 0}},
 {1942, {wxToolbook, getPageImage, 1}},
 {1943, {wxToolbook, getPageText, 1}},
 {1944, {wxToolbook, getSelection, 0}},
 {1946, {wxToolbook, hitTest, 2}},
 {1947, {wxToolbook, insertPage, 4}},
 {1948, {wxToolbook, setImageList, 1}},
 {1949, {wxToolbook, setPageSize, 1}},
 {1950, {wxToolbook, setPageImage, 2}},
 {1951, {wxToolbook, setPageText, 2}},
 {1952, {wxToolbook, setSelection, 1}},
 {1953, {wxToolbook, changeSelection, 1}},
 {1954, {wxToolbook, 'Destroy', undefined}},
 {1955, {wxListbook, new_0, 0}},
 {1956, {wxListbook, new_3, 3}},
 {1957, {wxListbook, addPage, 3}},
 {1958, {wxListbook, advanceSelection, 1}},
 {1959, {wxListbook, assignImageList, 1}},
 {1960, {wxListbook, create, 3}},
 {1961, {wxListbook, deleteAllPages, 0}},
 {1962, {wxListbook, deletePage, 1}},
 {1963, {wxListbook, removePage, 1}},
 {1964, {wxListbook, getCurrentPage, 0}},
 {1965, {wxListbook, getImageList, 0}},
 {1967, {wxListbook, getPage, 1}},
 {1968, {wxListbook, getPageCount, 0}},
 {1969, {wxListbook, getPageImage, 1}},
 {1970, {wxListbook, getPageText, 1}},
 {1971, {wxListbook, getSelection, 0}},
 {1973, {wxListbook, hitTest, 2}},
 {1974, {wxListbook, insertPage, 4}},
 {1975, {wxListbook, setImageList, 1}},
 {1976, {wxListbook, setPageSize, 1}},
 {1977, {wxListbook, setPageImage, 2}},
 {1978, {wxListbook, setPageText, 2}},
 {1979, {wxListbook, setSelection, 1}},
 {1980, {wxListbook, changeSelection, 1}},
 {1981, {wxListbook, 'Destroy', undefined}},
 {1982, {wxTreebook, new_0, 0}},
 {1983, {wxTreebook, new_3, 3}},
 {1984, {wxTreebook, addPage, 3}},
 {1985, {wxTreebook, advanceSelection, 1}},
 {1986, {wxTreebook, assignImageList, 1}},
 {1987, {wxTreebook, create, 3}},
 {1988, {wxTreebook, deleteAllPages, 0}},
 {1989, {wxTreebook, deletePage, 1}},
 {1990, {wxTreebook, removePage, 1}},
 {1991, {wxTreebook, getCurrentPage, 0}},
 {1992, {wxTreebook, getImageList, 0}},
 {1994, {wxTreebook, getPage, 1}},
 {1995, {wxTreebook, getPageCount, 0}},
 {1996, {wxTreebook, getPageImage, 1}},
 {1997, {wxTreebook, getPageText, 1}},
 {1998, {wxTreebook, getSelection, 0}},
 {1999, {wxTreebook, expandNode, 2}},
 {2000, {wxTreebook, isNodeExpanded, 1}},
 {2002, {wxTreebook, hitTest, 2}},
 {2003, {wxTreebook, insertPage, 4}},
 {2004, {wxTreebook, insertSubPage, 4}},
 {2005, {wxTreebook, setImageList, 1}},
 {2006, {wxTreebook, setPageSize, 1}},
 {2007, {wxTreebook, setPageImage, 2}},
 {2008, {wxTreebook, setPageText, 2}},
 {2009, {wxTreebook, setSelection, 1}},
 {2010, {wxTreebook, changeSelection, 1}},
 {2011, {wxTreebook, 'Destroy', undefined}},
 {2014, {wxTreeCtrl, new_2, 2}},
 {2015, {wxTreeCtrl, new_0, 0}},
 {2017, {wxTreeCtrl, destruct, 0}},
 {2018, {wxTreeCtrl, addRoot, 2}},
 {2019, {wxTreeCtrl, appendItem, 3}},
 {2020, {wxTreeCtrl, assignImageList, 1}},
 {2021, {wxTreeCtrl, assignStateImageList, 1}},
 {2022, {wxTreeCtrl, collapse, 1}},
 {2023, {wxTreeCtrl, collapseAndReset, 1}},
 {2024, {wxTreeCtrl, create, 2}},
 {2025, {wxTreeCtrl, delete, 1}},
 {2026, {wxTreeCtrl, deleteAllItems, 0}},
 {2027, {wxTreeCtrl, deleteChildren, 1}},
 {2028, {wxTreeCtrl, editLabel, 1}},
 {2029, {wxTreeCtrl, ensureVisible, 1}},
 {2030, {wxTreeCtrl, expand, 1}},
 {2031, {wxTreeCtrl, getBoundingRect, 3}},
 {2033, {wxTreeCtrl, getChildrenCount, 2}},
 {2034, {wxTreeCtrl, getCount, 0}},
 {2035, {wxTreeCtrl, getEditControl, 0}},
 {2036, {wxTreeCtrl, getFirstChild, 2}},
 {2037, {wxTreeCtrl, getNextChild, 2}},
 {2038, {wxTreeCtrl, getFirstVisibleItem, 0}},
 {2039, {wxTreeCtrl, getImageList, 0}},
 {2040, {wxTreeCtrl, getIndent, 0}},
 {2041, {wxTreeCtrl, getItemBackgroundColour, 1}},
 {2042, {wxTreeCtrl, getItemData, 1}},
 {2043, {wxTreeCtrl, getItemFont, 1}},
 {2044, {wxTreeCtrl, getItemImage_1, 1}},
 {2045, {wxTreeCtrl, getItemImage_2, 2}},
 {2046, {wxTreeCtrl, getItemText, 1}},
 {2047, {wxTreeCtrl, getItemTextColour, 1}},
 {2048, {wxTreeCtrl, getLastChild, 1}},
 {2049, {wxTreeCtrl, getNextSibling, 1}},
 {2050, {wxTreeCtrl, getNextVisible, 1}},
 {2051, {wxTreeCtrl, getItemParent, 1}},
 {2052, {wxTreeCtrl, getPrevSibling, 1}},
 {2053, {wxTreeCtrl, getPrevVisible, 1}},
 {2054, {wxTreeCtrl, getRootItem, 0}},
 {2055, {wxTreeCtrl, getSelection, 0}},
 {2056, {wxTreeCtrl, getSelections, 1}},
 {2057, {wxTreeCtrl, getStateImageList, 0}},
 {2058, {wxTreeCtrl, hitTest, 2}},
 {2060, {wxTreeCtrl, insertItem, 4}},
 {2061, {wxTreeCtrl, isBold, 1}},
 {2062, {wxTreeCtrl, isExpanded, 1}},
 {2063, {wxTreeCtrl, isSelected, 1}},
 {2064, {wxTreeCtrl, isVisible, 1}},
 {2065, {wxTreeCtrl, itemHasChildren, 1}},
 {2066, {wxTreeCtrl, isTreeItemIdOk, 1}},
 {2067, {wxTreeCtrl, prependItem, 3}},
 {2068, {wxTreeCtrl, scrollTo, 1}},
 {2069, {wxTreeCtrl, selectItem_1, 1}},
 {2070, {wxTreeCtrl, selectItem_2, 2}},
 {2071, {wxTreeCtrl, setIndent, 1}},
 {2072, {wxTreeCtrl, setImageList, 1}},
 {2073, {wxTreeCtrl, setItemBackgroundColour, 2}},
 {2074, {wxTreeCtrl, setItemBold, 2}},
 {2075, {wxTreeCtrl, setItemData, 2}},
 {2076, {wxTreeCtrl, setItemDropHighlight, 2}},
 {2077, {wxTreeCtrl, setItemFont, 2}},
 {2078, {wxTreeCtrl, setItemHasChildren, 2}},
 {2079, {wxTreeCtrl, setItemImage_2, 2}},
 {2080, {wxTreeCtrl, setItemImage_3, 3}},
 {2081, {wxTreeCtrl, setItemText, 2}},
 {2082, {wxTreeCtrl, setItemTextColour, 2}},
 {2083, {wxTreeCtrl, setStateImageList, 1}},
 {2084, {wxTreeCtrl, setWindowStyle, 1}},
 {2085, {wxTreeCtrl, sortChildren, 1}},
 {2086, {wxTreeCtrl, toggle, 1}},
 {2087, {wxTreeCtrl, toggleItemSelection, 1}},
 {2088, {wxTreeCtrl, unselect, 0}},
 {2089, {wxTreeCtrl, unselectAll, 0}},
 {2090, {wxTreeCtrl, unselectItem, 1}},
 {2091, {wxScrollBar, new_0, 0}},
 {2092, {wxScrollBar, new_3, 3}},
 {2093, {wxScrollBar, destruct, 0}},
 {2094, {wxScrollBar, create, 3}},
 {2095, {wxScrollBar, getRange, 0}},
 {2096, {wxScrollBar, getPageSize, 0}},
 {2097, {wxScrollBar, getThumbPosition, 0}},
 {2098, {wxScrollBar, getThumbSize, 0}},
 {2099, {wxScrollBar, setThumbPosition, 1}},
 {2100, {wxScrollBar, setScrollbar, 5}},
 {2102, {wxSpinButton, new_2, 2}},
 {2103, {wxSpinButton, new_0, 0}},
 {2104, {wxSpinButton, create, 2}},
 {2105, {wxSpinButton, getMax, 0}},
 {2106, {wxSpinButton, getMin, 0}},
 {2107, {wxSpinButton, getValue, 0}},
 {2108, {wxSpinButton, setRange, 2}},
 {2109, {wxSpinButton, setValue, 1}},
 {2110, {wxSpinButton, 'Destroy', undefined}},
 {2111, {wxSpinCtrl, new_0, 0}},
 {2112, {wxSpinCtrl, new_2, 2}},
 {2114, {wxSpinCtrl, create, 2}},
 {2117, {wxSpinCtrl, setValue_1_1, 1}},
 {2118, {wxSpinCtrl, setValue_1_0, 1}},
 {2120, {wxSpinCtrl, getValue, 0}},
 {2122, {wxSpinCtrl, setRange, 2}},
 {2123, {wxSpinCtrl, setSelection, 2}},
 {2125, {wxSpinCtrl, getMin, 0}},
 {2127, {wxSpinCtrl, getMax, 0}},
 {2128, {wxSpinCtrl, 'Destroy', undefined}},
 {2129, {wxStaticText, new_0, 0}},
 {2130, {wxStaticText, new_4, 4}},
 {2131, {wxStaticText, create, 4}},
 {2132, {wxStaticText, getLabel, 0}},
 {2133, {wxStaticText, setLabel, 1}},
 {2134, {wxStaticText, wrap, 1}},
 {2135, {wxStaticText, 'Destroy', undefined}},
 {2136, {wxStaticBitmap, new_0, 0}},
 {2137, {wxStaticBitmap, new_4, 4}},
 {2138, {wxStaticBitmap, create, 4}},
 {2139, {wxStaticBitmap, getBitmap, 0}},
 {2140, {wxStaticBitmap, setBitmap, 1}},
 {2141, {wxStaticBitmap, 'Destroy', undefined}},
 {2142, {wxRadioBox, new, 7}},
 {2144, {wxRadioBox, destruct, 0}},
 {2145, {wxRadioBox, create, 7}},
 {2146, {wxRadioBox, enable_2, 2}},
 {2147, {wxRadioBox, enable_1, 1}},
 {2148, {wxRadioBox, getSelection, 0}},
 {2149, {wxRadioBox, getString, 1}},
 {2150, {wxRadioBox, setSelection, 1}},
 {2151, {wxRadioBox, show_2, 2}},
 {2152, {wxRadioBox, show_1, 1}},
 {2153, {wxRadioBox, getColumnCount, 0}},
 {2154, {wxRadioBox, getItemHelpText, 1}},
 {2155, {wxRadioBox, getItemToolTip, 1}},
 {2157, {wxRadioBox, getItemFromPoint, 1}},
 {2158, {wxRadioBox, getRowCount, 0}},
 {2159, {wxRadioBox, isItemEnabled, 1}},
 {2160, {wxRadioBox, isItemShown, 1}},
 {2161, {wxRadioBox, setItemHelpText, 2}},
 {2162, {wxRadioBox, setItemToolTip, 2}},
 {2163, {wxRadioButton, new_0, 0}},
 {2164, {wxRadioButton, new_4, 4}},
 {2165, {wxRadioButton, create, 4}},
 {2166, {wxRadioButton, getValue, 0}},
 {2167, {wxRadioButton, setValue, 1}},
 {2168, {wxRadioButton, 'Destroy', undefined}},
 {2170, {wxSlider, new_6, 6}},
 {2171, {wxSlider, new_0, 0}},
 {2172, {wxSlider, create, 6}},
 {2173, {wxSlider, getLineSize, 0}},
 {2174, {wxSlider, getMax, 0}},
 {2175, {wxSlider, getMin, 0}},
 {2176, {wxSlider, getPageSize, 0}},
 {2177, {wxSlider, getThumbLength, 0}},
 {2178, {wxSlider, getValue, 0}},
 {2179, {wxSlider, setLineSize, 1}},
 {2180, {wxSlider, setPageSize, 1}},
 {2181, {wxSlider, setRange, 2}},
 {2182, {wxSlider, setThumbLength, 1}},
 {2183, {wxSlider, setValue, 1}},
 {2184, {wxSlider, 'Destroy', undefined}},
 {2186, {wxDialog, new_4, 4}},
 {2187, {wxDialog, new_0, 0}},
 {2189, {wxDialog, destruct, 0}},
 {2190, {wxDialog, create, 4}},
 {2191, {wxDialog, createButtonSizer, 1}},
 {2192, {wxDialog, createStdDialogButtonSizer, 1}},
 {2193, {wxDialog, endModal, 1}},
 {2194, {wxDialog, getAffirmativeId, 0}},
 {2195, {wxDialog, getReturnCode, 0}},
 {2196, {wxDialog, isModal, 0}},
 {2197, {wxDialog, setAffirmativeId, 1}},
 {2198, {wxDialog, setReturnCode, 1}},
 {2199, {wxDialog, show, 1}},
 {2200, {wxDialog, showModal, 0}},
 {2201, {wxColourDialog, new_0, 0}},
 {2202, {wxColourDialog, new_2, 2}},
 {2203, {wxColourDialog, destruct, 0}},
 {2204, {wxColourDialog, create, 2}},
 {2205, {wxColourDialog, getColourData, 0}},
 {2206, {wxColourData, new_0, 0}},
 {2207, {wxColourData, new_1, 1}},
 {2208, {wxColourData, destruct, 0}},
 {2209, {wxColourData, getChooseFull, 0}},
 {2210, {wxColourData, getColour, 0}},
 {2212, {wxColourData, getCustomColour, 1}},
 {2213, {wxColourData, setChooseFull, 1}},
 {2214, {wxColourData, setColour, 1}},
 {2215, {wxColourData, setCustomColour, 2}},
 {2216, {wxPalette, new_0, 0}},
 {2217, {wxPalette, new_4, 4}},
 {2219, {wxPalette, destruct, 0}},
 {2220, {wxPalette, create, 4}},
 {2221, {wxPalette, getColoursCount, 0}},
 {2222, {wxPalette, getPixel, 3}},
 {2223, {wxPalette, getRGB, 4}},
 {2224, {wxPalette, isOk, 0}},
 {2228, {wxDirDialog, new, 2}},
 {2229, {wxDirDialog, destruct, 0}},
 {2230, {wxDirDialog, getPath, 0}},
 {2231, {wxDirDialog, getMessage, 0}},
 {2232, {wxDirDialog, setMessage, 1}},
 {2233, {wxDirDialog, setPath, 1}},
 {2237, {wxFileDialog, new, 2}},
 {2238, {wxFileDialog, destruct, 0}},
 {2239, {wxFileDialog, getDirectory, 0}},
 {2240, {wxFileDialog, getFilename, 0}},
 {2241, {wxFileDialog, getFilenames, 1}},
 {2242, {wxFileDialog, getFilterIndex, 0}},
 {2243, {wxFileDialog, getMessage, 0}},
 {2244, {wxFileDialog, getPath, 0}},
 {2245, {wxFileDialog, getPaths, 1}},
 {2246, {wxFileDialog, getWildcard, 0}},
 {2247, {wxFileDialog, setDirectory, 1}},
 {2248, {wxFileDialog, setFilename, 1}},
 {2249, {wxFileDialog, setFilterIndex, 1}},
 {2250, {wxFileDialog, setMessage, 1}},
 {2251, {wxFileDialog, setPath, 1}},
 {2252, {wxFileDialog, setWildcard, 1}},
 {2253, {wxPickerBase, setInternalMargin, 1}},
 {2254, {wxPickerBase, getInternalMargin, 0}},
 {2255, {wxPickerBase, setTextCtrlProportion, 1}},
 {2256, {wxPickerBase, setPickerCtrlProportion, 1}},
 {2257, {wxPickerBase, getTextCtrlProportion, 0}},
 {2258, {wxPickerBase, getPickerCtrlProportion, 0}},
 {2259, {wxPickerBase, hasTextCtrl, 0}},
 {2260, {wxPickerBase, getTextCtrl, 0}},
 {2261, {wxPickerBase, isTextCtrlGrowable, 0}},
 {2262, {wxPickerBase, setPickerCtrlGrowable, 1}},
 {2263, {wxPickerBase, setTextCtrlGrowable, 1}},
 {2264, {wxPickerBase, isPickerCtrlGrowable, 0}},
 {2265, {wxFilePickerCtrl, new_0, 0}},
 {2266, {wxFilePickerCtrl, new_3, 3}},
 {2267, {wxFilePickerCtrl, create, 3}},
 {2268, {wxFilePickerCtrl, getPath, 0}},
 {2269, {wxFilePickerCtrl, setPath, 1}},
 {2270, {wxFilePickerCtrl, 'Destroy', undefined}},
 {2271, {wxDirPickerCtrl, new_0, 0}},
 {2272, {wxDirPickerCtrl, new_3, 3}},
 {2273, {wxDirPickerCtrl, create, 3}},
 {2274, {wxDirPickerCtrl, getPath, 0}},
 {2275, {wxDirPickerCtrl, setPath, 1}},
 {2276, {wxDirPickerCtrl, 'Destroy', undefined}},
 {2277, {wxColourPickerCtrl, new_0, 0}},
 {2278, {wxColourPickerCtrl, new_3, 3}},
 {2279, {wxColourPickerCtrl, create, 3}},
 {2280, {wxColourPickerCtrl, getColour, 0}},
 {2281, {wxColourPickerCtrl, setColour_1_1, 1}},
 {2282, {wxColourPickerCtrl, setColour_1_0, 1}},
 {2283, {wxColourPickerCtrl, 'Destroy', undefined}},
 {2284, {wxDatePickerCtrl, new_0, 0}},
 {2285, {wxDatePickerCtrl, new_3, 3}},
 {2286, {wxDatePickerCtrl, getRange, 2}},
 {2287, {wxDatePickerCtrl, getValue, 0}},
 {2288, {wxDatePickerCtrl, setRange, 2}},
 {2289, {wxDatePickerCtrl, setValue, 1}},
 {2290, {wxDatePickerCtrl, 'Destroy', undefined}},
 {2291, {wxFontPickerCtrl, new_0, 0}},
 {2292, {wxFontPickerCtrl, new_3, 3}},
 {2293, {wxFontPickerCtrl, create, 3}},
 {2294, {wxFontPickerCtrl, getSelectedFont, 0}},
 {2295, {wxFontPickerCtrl, setSelectedFont, 1}},
 {2296, {wxFontPickerCtrl, getMaxPointSize, 0}},
 {2297, {wxFontPickerCtrl, setMaxPointSize, 1}},
 {2298, {wxFontPickerCtrl, 'Destroy', undefined}},
 {2301, {wxFindReplaceDialog, new_0, 0}},
 {2302, {wxFindReplaceDialog, new_4, 4}},
 {2303, {wxFindReplaceDialog, destruct, 0}},
 {2304, {wxFindReplaceDialog, create, 4}},
 {2305, {wxFindReplaceDialog, getData, 0}},
 {2306, {wxFindReplaceData, new_0, 0}},
 {2307, {wxFindReplaceData, new_1, 1}},
 {2308, {wxFindReplaceData, getFindString, 0}},
 {2309, {wxFindReplaceData, getReplaceString, 0}},
 {2310, {wxFindReplaceData, getFlags, 0}},
 {2311, {wxFindReplaceData, setFlags, 1}},
 {2312, {wxFindReplaceData, setFindString, 1}},
 {2313, {wxFindReplaceData, setReplaceString, 1}},
 {2314, {wxFindReplaceData, 'Destroy', undefined}},
 {2315, {wxMultiChoiceDialog, new_0, 0}},
 {2317, {wxMultiChoiceDialog, new_5, 5}},
 {2318, {wxMultiChoiceDialog, getSelections, 0}},
 {2319, {wxMultiChoiceDialog, setSelections, 1}},
 {2320, {wxMultiChoiceDialog, 'Destroy', undefined}},
 {2321, {wxSingleChoiceDialog, new_0, 0}},
 {2323, {wxSingleChoiceDialog, new_5, 5}},
 {2324, {wxSingleChoiceDialog, getSelection, 0}},
 {2325, {wxSingleChoiceDialog, getStringSelection, 0}},
 {2326, {wxSingleChoiceDialog, setSelection, 1}},
 {2327, {wxSingleChoiceDialog, 'Destroy', undefined}},
 {2328, {wxTextEntryDialog, new, 3}},
 {2329, {wxTextEntryDialog, getValue, 0}},
 {2330, {wxTextEntryDialog, setValue, 1}},
 {2331, {wxTextEntryDialog, 'Destroy', undefined}},
 {2332, {wxPasswordEntryDialog, new, 3}},
 {2333, {wxPasswordEntryDialog, 'Destroy', undefined}},
 {2334, {wxFontData, new_0, 0}},
 {2335, {wxFontData, new_1, 1}},
 {2336, {wxFontData, destruct, 0}},
 {2337, {wxFontData, enableEffects, 1}},
 {2338, {wxFontData, getAllowSymbols, 0}},
 {2339, {wxFontData, getColour, 0}},
 {2340, {wxFontData, getChosenFont, 0}},
 {2341, {wxFontData, getEnableEffects, 0}},
 {2342, {wxFontData, getInitialFont, 0}},
 {2343, {wxFontData, getShowHelp, 0}},
 {2344, {wxFontData, setAllowSymbols, 1}},
 {2345, {wxFontData, setChosenFont, 1}},
 {2346, {wxFontData, setColour, 1}},
 {2347, {wxFontData, setInitialFont, 1}},
 {2348, {wxFontData, setRange, 2}},
 {2349, {wxFontData, setShowHelp, 1}},
 {2353, {wxFontDialog, new_0, 0}},
 {2355, {wxFontDialog, new_2, 2}},
 {2357, {wxFontDialog, create, 2}},
 {2358, {wxFontDialog, getFontData, 0}},
 {2360, {wxFontDialog, 'Destroy', undefined}},
 {2361, {wxProgressDialog, new, 3}},
 {2362, {wxProgressDialog, destruct, 0}},
 {2363, {wxProgressDialog, resume, 0}},
 {2364, {wxProgressDialog, update_2, 2}},
 {2365, {wxProgressDialog, update_0, 0}},
 {2366, {wxMessageDialog, new, 3}},
 {2367, {wxMessageDialog, destruct, 0}},
 {2368, {wxPageSetupDialog, new, 2}},
 {2369, {wxPageSetupDialog, destruct, 0}},
 {2370, {wxPageSetupDialog, getPageSetupData, 0}},
 {2371, {wxPageSetupDialog, showModal, 0}},
 {2372, {wxPageSetupDialogData, new_0, 0}},
 {2373, {wxPageSetupDialogData, new_1_0, 1}},
 {2374, {wxPageSetupDialogData, new_1_1, 1}},
 {2375, {wxPageSetupDialogData, destruct, 0}},
 {2376, {wxPageSetupDialogData, enableHelp, 1}},
 {2377, {wxPageSetupDialogData, enableMargins, 1}},
 {2378, {wxPageSetupDialogData, enableOrientation, 1}},
 {2379, {wxPageSetupDialogData, enablePaper, 1}},
 {2380, {wxPageSetupDialogData, enablePrinter, 1}},
 {2381, {wxPageSetupDialogData, getDefaultMinMargins, 0}},
 {2382, {wxPageSetupDialogData, getEnableMargins, 0}},
 {2383, {wxPageSetupDialogData, getEnableOrientation, 0}},
 {2384, {wxPageSetupDialogData, getEnablePaper, 0}},
 {2385, {wxPageSetupDialogData, getEnablePrinter, 0}},
 {2386, {wxPageSetupDialogData, getEnableHelp, 0}},
 {2387, {wxPageSetupDialogData, getDefaultInfo, 0}},
 {2388, {wxPageSetupDialogData, getMarginTopLeft, 0}},
 {2389, {wxPageSetupDialogData, getMarginBottomRight, 0}},
 {2390, {wxPageSetupDialogData, getMinMarginTopLeft, 0}},
 {2391, {wxPageSetupDialogData, getMinMarginBottomRight, 0}},
 {2392, {wxPageSetupDialogData, getPaperId, 0}},
 {2393, {wxPageSetupDialogData, getPaperSize, 0}},
 {2395, {wxPageSetupDialogData, getPrintData, 0}},
 {2396, {wxPageSetupDialogData, isOk, 0}},
 {2397, {wxPageSetupDialogData, setDefaultInfo, 1}},
 {2398, {wxPageSetupDialogData, setDefaultMinMargins, 1}},
 {2399, {wxPageSetupDialogData, setMarginTopLeft, 1}},
 {2400, {wxPageSetupDialogData, setMarginBottomRight, 1}},
 {2401, {wxPageSetupDialogData, setMinMarginTopLeft, 1}},
 {2402, {wxPageSetupDialogData, setMinMarginBottomRight, 1}},
 {2403, {wxPageSetupDialogData, setPaperId, 1}},
 {2404, {wxPageSetupDialogData, setPaperSize_1_1, 1}},
 {2405, {wxPageSetupDialogData, setPaperSize_1_0, 1}},
 {2406, {wxPageSetupDialogData, setPrintData, 1}},
 {2407, {wxPrintDialog, new_2_0, 2}},
 {2408, {wxPrintDialog, new_2_1, 2}},
 {2409, {wxPrintDialog, destruct, 0}},
 {2410, {wxPrintDialog, getPrintDialogData, 0}},
 {2411, {wxPrintDialog, getPrintDC, 0}},
 {2412, {wxPrintDialogData, new_0, 0}},
 {2413, {wxPrintDialogData, new_1_1, 1}},
 {2414, {wxPrintDialogData, new_1_0, 1}},
 {2415, {wxPrintDialogData, destruct, 0}},
 {2416, {wxPrintDialogData, enableHelp, 1}},
 {2417, {wxPrintDialogData, enablePageNumbers, 1}},
 {2418, {wxPrintDialogData, enablePrintToFile, 1}},
 {2419, {wxPrintDialogData, enableSelection, 1}},
 {2420, {wxPrintDialogData, getAllPages, 0}},
 {2421, {wxPrintDialogData, getCollate, 0}},
 {2422, {wxPrintDialogData, getFromPage, 0}},
 {2423, {wxPrintDialogData, getMaxPage, 0}},
 {2424, {wxPrintDialogData, getMinPage, 0}},
 {2425, {wxPrintDialogData, getNoCopies, 0}},
 {2426, {wxPrintDialogData, getPrintData, 0}},
 {2427, {wxPrintDialogData, getPrintToFile, 0}},
 {2428, {wxPrintDialogData, getSelection, 0}},
 {2429, {wxPrintDialogData, getToPage, 0}},
 {2430, {wxPrintDialogData, isOk, 0}},
 {2431, {wxPrintDialogData, setCollate, 1}},
 {2432, {wxPrintDialogData, setFromPage, 1}},
 {2433, {wxPrintDialogData, setMaxPage, 1}},
 {2434, {wxPrintDialogData, setMinPage, 1}},
 {2435, {wxPrintDialogData, setNoCopies, 1}},
 {2436, {wxPrintDialogData, setPrintData, 1}},
 {2437, {wxPrintDialogData, setPrintToFile, 1}},
 {2438, {wxPrintDialogData, setSelection, 1}},
 {2439, {wxPrintDialogData, setToPage, 1}},
 {2440, {wxPrintData, new_0, 0}},
 {2441, {wxPrintData, new_1, 1}},
 {2442, {wxPrintData, destruct, 0}},
 {2443, {wxPrintData, getCollate, 0}},
 {2444, {wxPrintData, getBin, 0}},
 {2445, {wxPrintData, getColour, 0}},
 {2446, {wxPrintData, getDuplex, 0}},
 {2447, {wxPrintData, getNoCopies, 0}},
 {2448, {wxPrintData, getOrientation, 0}},
 {2449, {wxPrintData, getPaperId, 0}},
 {2450, {wxPrintData, getPrinterName, 0}},
 {2451, {wxPrintData, getQuality, 0}},
 {2452, {wxPrintData, isOk, 0}},
 {2453, {wxPrintData, setBin, 1}},
 {2454, {wxPrintData, setCollate, 1}},
 {2455, {wxPrintData, setColour, 1}},
 {2456, {wxPrintData, setDuplex, 1}},
 {2457, {wxPrintData, setNoCopies, 1}},
 {2458, {wxPrintData, setOrientation, 1}},
 {2459, {wxPrintData, setPaperId, 1}},
 {2460, {wxPrintData, setPrinterName, 1}},
 {2461, {wxPrintData, setQuality, 1}},
 {2464, {wxPrintPreview, new_2, 2}},
 {2465, {wxPrintPreview, new_3, 3}},
 {2467, {wxPrintPreview, destruct, 0}},
 {2468, {wxPrintPreview, getCanvas, 0}},
 {2469, {wxPrintPreview, getCurrentPage, 0}},
 {2470, {wxPrintPreview, getFrame, 0}},
 {2471, {wxPrintPreview, getMaxPage, 0}},
 {2472, {wxPrintPreview, getMinPage, 0}},
 {2473, {wxPrintPreview, getPrintout, 0}},
 {2474, {wxPrintPreview, getPrintoutForPrinting, 0}},
 {2475, {wxPrintPreview, isOk, 0}},
 {2476, {wxPrintPreview, paintPage, 2}},
 {2477, {wxPrintPreview, print, 1}},
 {2478, {wxPrintPreview, renderPage, 1}},
 {2479, {wxPrintPreview, setCanvas, 1}},
 {2480, {wxPrintPreview, setCurrentPage, 1}},
 {2481, {wxPrintPreview, setFrame, 1}},
 {2482, {wxPrintPreview, setPrintout, 1}},
 {2483, {wxPrintPreview, setZoom, 1}},
 {2484, {wxPreviewFrame, new, 3}},
 {2485, {wxPreviewFrame, destruct, 0}},
 {2486, {wxPreviewFrame, createControlBar, 0}},
 {2487, {wxPreviewFrame, createCanvas, 0}},
 {2488, {wxPreviewFrame, initialize, 0}},
 {2489, {wxPreviewFrame, onCloseWindow, 1}},
 {2490, {wxPreviewControlBar, new, 4}},
 {2491, {wxPreviewControlBar, destruct, 0}},
 {2492, {wxPreviewControlBar, createButtons, 0}},
 {2493, {wxPreviewControlBar, getPrintPreview, 0}},
 {2494, {wxPreviewControlBar, getZoomControl, 0}},
 {2495, {wxPreviewControlBar, setZoomControl, 1}},
 {2497, {wxPrinter, new, 1}},
 {2498, {wxPrinter, createAbortWindow, 2}},
 {2499, {wxPrinter, getAbort, 0}},
 {2500, {wxPrinter, getLastError, 0}},
 {2501, {wxPrinter, getPrintDialogData, 0}},
 {2502, {wxPrinter, print, 3}},
 {2503, {wxPrinter, printDialog, 1}},
 {2504, {wxPrinter, reportError, 3}},
 {2505, {wxPrinter, setup, 1}},
 {2506, {wxPrinter, 'Destroy', undefined}},
 {2507, {wxXmlResource, new_1, 1}},
 {2508, {wxXmlResource, new_2, 2}},
 {2509, {wxXmlResource, destruct, 0}},
 {2510, {wxXmlResource, attachUnknownControl, 3}},
 {2511, {wxXmlResource, clearHandlers, 0}},
 {2512, {wxXmlResource, compareVersion, 4}},
 {2513, {wxXmlResource, get, 0}},
 {2514, {wxXmlResource, getFlags, 0}},
 {2515, {wxXmlResource, getVersion, 0}},
 {2516, {wxXmlResource, getXRCID, 2}},
 {2517, {wxXmlResource, initAllHandlers, 0}},
 {2518, {wxXmlResource, load, 1}},
 {2519, {wxXmlResource, loadBitmap, 1}},
 {2520, {wxXmlResource, loadDialog_2, 2}},
 {2521, {wxXmlResource, loadDialog_3, 3}},
 {2522, {wxXmlResource, loadFrame_2, 2}},
 {2523, {wxXmlResource, loadFrame_3, 3}},
 {2524, {wxXmlResource, loadIcon, 1}},
 {2525, {wxXmlResource, loadMenu, 1}},
 {2526, {wxXmlResource, loadMenuBar_2, 2}},
 {2527, {wxXmlResource, loadMenuBar_1, 1}},
 {2528, {wxXmlResource, loadPanel_2, 2}},
 {2529, {wxXmlResource, loadPanel_3, 3}},
 {2530, {wxXmlResource, loadToolBar, 2}},
 {2531, {wxXmlResource, set, 1}},
 {2532, {wxXmlResource, setFlags, 1}},
 {2533, {wxXmlResource, unload, 1}},
 {2534, {wxXmlResource, xrcctrl, 3}},
 {2535, {wxHtmlEasyPrinting, new, 1}},
 {2536, {wxHtmlEasyPrinting, destruct, 0}},
 {2537, {wxHtmlEasyPrinting, getPrintData, 0}},
 {2538, {wxHtmlEasyPrinting, getPageSetupData, 0}},
 {2539, {wxHtmlEasyPrinting, previewFile, 1}},
 {2540, {wxHtmlEasyPrinting, previewText, 2}},
 {2541, {wxHtmlEasyPrinting, printFile, 1}},
 {2542, {wxHtmlEasyPrinting, printText, 2}},
 {2543, {wxHtmlEasyPrinting, pageSetup, 0}},
 {2544, {wxHtmlEasyPrinting, setFonts, 3}},
 {2545, {wxHtmlEasyPrinting, setHeader, 2}},
 {2546, {wxHtmlEasyPrinting, setFooter, 2}},
 {2548, {wxGLCanvas, new_2, 2}},
 {2549, {wxGLCanvas, new_3_1, 3}},
 {2550, {wxGLCanvas, new_3_0, 3}},
 {2551, {wxGLCanvas, getContext, 0}},
 {2553, {wxGLCanvas, setCurrent, 0}},
 {2554, {wxGLCanvas, swapBuffers, 0}},
 {2555, {wxGLCanvas, 'Destroy', undefined}},
 {2556, {wxAuiManager, new, 1}},
 {2557, {wxAuiManager, destruct, 0}},
 {2558, {wxAuiManager, addPane_2_1, 2}},
 {2559, {wxAuiManager, addPane_3, 3}},
 {2560, {wxAuiManager, addPane_2_0, 2}},
 {2561, {wxAuiManager, detachPane, 1}},
 {2562, {wxAuiManager, getAllPanes, 0}},
 {2563, {wxAuiManager, getArtProvider, 0}},
 {2564, {wxAuiManager, getDockSizeConstraint, 2}},
 {2565, {wxAuiManager, getFlags, 0}},
 {2566, {wxAuiManager, getManagedWindow, 0}},
 {2567, {wxAuiManager, getManager, 1}},
 {2568, {wxAuiManager, getPane_1_1, 1}},
 {2569, {wxAuiManager, getPane_1_0, 1}},
 {2570, {wxAuiManager, hideHint, 0}},
 {2571, {wxAuiManager, insertPane, 3}},
 {2572, {wxAuiManager, loadPaneInfo, 2}},
 {2573, {wxAuiManager, loadPerspective, 2}},
 {2574, {wxAuiManager, savePaneInfo, 1}},
 {2575, {wxAuiManager, savePerspective, 0}},
 {2576, {wxAuiManager, setArtProvider, 1}},
 {2577, {wxAuiManager, setDockSizeConstraint, 2}},
 {2578, {wxAuiManager, setFlags, 1}},
 {2579, {wxAuiManager, setManagedWindow, 1}},
 {2580, {wxAuiManager, showHint, 1}},
 {2581, {wxAuiManager, unInit, 0}},
 {2582, {wxAuiManager, update, 0}},
 {2583, {wxAuiPaneInfo, new_0, 0}},
 {2584, {wxAuiPaneInfo, new_1, 1}},
 {2585, {wxAuiPaneInfo, destruct, 0}},
 {2586, {wxAuiPaneInfo, bestSize_1, 1}},
 {2587, {wxAuiPaneInfo, bestSize_2, 2}},
 {2588, {wxAuiPaneInfo, bottom, 0}},
 {2589, {wxAuiPaneInfo, bottomDockable, 1}},
 {2590, {wxAuiPaneInfo, caption, 1}},
 {2591, {wxAuiPaneInfo, captionVisible, 1}},
 {2592, {wxAuiPaneInfo, centre, 0}},
 {2593, {wxAuiPaneInfo, centrePane, 0}},
 {2594, {wxAuiPaneInfo, closeButton, 1}},
 {2595, {wxAuiPaneInfo, defaultPane, 0}},
 {2596, {wxAuiPaneInfo, destroyOnClose, 1}},
 {2597, {wxAuiPaneInfo, direction, 1}},
 {2598, {wxAuiPaneInfo, dock, 0}},
 {2599, {wxAuiPaneInfo, dockable, 1}},
 {2600, {wxAuiPaneInfo, fixed, 0}},
 {2601, {wxAuiPaneInfo, float, 0}},
 {2602, {wxAuiPaneInfo, floatable, 1}},
 {2603, {wxAuiPaneInfo, floatingPosition_1, 1}},
 {2604, {wxAuiPaneInfo, floatingPosition_2, 2}},
 {2605, {wxAuiPaneInfo, floatingSize_1, 1}},
 {2606, {wxAuiPaneInfo, floatingSize_2, 2}},
 {2607, {wxAuiPaneInfo, gripper, 1}},
 {2608, {wxAuiPaneInfo, gripperTop, 1}},
 {2609, {wxAuiPaneInfo, hasBorder, 0}},
 {2610, {wxAuiPaneInfo, hasCaption, 0}},
 {2611, {wxAuiPaneInfo, hasCloseButton, 0}},
 {2612, {wxAuiPaneInfo, hasFlag, 1}},
 {2613, {wxAuiPaneInfo, hasGripper, 0}},
 {2614, {wxAuiPaneInfo, hasGripperTop, 0}},
 {2615, {wxAuiPaneInfo, hasMaximizeButton, 0}},
 {2616, {wxAuiPaneInfo, hasMinimizeButton, 0}},
 {2617, {wxAuiPaneInfo, hasPinButton, 0}},
 {2618, {wxAuiPaneInfo, hide, 0}},
 {2619, {wxAuiPaneInfo, isBottomDockable, 0}},
 {2620, {wxAuiPaneInfo, isDocked, 0}},
 {2621, {wxAuiPaneInfo, isFixed, 0}},
 {2622, {wxAuiPaneInfo, isFloatable, 0}},
 {2623, {wxAuiPaneInfo, isFloating, 0}},
 {2624, {wxAuiPaneInfo, isLeftDockable, 0}},
 {2625, {wxAuiPaneInfo, isMovable, 0}},
 {2626, {wxAuiPaneInfo, isOk, 0}},
 {2627, {wxAuiPaneInfo, isResizable, 0}},
 {2628, {wxAuiPaneInfo, isRightDockable, 0}},
 {2629, {wxAuiPaneInfo, isShown, 0}},
 {2630, {wxAuiPaneInfo, isToolbar, 0}},
 {2631, {wxAuiPaneInfo, isTopDockable, 0}},
 {2632, {wxAuiPaneInfo, layer, 1}},
 {2633, {wxAuiPaneInfo, left, 0}},
 {2634, {wxAuiPaneInfo, leftDockable, 1}},
 {2635, {wxAuiPaneInfo, maxSize_1, 1}},
 {2636, {wxAuiPaneInfo, maxSize_2, 2}},
 {2637, {wxAuiPaneInfo, maximizeButton, 1}},
 {2638, {wxAuiPaneInfo, minSize_1, 1}},
 {2639, {wxAuiPaneInfo, minSize_2, 2}},
 {2640, {wxAuiPaneInfo, minimizeButton, 1}},
 {2641, {wxAuiPaneInfo, movable, 1}},
 {2642, {wxAuiPaneInfo, name, 1}},
 {2643, {wxAuiPaneInfo, paneBorder, 1}},
 {2644, {wxAuiPaneInfo, pinButton, 1}},
 {2645, {wxAuiPaneInfo, position, 1}},
 {2646, {wxAuiPaneInfo, resizable, 1}},
 {2647, {wxAuiPaneInfo, right, 0}},
 {2648, {wxAuiPaneInfo, rightDockable, 1}},
 {2649, {wxAuiPaneInfo, row, 1}},
 {2650, {wxAuiPaneInfo, safeSet, 1}},
 {2651, {wxAuiPaneInfo, setFlag, 2}},
 {2652, {wxAuiPaneInfo, show, 1}},
 {2653, {wxAuiPaneInfo, toolbarPane, 0}},
 {2654, {wxAuiPaneInfo, top, 0}},
 {2655, {wxAuiPaneInfo, topDockable, 1}},
 {2656, {wxAuiPaneInfo, window, 1}},
 {2657, {wxAuiPaneInfo, getWindow, 0}},
 {2658, {wxAuiPaneInfo, getFrame, 0}},
 {2659, {wxAuiPaneInfo, getDirection, 0}},
 {2660, {wxAuiPaneInfo, getLayer, 0}},
 {2661, {wxAuiPaneInfo, getRow, 0}},
 {2662, {wxAuiPaneInfo, getPosition, 0}},
 {2663, {wxAuiPaneInfo, getFloatingPosition, 0}},
 {2664, {wxAuiPaneInfo, getFloatingSize, 0}},
 {2665, {wxAuiNotebook, new_0, 0}},
 {2666, {wxAuiNotebook, new_2, 2}},
 {2667, {wxAuiNotebook, addPage, 3}},
 {2668, {wxAuiNotebook, create, 2}},
 {2669, {wxAuiNotebook, deletePage, 1}},
 {2670, {wxAuiNotebook, getArtProvider, 0}},
 {2671, {wxAuiNotebook, getPage, 1}},
 {2672, {wxAuiNotebook, getPageBitmap, 1}},
 {2673, {wxAuiNotebook, getPageCount, 0}},
 {2674, {wxAuiNotebook, getPageIndex, 1}},
 {2675, {wxAuiNotebook, getPageText, 1}},
 {2676, {wxAuiNotebook, getSelection, 0}},
 {2677, {wxAuiNotebook, insertPage, 4}},
 {2678, {wxAuiNotebook, removePage, 1}},
 {2679, {wxAuiNotebook, setArtProvider, 1}},
 {2680, {wxAuiNotebook, setFont, 1}},
 {2681, {wxAuiNotebook, setPageBitmap, 2}},
 {2682, {wxAuiNotebook, setPageText, 2}},
 {2683, {wxAuiNotebook, setSelection, 1}},
 {2684, {wxAuiNotebook, setTabCtrlHeight, 1}},
 {2685, {wxAuiNotebook, setUniformBitmapSize, 1}},
 {2686, {wxAuiNotebook, 'Destroy', undefined}},
 {2687, {wxAuiTabArt, setFlags, 1}},
 {2688, {wxAuiTabArt, setMeasuringFont, 1}},
 {2689, {wxAuiTabArt, setNormalFont, 1}},
 {2690, {wxAuiTabArt, setSelectedFont, 1}},
 {2691, {wxAuiTabArt, setColour, 1}},
 {2692, {wxAuiTabArt, setActiveColour, 1}},
 {2693, {wxAuiDockArt, getColour, 1}},
 {2694, {wxAuiDockArt, getFont, 1}},
 {2695, {wxAuiDockArt, getMetric, 1}},
 {2696, {wxAuiDockArt, setColour, 2}},
 {2697, {wxAuiDockArt, setFont, 2}},
 {2698, {wxAuiDockArt, setMetric, 2}},
 {2699, {wxAuiSimpleTabArt, new, 0}},
 {2700, {wxAuiSimpleTabArt, 'Destroy', undefined}},
 {2701, {wxMDIParentFrame, new_0, 0}},
 {2702, {wxMDIParentFrame, new_4, 4}},
 {2703, {wxMDIParentFrame, destruct, 0}},
 {2704, {wxMDIParentFrame, activateNext, 0}},
 {2705, {wxMDIParentFrame, activatePrevious, 0}},
 {2706, {wxMDIParentFrame, arrangeIcons, 0}},
 {2707, {wxMDIParentFrame, cascade, 0}},
 {2708, {wxMDIParentFrame, create, 4}},
 {2709, {wxMDIParentFrame, getActiveChild, 0}},
 {2710, {wxMDIParentFrame, getClientWindow, 0}},
 {2711, {wxMDIParentFrame, tile, 1}},
 {2712, {wxMDIChildFrame, new_0, 0}},
 {2713, {wxMDIChildFrame, new_4, 4}},
 {2714, {wxMDIChildFrame, destruct, 0}},
 {2715, {wxMDIChildFrame, activate, 0}},
 {2716, {wxMDIChildFrame, create, 4}},
 {2717, {wxMDIChildFrame, maximize, 1}},
 {2718, {wxMDIChildFrame, restore, 0}},
 {2719, {wxMDIClientWindow, new_0, 0}},
 {2720, {wxMDIClientWindow, new_2, 2}},
 {2721, {wxMDIClientWindow, destruct, 0}},
 {2722, {wxMDIClientWindow, createClient, 2}},
 {2723, {wxLayoutAlgorithm, new, 0}},
 {2724, {wxLayoutAlgorithm, layoutFrame, 2}},
 {2725, {wxLayoutAlgorithm, layoutMDIFrame, 2}},
 {2726, {wxLayoutAlgorithm, layoutWindow, 2}},
 {2727, {wxLayoutAlgorithm, 'Destroy', undefined}},
 {2728, {wxEvent, getId, 0}},
 {2729, {wxEvent, getSkipped, 0}},
 {2730, {wxEvent, getTimestamp, 0}},
 {2731, {wxEvent, isCommandEvent, 0}},
 {2732, {wxEvent, resumePropagation, 1}},
 {2733, {wxEvent, shouldPropagate, 0}},
 {2734, {wxEvent, skip, 1}},
 {2735, {wxEvent, stopPropagation, 0}},
 {2736, {wxCommandEvent, getClientData, 0}},
 {2737, {wxCommandEvent, getExtraLong, 0}},
 {2738, {wxCommandEvent, getInt, 0}},
 {2739, {wxCommandEvent, getSelection, 0}},
 {2740, {wxCommandEvent, getString, 0}},
 {2741, {wxCommandEvent, isChecked, 0}},
 {2742, {wxCommandEvent, isSelection, 0}},
 {2743, {wxCommandEvent, setInt, 1}},
 {2744, {wxCommandEvent, setString, 1}},
 {2745, {wxScrollEvent, getOrientation, 0}},
 {2746, {wxScrollEvent, getPosition, 0}},
 {2747, {wxScrollWinEvent, getOrientation, 0}},
 {2748, {wxScrollWinEvent, getPosition, 0}},
 {2749, {wxMouseEvent, altDown, 0}},
 {2750, {wxMouseEvent, button, 1}},
 {2751, {wxMouseEvent, buttonDClick, 1}},
 {2752, {wxMouseEvent, buttonDown, 1}},
 {2753, {wxMouseEvent, buttonUp, 1}},
 {2754, {wxMouseEvent, cmdDown, 0}},
 {2755, {wxMouseEvent, controlDown, 0}},
 {2756, {wxMouseEvent, dragging, 0}},
 {2757, {wxMouseEvent, entering, 0}},
 {2758, {wxMouseEvent, getButton, 0}},
 {2761, {wxMouseEvent, getPosition, 0}},
 {2762, {wxMouseEvent, getLogicalPosition, 1}},
 {2763, {wxMouseEvent, getLinesPerAction, 0}},
 {2764, {wxMouseEvent, getWheelRotation, 0}},
 {2765, {wxMouseEvent, getWheelDelta, 0}},
 {2766, {wxMouseEvent, getX, 0}},
 {2767, {wxMouseEvent, getY, 0}},
 {2768, {wxMouseEvent, isButton, 0}},
 {2769, {wxMouseEvent, isPageScroll, 0}},
 {2770, {wxMouseEvent, leaving, 0}},
 {2771, {wxMouseEvent, leftDClick, 0}},
 {2772, {wxMouseEvent, leftDown, 0}},
 {2773, {wxMouseEvent, leftIsDown, 0}},
 {2774, {wxMouseEvent, leftUp, 0}},
 {2775, {wxMouseEvent, metaDown, 0}},
 {2776, {wxMouseEvent, middleDClick, 0}},
 {2777, {wxMouseEvent, middleDown, 0}},
 {2778, {wxMouseEvent, middleIsDown, 0}},
 {2779, {wxMouseEvent, middleUp, 0}},
 {2780, {wxMouseEvent, moving, 0}},
 {2781, {wxMouseEvent, rightDClick, 0}},
 {2782, {wxMouseEvent, rightDown, 0}},
 {2783, {wxMouseEvent, rightIsDown, 0}},
 {2784, {wxMouseEvent, rightUp, 0}},
 {2785, {wxMouseEvent, shiftDown, 0}},
 {2786, {wxSetCursorEvent, getCursor, 0}},
 {2787, {wxSetCursorEvent, getX, 0}},
 {2788, {wxSetCursorEvent, getY, 0}},
 {2789, {wxSetCursorEvent, hasCursor, 0}},
 {2790, {wxSetCursorEvent, setCursor, 1}},
 {2791, {wxKeyEvent, altDown, 0}},
 {2792, {wxKeyEvent, cmdDown, 0}},
 {2793, {wxKeyEvent, controlDown, 0}},
 {2794, {wxKeyEvent, getKeyCode, 0}},
 {2795, {wxKeyEvent, getModifiers, 0}},
 {2798, {wxKeyEvent, getPosition, 0}},
 {2799, {wxKeyEvent, getRawKeyCode, 0}},
 {2800, {wxKeyEvent, getRawKeyFlags, 0}},
 {2801, {wxKeyEvent, getUnicodeKey, 0}},
 {2802, {wxKeyEvent, getX, 0}},
 {2803, {wxKeyEvent, getY, 0}},
 {2804, {wxKeyEvent, hasModifiers, 0}},
 {2805, {wxKeyEvent, metaDown, 0}},
 {2806, {wxKeyEvent, shiftDown, 0}},
 {2807, {wxSizeEvent, getSize, 0}},
 {2808, {wxMoveEvent, getPosition, 0}},
 {2809, {wxEraseEvent, getDC, 0}},
 {2810, {wxFocusEvent, getWindow, 0}},
 {2811, {wxChildFocusEvent, getWindow, 0}},
 {2812, {wxMenuEvent, getMenu, 0}},
 {2813, {wxMenuEvent, getMenuId, 0}},
 {2814, {wxMenuEvent, isPopup, 0}},
 {2815, {wxCloseEvent, canVeto, 0}},
 {2816, {wxCloseEvent, getLoggingOff, 0}},
 {2817, {wxCloseEvent, setCanVeto, 1}},
 {2818, {wxCloseEvent, setLoggingOff, 1}},
 {2819, {wxCloseEvent, veto, 1}},
 {2820, {wxShowEvent, setShow, 1}},
 {2821, {wxShowEvent, getShow, 0}},
 {2822, {wxIconizeEvent, iconized, 0}},
 {2823, {wxJoystickEvent, buttonDown, 1}},
 {2824, {wxJoystickEvent, buttonIsDown, 1}},
 {2825, {wxJoystickEvent, buttonUp, 1}},
 {2826, {wxJoystickEvent, getButtonChange, 0}},
 {2827, {wxJoystickEvent, getButtonState, 0}},
 {2828, {wxJoystickEvent, getJoystick, 0}},
 {2829, {wxJoystickEvent, getPosition, 0}},
 {2830, {wxJoystickEvent, getZPosition, 0}},
 {2831, {wxJoystickEvent, isButton, 0}},
 {2832, {wxJoystickEvent, isMove, 0}},
 {2833, {wxJoystickEvent, isZMove, 0}},
 {2834, {wxUpdateUIEvent, canUpdate, 1}},
 {2835, {wxUpdateUIEvent, check, 1}},
 {2836, {wxUpdateUIEvent, enable, 1}},
 {2837, {wxUpdateUIEvent, show, 1}},
 {2838, {wxUpdateUIEvent, getChecked, 0}},
 {2839, {wxUpdateUIEvent, getEnabled, 0}},
 {2840, {wxUpdateUIEvent, getShown, 0}},
 {2841, {wxUpdateUIEvent, getSetChecked, 0}},
 {2842, {wxUpdateUIEvent, getSetEnabled, 0}},
 {2843, {wxUpdateUIEvent, getSetShown, 0}},
 {2844, {wxUpdateUIEvent, getSetText, 0}},
 {2845, {wxUpdateUIEvent, getText, 0}},
 {2846, {wxUpdateUIEvent, getMode, 0}},
 {2847, {wxUpdateUIEvent, getUpdateInterval, 0}},
 {2848, {wxUpdateUIEvent, resetUpdateTime, 0}},
 {2849, {wxUpdateUIEvent, setMode, 1}},
 {2850, {wxUpdateUIEvent, setText, 1}},
 {2851, {wxUpdateUIEvent, setUpdateInterval, 1}},
 {2852, {wxMouseCaptureChangedEvent, getCapturedWindow, 0}},
 {2853, {wxPaletteChangedEvent, setChangedWindow, 1}},
 {2854, {wxPaletteChangedEvent, getChangedWindow, 0}},
 {2855, {wxQueryNewPaletteEvent, setPaletteRealized, 1}},
 {2856, {wxQueryNewPaletteEvent, getPaletteRealized, 0}},
 {2857, {wxNavigationKeyEvent, getDirection, 0}},
 {2858, {wxNavigationKeyEvent, setDirection, 1}},
 {2859, {wxNavigationKeyEvent, isWindowChange, 0}},
 {2860, {wxNavigationKeyEvent, setWindowChange, 1}},
 {2861, {wxNavigationKeyEvent, isFromTab, 0}},
 {2862, {wxNavigationKeyEvent, setFromTab, 1}},
 {2863, {wxNavigationKeyEvent, getCurrentFocus, 0}},
 {2864, {wxNavigationKeyEvent, setCurrentFocus, 1}},
 {2865, {wxHelpEvent, getOrigin, 0}},
 {2866, {wxHelpEvent, getPosition, 0}},
 {2867, {wxHelpEvent, setOrigin, 1}},
 {2868, {wxHelpEvent, setPosition, 1}},
 {2869, {wxContextMenuEvent, getPosition, 0}},
 {2870, {wxContextMenuEvent, setPosition, 1}},
 {2871, {wxIdleEvent, canSend, 1}},
 {2872, {wxIdleEvent, getMode, 0}},
 {2873, {wxIdleEvent, requestMore, 1}},
 {2874, {wxIdleEvent, moreRequested, 0}},
 {2875, {wxIdleEvent, setMode, 1}},
 {2876, {wxGridEvent, altDown, 0}},
 {2877, {wxGridEvent, controlDown, 0}},
 {2878, {wxGridEvent, getCol, 0}},
 {2879, {wxGridEvent, getPosition, 0}},
 {2880, {wxGridEvent, getRow, 0}},
 {2881, {wxGridEvent, metaDown, 0}},
 {2882, {wxGridEvent, selecting, 0}},
 {2883, {wxGridEvent, shiftDown, 0}},
 {2884, {wxNotifyEvent, allow, 0}},
 {2885, {wxNotifyEvent, isAllowed, 0}},
 {2886, {wxNotifyEvent, veto, 0}},
 {2887, {wxSashEvent, getEdge, 0}},
 {2888, {wxSashEvent, getDragRect, 0}},
 {2889, {wxSashEvent, getDragStatus, 0}},
 {2890, {wxListEvent, getCacheFrom, 0}},
 {2891, {wxListEvent, getCacheTo, 0}},
 {2892, {wxListEvent, getKeyCode, 0}},
 {2893, {wxListEvent, getIndex, 0}},
 {2894, {wxListEvent, getColumn, 0}},
 {2895, {wxListEvent, getPoint, 0}},
 {2896, {wxListEvent, getLabel, 0}},
 {2897, {wxListEvent, getText, 0}},
 {2898, {wxListEvent, getImage, 0}},
 {2899, {wxListEvent, getData, 0}},
 {2900, {wxListEvent, getMask, 0}},
 {2901, {wxListEvent, getItem, 0}},
 {2902, {wxListEvent, isEditCancelled, 0}},
 {2903, {wxDateEvent, getDate, 0}},
 {2904, {wxCalendarEvent, getWeekDay, 0}},
 {2905, {wxFileDirPickerEvent, getPath, 0}},
 {2906, {wxColourPickerEvent, getColour, 0}},
 {2907, {wxFontPickerEvent, getFont, 0}},
 {2908, {wxStyledTextEvent, getPosition, 0}},
 {2909, {wxStyledTextEvent, getKey, 0}},
 {2910, {wxStyledTextEvent, getModifiers, 0}},
 {2911, {wxStyledTextEvent, getModificationType, 0}},
 {2912, {wxStyledTextEvent, getText, 0}},
 {2913, {wxStyledTextEvent, getLength, 0}},
 {2914, {wxStyledTextEvent, getLinesAdded, 0}},
 {2915, {wxStyledTextEvent, getLine, 0}},
 {2916, {wxStyledTextEvent, getFoldLevelNow, 0}},
 {2917, {wxStyledTextEvent, getFoldLevelPrev, 0}},
 {2918, {wxStyledTextEvent, getMargin, 0}},
 {2919, {wxStyledTextEvent, getMessage, 0}},
 {2920, {wxStyledTextEvent, getWParam, 0}},
 {2921, {wxStyledTextEvent, getLParam, 0}},
 {2922, {wxStyledTextEvent, getListType, 0}},
 {2923, {wxStyledTextEvent, getX, 0}},
 {2924, {wxStyledTextEvent, getY, 0}},
 {2925, {wxStyledTextEvent, getDragText, 0}},
 {2926, {wxStyledTextEvent, getDragAllowMove, 0}},
 {2927, {wxStyledTextEvent, getDragResult, 0}},
 {2928, {wxStyledTextEvent, getShift, 0}},
 {2929, {wxStyledTextEvent, getControl, 0}},
 {2930, {wxStyledTextEvent, getAlt, 0}},
 {2931, {utils, getKeyState, 1}},
 {2932, {utils, getMousePosition, 2}},
 {2933, {utils, getMouseState, 0}},
 {2934, {utils, setDetectableAutoRepeat, 1}},
 {2935, {utils, bell, 0}},
 {2936, {utils, findMenuItemId, 3}},
 {2937, {utils, genericFindWindowAtPoint, 1}},
 {2938, {utils, findWindowAtPoint, 1}},
 {2939, {utils, beginBusyCursor, 1}},
 {2940, {utils, endBusyCursor, 0}},
 {2941, {utils, isBusy, 0}},
 {2942, {utils, shutdown, 1}},
 {2943, {utils, shell, 1}},
 {2944, {utils, launchDefaultBrowser, 2}},
 {2945, {utils, getEmailAddress, 0}},
 {2946, {utils, getUserId, 0}},
 {2947, {utils, getHomeDir, 0}},
 {2948, {utils, newId, 0}},
 {2949, {utils, registerId, 1}},
 {2950, {utils, getCurrentId, 0}},
 {2951, {utils, getOsDescription, 0}},
 {2952, {utils, isPlatformLittleEndian, 0}},
 {2953, {utils, isPlatform64Bit, 0}},
 {2954, {gdicmn, displaySize, 2}},
 {2955, {gdicmn, setCursor, 1}},
 {2956, {wxPrintout, new, 1}},
 {2957, {wxPrintout, destruct, 0}},
 {2958, {wxPrintout, getDC, 0}},
 {2959, {wxPrintout, getPageSizeMM, 2}},
 {2960, {wxPrintout, getPageSizePixels, 2}},
 {2961, {wxPrintout, getPaperRectPixels, 0}},
 {2962, {wxPrintout, getPPIPrinter, 2}},
 {2963, {wxPrintout, getPPIScreen, 2}},
 {2964, {wxPrintout, getTitle, 0}},
 {2965, {wxPrintout, isPreview, 0}},
 {2966, {wxPrintout, fitThisSizeToPaper, 1}},
 {2967, {wxPrintout, fitThisSizeToPage, 1}},
 {2968, {wxPrintout, fitThisSizeToPageMargins, 2}},
 {2969, {wxPrintout, mapScreenSizeToPaper, 0}},
 {2970, {wxPrintout, mapScreenSizeToPage, 0}},
 {2971, {wxPrintout, mapScreenSizeToPageMargins, 1}},
 {2972, {wxPrintout, mapScreenSizeToDevice, 0}},
 {2973, {wxPrintout, getLogicalPaperRect, 0}},
 {2974, {wxPrintout, getLogicalPageRect, 0}},
 {2975, {wxPrintout, getLogicalPageMarginsRect, 1}},
 {2976, {wxPrintout, setLogicalOrigin, 2}},
 {2977, {wxPrintout, offsetLogicalOrigin, 2}},
 {2978, {wxStyledTextCtrl, new_2, 2}},
 {2979, {wxStyledTextCtrl, new_0, 0}},
 {2980, {wxStyledTextCtrl, destruct, 0}},
 {2981, {wxStyledTextCtrl, create, 2}},
 {2982, {wxStyledTextCtrl, addText, 1}},
 {2983, {wxStyledTextCtrl, addStyledText, 1}},
 {2984, {wxStyledTextCtrl, insertText, 2}},
 {2985, {wxStyledTextCtrl, clearAll, 0}},
 {2986, {wxStyledTextCtrl, clearDocumentStyle, 0}},
 {2987, {wxStyledTextCtrl, getLength, 0}},
 {2988, {wxStyledTextCtrl, getCharAt, 1}},
 {2989, {wxStyledTextCtrl, getCurrentPos, 0}},
 {2990, {wxStyledTextCtrl, getAnchor, 0}},
 {2991, {wxStyledTextCtrl, getStyleAt, 1}},
 {2992, {wxStyledTextCtrl, redo, 0}},
 {2993, {wxStyledTextCtrl, setUndoCollection, 1}},
 {2994, {wxStyledTextCtrl, selectAll, 0}},
 {2995, {wxStyledTextCtrl, setSavePoint, 0}},
 {2996, {wxStyledTextCtrl, getStyledText, 2}},
 {2997, {wxStyledTextCtrl, canRedo, 0}},
 {2998, {wxStyledTextCtrl, markerLineFromHandle, 1}},
 {2999, {wxStyledTextCtrl, markerDeleteHandle, 1}},
 {3000, {wxStyledTextCtrl, getUndoCollection, 0}},
 {3001, {wxStyledTextCtrl, getViewWhiteSpace, 0}},
 {3002, {wxStyledTextCtrl, setViewWhiteSpace, 1}},
 {3003, {wxStyledTextCtrl, positionFromPoint, 1}},
 {3004, {wxStyledTextCtrl, positionFromPointClose, 2}},
 {3005, {wxStyledTextCtrl, gotoLine, 1}},
 {3006, {wxStyledTextCtrl, gotoPos, 1}},
 {3007, {wxStyledTextCtrl, setAnchor, 1}},
 {3008, {wxStyledTextCtrl, getCurLine, 1}},
 {3009, {wxStyledTextCtrl, getEndStyled, 0}},
 {3010, {wxStyledTextCtrl, convertEOLs, 1}},
 {3011, {wxStyledTextCtrl, getEOLMode, 0}},
 {3012, {wxStyledTextCtrl, setEOLMode, 1}},
 {3013, {wxStyledTextCtrl, startStyling, 2}},
 {3014, {wxStyledTextCtrl, setStyling, 2}},
 {3015, {wxStyledTextCtrl, getBufferedDraw, 0}},
 {3016, {wxStyledTextCtrl, setBufferedDraw, 1}},
 {3017, {wxStyledTextCtrl, setTabWidth, 1}},
 {3018, {wxStyledTextCtrl, getTabWidth, 0}},
 {3019, {wxStyledTextCtrl, setCodePage, 1}},
 {3020, {wxStyledTextCtrl, markerDefine, 3}},
 {3021, {wxStyledTextCtrl, markerSetForeground, 2}},
 {3022, {wxStyledTextCtrl, markerSetBackground, 2}},
 {3023, {wxStyledTextCtrl, markerAdd, 2}},
 {3024, {wxStyledTextCtrl, markerDelete, 2}},
 {3025, {wxStyledTextCtrl, markerDeleteAll, 1}},
 {3026, {wxStyledTextCtrl, markerGet, 1}},
 {3027, {wxStyledTextCtrl, markerNext, 2}},
 {3028, {wxStyledTextCtrl, markerPrevious, 2}},
 {3029, {wxStyledTextCtrl, markerDefineBitmap, 2}},
 {3030, {wxStyledTextCtrl, markerAddSet, 2}},
 {3031, {wxStyledTextCtrl, markerSetAlpha, 2}},
 {3032, {wxStyledTextCtrl, setMarginType, 2}},
 {3033, {wxStyledTextCtrl, getMarginType, 1}},
 {3034, {wxStyledTextCtrl, setMarginWidth, 2}},
 {3035, {wxStyledTextCtrl, getMarginWidth, 1}},
 {3036, {wxStyledTextCtrl, setMarginMask, 2}},
 {3037, {wxStyledTextCtrl, getMarginMask, 1}},
 {3038, {wxStyledTextCtrl, setMarginSensitive, 2}},
 {3039, {wxStyledTextCtrl, getMarginSensitive, 1}},
 {3040, {wxStyledTextCtrl, styleClearAll, 0}},
 {3041, {wxStyledTextCtrl, styleSetForeground, 2}},
 {3042, {wxStyledTextCtrl, styleSetBackground, 2}},
 {3043, {wxStyledTextCtrl, styleSetBold, 2}},
 {3044, {wxStyledTextCtrl, styleSetItalic, 2}},
 {3045, {wxStyledTextCtrl, styleSetSize, 2}},
 {3046, {wxStyledTextCtrl, styleSetFaceName, 2}},
 {3047, {wxStyledTextCtrl, styleSetEOLFilled, 2}},
 {3048, {wxStyledTextCtrl, styleResetDefault, 0}},
 {3049, {wxStyledTextCtrl, styleSetUnderline, 2}},
 {3050, {wxStyledTextCtrl, styleSetCase, 2}},
 {3051, {wxStyledTextCtrl, styleSetHotSpot, 2}},
 {3052, {wxStyledTextCtrl, setSelForeground, 2}},
 {3053, {wxStyledTextCtrl, setSelBackground, 2}},
 {3054, {wxStyledTextCtrl, getSelAlpha, 0}},
 {3055, {wxStyledTextCtrl, setSelAlpha, 1}},
 {3056, {wxStyledTextCtrl, setCaretForeground, 1}},
 {3057, {wxStyledTextCtrl, cmdKeyAssign, 3}},
 {3058, {wxStyledTextCtrl, cmdKeyClear, 2}},
 {3059, {wxStyledTextCtrl, cmdKeyClearAll, 0}},
 {3060, {wxStyledTextCtrl, setStyleBytes, 2}},
 {3061, {wxStyledTextCtrl, styleSetVisible, 2}},
 {3062, {wxStyledTextCtrl, getCaretPeriod, 0}},
 {3063, {wxStyledTextCtrl, setCaretPeriod, 1}},
 {3064, {wxStyledTextCtrl, setWordChars, 1}},
 {3065, {wxStyledTextCtrl, beginUndoAction, 0}},
 {3066, {wxStyledTextCtrl, endUndoAction, 0}},
 {3067, {wxStyledTextCtrl, indicatorSetStyle, 2}},
 {3068, {wxStyledTextCtrl, indicatorGetStyle, 1}},
 {3069, {wxStyledTextCtrl, indicatorSetForeground, 2}},
 {3070, {wxStyledTextCtrl, indicatorGetForeground, 1}},
 {3071, {wxStyledTextCtrl, setWhitespaceForeground, 2}},
 {3072, {wxStyledTextCtrl, setWhitespaceBackground, 2}},
 {3073, {wxStyledTextCtrl, getStyleBits, 0}},
 {3074, {wxStyledTextCtrl, setLineState, 2}},
 {3075, {wxStyledTextCtrl, getLineState, 1}},
 {3076, {wxStyledTextCtrl, getMaxLineState, 0}},
 {3077, {wxStyledTextCtrl, getCaretLineVisible, 0}},
 {3078, {wxStyledTextCtrl, setCaretLineVisible, 1}},
 {3079, {wxStyledTextCtrl, getCaretLineBackground, 0}},
 {3080, {wxStyledTextCtrl, setCaretLineBackground, 1}},
 {3081, {wxStyledTextCtrl, autoCompShow, 2}},
 {3082, {wxStyledTextCtrl, autoCompCancel, 0}},
 {3083, {wxStyledTextCtrl, autoCompActive, 0}},
 {3084, {wxStyledTextCtrl, autoCompPosStart, 0}},
 {3085, {wxStyledTextCtrl, autoCompComplete, 0}},
 {3086, {wxStyledTextCtrl, autoCompStops, 1}},
 {3087, {wxStyledTextCtrl, autoCompSetSeparator, 1}},
 {3088, {wxStyledTextCtrl, autoCompGetSeparator, 0}},
 {3089, {wxStyledTextCtrl, autoCompSelect, 1}},
 {3090, {wxStyledTextCtrl, autoCompSetCancelAtStart, 1}},
 {3091, {wxStyledTextCtrl, autoCompGetCancelAtStart, 0}},
 {3092, {wxStyledTextCtrl, autoCompSetFillUps, 1}},
 {3093, {wxStyledTextCtrl, autoCompSetChooseSingle, 1}},
 {3094, {wxStyledTextCtrl, autoCompGetChooseSingle, 0}},
 {3095, {wxStyledTextCtrl, autoCompSetIgnoreCase, 1}},
 {3096, {wxStyledTextCtrl, autoCompGetIgnoreCase, 0}},
 {3097, {wxStyledTextCtrl, userListShow, 2}},
 {3098, {wxStyledTextCtrl, autoCompSetAutoHide, 1}},
 {3099, {wxStyledTextCtrl, autoCompGetAutoHide, 0}},
 {3100, {wxStyledTextCtrl, autoCompSetDropRestOfWord, 1}},
 {3101, {wxStyledTextCtrl, autoCompGetDropRestOfWord, 0}},
 {3102, {wxStyledTextCtrl, registerImage, 2}},
 {3103, {wxStyledTextCtrl, clearRegisteredImages, 0}},
 {3104, {wxStyledTextCtrl, autoCompGetTypeSeparator, 0}},
 {3105, {wxStyledTextCtrl, autoCompSetTypeSeparator, 1}},
 {3106, {wxStyledTextCtrl, autoCompSetMaxWidth, 1}},
 {3107, {wxStyledTextCtrl, autoCompGetMaxWidth, 0}},
 {3108, {wxStyledTextCtrl, autoCompSetMaxHeight, 1}},
 {3109, {wxStyledTextCtrl, autoCompGetMaxHeight, 0}},
 {3110, {wxStyledTextCtrl, setIndent, 1}},
 {3111, {wxStyledTextCtrl, getIndent, 0}},
 {3112, {wxStyledTextCtrl, setUseTabs, 1}},
 {3113, {wxStyledTextCtrl, getUseTabs, 0}},
 {3114, {wxStyledTextCtrl, setLineIndentation, 2}},
 {3115, {wxStyledTextCtrl, getLineIndentation, 1}},
 {3116, {wxStyledTextCtrl, getLineIndentPosition, 1}},
 {3117, {wxStyledTextCtrl, getColumn, 1}},
 {3118, {wxStyledTextCtrl, setUseHorizontalScrollBar, 1}},
 {3119, {wxStyledTextCtrl, getUseHorizontalScrollBar, 0}},
 {3120, {wxStyledTextCtrl, setIndentationGuides, 1}},
 {3121, {wxStyledTextCtrl, getIndentationGuides, 0}},
 {3122, {wxStyledTextCtrl, setHighlightGuide, 1}},
 {3123, {wxStyledTextCtrl, getHighlightGuide, 0}},
 {3124, {wxStyledTextCtrl, getLineEndPosition, 1}},
 {3125, {wxStyledTextCtrl, getCodePage, 0}},
 {3126, {wxStyledTextCtrl, getCaretForeground, 0}},
 {3127, {wxStyledTextCtrl, getReadOnly, 0}},
 {3128, {wxStyledTextCtrl, setCurrentPos, 1}},
 {3129, {wxStyledTextCtrl, setSelectionStart, 1}},
 {3130, {wxStyledTextCtrl, getSelectionStart, 0}},
 {3131, {wxStyledTextCtrl, setSelectionEnd, 1}},
 {3132, {wxStyledTextCtrl, getSelectionEnd, 0}},
 {3133, {wxStyledTextCtrl, setPrintMagnification, 1}},
 {3134, {wxStyledTextCtrl, getPrintMagnification, 0}},
 {3135, {wxStyledTextCtrl, setPrintColourMode, 1}},
 {3136, {wxStyledTextCtrl, getPrintColourMode, 0}},
 {3137, {wxStyledTextCtrl, findText, 4}},
 {3138, {wxStyledTextCtrl, formatRange, 7}},
 {3139, {wxStyledTextCtrl, getFirstVisibleLine, 0}},
 {3140, {wxStyledTextCtrl, getLine, 1}},
 {3141, {wxStyledTextCtrl, getLineCount, 0}},
 {3142, {wxStyledTextCtrl, setMarginLeft, 1}},
 {3143, {wxStyledTextCtrl, getMarginLeft, 0}},
 {3144, {wxStyledTextCtrl, setMarginRight, 1}},
 {3145, {wxStyledTextCtrl, getMarginRight, 0}},
 {3146, {wxStyledTextCtrl, getModify, 0}},
 {3147, {wxStyledTextCtrl, setSelection, 2}},
 {3148, {wxStyledTextCtrl, getSelectedText, 0}},
 {3149, {wxStyledTextCtrl, getTextRange, 2}},
 {3150, {wxStyledTextCtrl, hideSelection, 1}},
 {3151, {wxStyledTextCtrl, lineFromPosition, 1}},
 {3152, {wxStyledTextCtrl, positionFromLine, 1}},
 {3153, {wxStyledTextCtrl, lineScroll, 2}},
 {3154, {wxStyledTextCtrl, ensureCaretVisible, 0}},
 {3155, {wxStyledTextCtrl, replaceSelection, 1}},
 {3156, {wxStyledTextCtrl, setReadOnly, 1}},
 {3157, {wxStyledTextCtrl, canPaste, 0}},
 {3158, {wxStyledTextCtrl, canUndo, 0}},
 {3159, {wxStyledTextCtrl, emptyUndoBuffer, 0}},
 {3160, {wxStyledTextCtrl, undo, 0}},
 {3161, {wxStyledTextCtrl, cut, 0}},
 {3162, {wxStyledTextCtrl, copy, 0}},
 {3163, {wxStyledTextCtrl, paste, 0}},
 {3164, {wxStyledTextCtrl, clear, 0}},
 {3165, {wxStyledTextCtrl, setText, 1}},
 {3166, {wxStyledTextCtrl, getText, 0}},
 {3167, {wxStyledTextCtrl, getTextLength, 0}},
 {3168, {wxStyledTextCtrl, getOvertype, 0}},
 {3169, {wxStyledTextCtrl, setCaretWidth, 1}},
 {3170, {wxStyledTextCtrl, getCaretWidth, 0}},
 {3171, {wxStyledTextCtrl, setTargetStart, 1}},
 {3172, {wxStyledTextCtrl, getTargetStart, 0}},
 {3173, {wxStyledTextCtrl, setTargetEnd, 1}},
 {3174, {wxStyledTextCtrl, getTargetEnd, 0}},
 {3175, {wxStyledTextCtrl, replaceTarget, 1}},
 {3176, {wxStyledTextCtrl, searchInTarget, 1}},
 {3177, {wxStyledTextCtrl, setSearchFlags, 1}},
 {3178, {wxStyledTextCtrl, getSearchFlags, 0}},
 {3179, {wxStyledTextCtrl, callTipShow, 2}},
 {3180, {wxStyledTextCtrl, callTipCancel, 0}},
 {3181, {wxStyledTextCtrl, callTipActive, 0}},
 {3182, {wxStyledTextCtrl, callTipPosAtStart, 0}},
 {3183, {wxStyledTextCtrl, callTipSetHighlight, 2}},
 {3184, {wxStyledTextCtrl, callTipSetBackground, 1}},
 {3185, {wxStyledTextCtrl, callTipSetForeground, 1}},
 {3186, {wxStyledTextCtrl, callTipSetForegroundHighlight, 1}},
 {3187, {wxStyledTextCtrl, callTipUseStyle, 1}},
 {3188, {wxStyledTextCtrl, visibleFromDocLine, 1}},
 {3189, {wxStyledTextCtrl, docLineFromVisible, 1}},
 {3190, {wxStyledTextCtrl, wrapCount, 1}},
 {3191, {wxStyledTextCtrl, setFoldLevel, 2}},
 {3192, {wxStyledTextCtrl, getFoldLevel, 1}},
 {3193, {wxStyledTextCtrl, getLastChild, 2}},
 {3194, {wxStyledTextCtrl, getFoldParent, 1}},
 {3195, {wxStyledTextCtrl, showLines, 2}},
 {3196, {wxStyledTextCtrl, hideLines, 2}},
 {3197, {wxStyledTextCtrl, getLineVisible, 1}},
 {3198, {wxStyledTextCtrl, setFoldExpanded, 2}},
 {3199, {wxStyledTextCtrl, getFoldExpanded, 1}},
 {3200, {wxStyledTextCtrl, toggleFold, 1}},
 {3201, {wxStyledTextCtrl, ensureVisible, 1}},
 {3202, {wxStyledTextCtrl, setFoldFlags, 1}},
 {3203, {wxStyledTextCtrl, ensureVisibleEnforcePolicy, 1}},
 {3204, {wxStyledTextCtrl, setTabIndents, 1}},
 {3205, {wxStyledTextCtrl, getTabIndents, 0}},
 {3206, {wxStyledTextCtrl, setBackSpaceUnIndents, 1}},
 {3207, {wxStyledTextCtrl, getBackSpaceUnIndents, 0}},
 {3208, {wxStyledTextCtrl, setMouseDwellTime, 1}},
 {3209, {wxStyledTextCtrl, getMouseDwellTime, 0}},
 {3210, {wxStyledTextCtrl, wordStartPosition, 2}},
 {3211, {wxStyledTextCtrl, wordEndPosition, 2}},
 {3212, {wxStyledTextCtrl, setWrapMode, 1}},
 {3213, {wxStyledTextCtrl, getWrapMode, 0}},
 {3214, {wxStyledTextCtrl, setWrapVisualFlags, 1}},
 {3215, {wxStyledTextCtrl, getWrapVisualFlags, 0}},
 {3216, {wxStyledTextCtrl, setWrapVisualFlagsLocation, 1}},
 {3217, {wxStyledTextCtrl, getWrapVisualFlagsLocation, 0}},
 {3218, {wxStyledTextCtrl, setWrapStartIndent, 1}},
 {3219, {wxStyledTextCtrl, getWrapStartIndent, 0}},
 {3220, {wxStyledTextCtrl, setLayoutCache, 1}},
 {3221, {wxStyledTextCtrl, getLayoutCache, 0}},
 {3222, {wxStyledTextCtrl, setScrollWidth, 1}},
 {3223, {wxStyledTextCtrl, getScrollWidth, 0}},
 {3224, {wxStyledTextCtrl, textWidth, 2}},
 {3225, {wxStyledTextCtrl, getEndAtLastLine, 0}},
 {3226, {wxStyledTextCtrl, textHeight, 1}},
 {3227, {wxStyledTextCtrl, setUseVerticalScrollBar, 1}},
 {3228, {wxStyledTextCtrl, getUseVerticalScrollBar, 0}},
 {3229, {wxStyledTextCtrl, appendText, 1}},
 {3230, {wxStyledTextCtrl, getTwoPhaseDraw, 0}},
 {3231, {wxStyledTextCtrl, setTwoPhaseDraw, 1}},
 {3232, {wxStyledTextCtrl, targetFromSelection, 0}},
 {3233, {wxStyledTextCtrl, linesJoin, 0}},
 {3234, {wxStyledTextCtrl, linesSplit, 1}},
 {3235, {wxStyledTextCtrl, setFoldMarginColour, 2}},
 {3236, {wxStyledTextCtrl, setFoldMarginHiColour, 2}},
 {3237, {wxStyledTextCtrl, lineDown, 0}},
 {3238, {wxStyledTextCtrl, lineDownExtend, 0}},
 {3239, {wxStyledTextCtrl, lineUp, 0}},
 {3240, {wxStyledTextCtrl, lineUpExtend, 0}},
 {3241, {wxStyledTextCtrl, charLeft, 0}},
 {3242, {wxStyledTextCtrl, charLeftExtend, 0}},
 {3243, {wxStyledTextCtrl, charRight, 0}},
 {3244, {wxStyledTextCtrl, charRightExtend, 0}},
 {3245, {wxStyledTextCtrl, wordLeft, 0}},
 {3246, {wxStyledTextCtrl, wordLeftExtend, 0}},
 {3247, {wxStyledTextCtrl, wordRight, 0}},
 {3248, {wxStyledTextCtrl, wordRightExtend, 0}},
 {3249, {wxStyledTextCtrl, home, 0}},
 {3250, {wxStyledTextCtrl, homeExtend, 0}},
 {3251, {wxStyledTextCtrl, lineEnd, 0}},
 {3252, {wxStyledTextCtrl, lineEndExtend, 0}},
 {3253, {wxStyledTextCtrl, documentStart, 0}},
 {3254, {wxStyledTextCtrl, documentStartExtend, 0}},
 {3255, {wxStyledTextCtrl, documentEnd, 0}},
 {3256, {wxStyledTextCtrl, documentEndExtend, 0}},
 {3257, {wxStyledTextCtrl, pageUp, 0}},
 {3258, {wxStyledTextCtrl, pageUpExtend, 0}},
 {3259, {wxStyledTextCtrl, pageDown, 0}},
 {3260, {wxStyledTextCtrl, pageDownExtend, 0}},
 {3261, {wxStyledTextCtrl, editToggleOvertype, 0}},
 {3262, {wxStyledTextCtrl, cancel, 0}},
 {3263, {wxStyledTextCtrl, deleteBack, 0}},
 {3264, {wxStyledTextCtrl, tab, 0}},
 {3265, {wxStyledTextCtrl, backTab, 0}},
 {3266, {wxStyledTextCtrl, newLine, 0}},
 {3267, {wxStyledTextCtrl, formFeed, 0}},
 {3268, {wxStyledTextCtrl, vCHome, 0}},
 {3269, {wxStyledTextCtrl, vCHomeExtend, 0}},
 {3270, {wxStyledTextCtrl, zoomIn, 0}},
 {3271, {wxStyledTextCtrl, zoomOut, 0}},
 {3272, {wxStyledTextCtrl, delWordLeft, 0}},
 {3273, {wxStyledTextCtrl, delWordRight, 0}},
 {3274, {wxStyledTextCtrl, lineCut, 0}},
 {3275, {wxStyledTextCtrl, lineDelete, 0}},
 {3276, {wxStyledTextCtrl, lineTranspose, 0}},
 {3277, {wxStyledTextCtrl, lineDuplicate, 0}},
 {3278, {wxStyledTextCtrl, lowerCase, 0}},
 {3279, {wxStyledTextCtrl, upperCase, 0}},
 {3280, {wxStyledTextCtrl, lineScrollDown, 0}},
 {3281, {wxStyledTextCtrl, lineScrollUp, 0}},
 {3282, {wxStyledTextCtrl, deleteBackNotLine, 0}},
 {3283, {wxStyledTextCtrl, homeDisplay, 0}},
 {3284, {wxStyledTextCtrl, homeDisplayExtend, 0}},
 {3285, {wxStyledTextCtrl, lineEndDisplay, 0}},
 {3286, {wxStyledTextCtrl, lineEndDisplayExtend, 0}},
 {3287, {wxStyledTextCtrl, homeWrapExtend, 0}},
 {3288, {wxStyledTextCtrl, lineEndWrap, 0}},
 {3289, {wxStyledTextCtrl, lineEndWrapExtend, 0}},
 {3290, {wxStyledTextCtrl, vCHomeWrap, 0}},
 {3291, {wxStyledTextCtrl, vCHomeWrapExtend, 0}},
 {3292, {wxStyledTextCtrl, lineCopy, 0}},
 {3293, {wxStyledTextCtrl, moveCaretInsideView, 0}},
 {3294, {wxStyledTextCtrl, lineLength, 1}},
 {3295, {wxStyledTextCtrl, braceHighlight, 2}},
 {3296, {wxStyledTextCtrl, braceBadLight, 1}},
 {3297, {wxStyledTextCtrl, braceMatch, 1}},
 {3298, {wxStyledTextCtrl, getViewEOL, 0}},
 {3299, {wxStyledTextCtrl, setViewEOL, 1}},
 {3300, {wxStyledTextCtrl, setModEventMask, 1}},
 {3301, {wxStyledTextCtrl, getEdgeColumn, 0}},
 {3302, {wxStyledTextCtrl, setEdgeColumn, 1}},
 {3303, {wxStyledTextCtrl, setEdgeMode, 1}},
 {3304, {wxStyledTextCtrl, getEdgeMode, 0}},
 {3305, {wxStyledTextCtrl, getEdgeColour, 0}},
 {3306, {wxStyledTextCtrl, setEdgeColour, 1}},
 {3307, {wxStyledTextCtrl, searchAnchor, 0}},
 {3308, {wxStyledTextCtrl, searchNext, 2}},
 {3309, {wxStyledTextCtrl, searchPrev, 2}},
 {3310, {wxStyledTextCtrl, linesOnScreen, 0}},
 {3311, {wxStyledTextCtrl, usePopUp, 1}},
 {3312, {wxStyledTextCtrl, selectionIsRectangle, 0}},
 {3313, {wxStyledTextCtrl, setZoom, 1}},
 {3314, {wxStyledTextCtrl, getZoom, 0}},
 {3315, {wxStyledTextCtrl, getModEventMask, 0}},
 {3316, {wxStyledTextCtrl, setSTCFocus, 1}},
 {3317, {wxStyledTextCtrl, getSTCFocus, 0}},
 {3318, {wxStyledTextCtrl, setStatus, 1}},
 {3319, {wxStyledTextCtrl, getStatus, 0}},
 {3320, {wxStyledTextCtrl, setMouseDownCaptures, 1}},
 {3321, {wxStyledTextCtrl, getMouseDownCaptures, 0}},
 {3322, {wxStyledTextCtrl, setSTCCursor, 1}},
 {3323, {wxStyledTextCtrl, getSTCCursor, 0}},
 {3324, {wxStyledTextCtrl, setControlCharSymbol, 1}},
 {3325, {wxStyledTextCtrl, getControlCharSymbol, 0}},
 {3326, {wxStyledTextCtrl, wordPartLeft, 0}},
 {3327, {wxStyledTextCtrl, wordPartLeftExtend, 0}},
 {3328, {wxStyledTextCtrl, wordPartRight, 0}},
 {3329, {wxStyledTextCtrl, wordPartRightExtend, 0}},
 {3330, {wxStyledTextCtrl, setVisiblePolicy, 2}},
 {3331, {wxStyledTextCtrl, delLineLeft, 0}},
 {3332, {wxStyledTextCtrl, delLineRight, 0}},
 {3333, {wxStyledTextCtrl, getXOffset, 0}},
 {3334, {wxStyledTextCtrl, chooseCaretX, 0}},
 {3335, {wxStyledTextCtrl, setXCaretPolicy, 2}},
 {3336, {wxStyledTextCtrl, setYCaretPolicy, 2}},
 {3337, {wxStyledTextCtrl, getPrintWrapMode, 0}},
 {3338, {wxStyledTextCtrl, setHotspotActiveForeground, 2}},
 {3339, {wxStyledTextCtrl, setHotspotActiveBackground, 2}},
 {3340, {wxStyledTextCtrl, setHotspotActiveUnderline, 1}},
 {3341, {wxStyledTextCtrl, setHotspotSingleLine, 1}},
 {3342, {wxStyledTextCtrl, paraDownExtend, 0}},
 {3343, {wxStyledTextCtrl, paraUp, 0}},
 {3344, {wxStyledTextCtrl, paraUpExtend, 0}},
 {3345, {wxStyledTextCtrl, positionBefore, 1}},
 {3346, {wxStyledTextCtrl, positionAfter, 1}},
 {3347, {wxStyledTextCtrl, copyRange, 2}},
 {3348, {wxStyledTextCtrl, copyText, 2}},
 {3349, {wxStyledTextCtrl, setSelectionMode, 1}},
 {3350, {wxStyledTextCtrl, getSelectionMode, 0}},
 {3351, {wxStyledTextCtrl, lineDownRectExtend, 0}},
 {3352, {wxStyledTextCtrl, lineUpRectExtend, 0}},
 {3353, {wxStyledTextCtrl, charLeftRectExtend, 0}},
 {3354, {wxStyledTextCtrl, charRightRectExtend, 0}},
 {3355, {wxStyledTextCtrl, homeRectExtend, 0}},
 {3356, {wxStyledTextCtrl, vCHomeRectExtend, 0}},
 {3357, {wxStyledTextCtrl, lineEndRectExtend, 0}},
 {3358, {wxStyledTextCtrl, pageUpRectExtend, 0}},
 {3359, {wxStyledTextCtrl, pageDownRectExtend, 0}},
 {3360, {wxStyledTextCtrl, stutteredPageUp, 0}},
 {3361, {wxStyledTextCtrl, stutteredPageUpExtend, 0}},
 {3362, {wxStyledTextCtrl, stutteredPageDown, 0}},
 {3363, {wxStyledTextCtrl, stutteredPageDownExtend, 0}},
 {3364, {wxStyledTextCtrl, wordLeftEnd, 0}},
 {3365, {wxStyledTextCtrl, wordLeftEndExtend, 0}},
 {3366, {wxStyledTextCtrl, wordRightEnd, 0}},
 {3367, {wxStyledTextCtrl, wordRightEndExtend, 0}},
 {3368, {wxStyledTextCtrl, setWhitespaceChars, 1}},
 {3369, {wxStyledTextCtrl, setCharsDefault, 0}},
 {3370, {wxStyledTextCtrl, autoCompGetCurrent, 0}},
 {3371, {wxStyledTextCtrl, allocate, 1}},
 {3372, {wxStyledTextCtrl, findColumn, 2}},
 {3373, {wxStyledTextCtrl, getCaretSticky, 0}},
 {3374, {wxStyledTextCtrl, setCaretSticky, 1}},
 {3375, {wxStyledTextCtrl, toggleCaretSticky, 0}},
 {3376, {wxStyledTextCtrl, setPasteConvertEndings, 1}},
 {3377, {wxStyledTextCtrl, getPasteConvertEndings, 0}},
 {3378, {wxStyledTextCtrl, selectionDuplicate, 0}},
 {3379, {wxStyledTextCtrl, setCaretLineBackAlpha, 1}},
 {3380, {wxStyledTextCtrl, getCaretLineBackAlpha, 0}},
 {3381, {wxStyledTextCtrl, startRecord, 0}},
 {3382, {wxStyledTextCtrl, stopRecord, 0}},
 {3383, {wxStyledTextCtrl, setLexer, 1}},
 {3384, {wxStyledTextCtrl, getLexer, 0}},
 {3385, {wxStyledTextCtrl, colourise, 2}},
 {3386, {wxStyledTextCtrl, setProperty, 2}},
 {3387, {wxStyledTextCtrl, setKeyWords, 2}},
 {3388, {wxStyledTextCtrl, setLexerLanguage, 1}},
 {3389, {wxStyledTextCtrl, getProperty, 1}},
 {3390, {wxStyledTextCtrl, getStyleBitsNeeded, 0}},
 {3391, {wxStyledTextCtrl, getCurrentLine, 0}},
 {3392, {wxStyledTextCtrl, styleSetSpec, 2}},
 {3393, {wxStyledTextCtrl, styleSetFont, 2}},
 {3394, {wxStyledTextCtrl, styleSetFontAttr, 7}},
 {3395, {wxStyledTextCtrl, styleSetCharacterSet, 2}},
 {3396, {wxStyledTextCtrl, styleSetFontEncoding, 2}},
 {3397, {wxStyledTextCtrl, cmdKeyExecute, 1}},
 {3398, {wxStyledTextCtrl, setMargins, 2}},
 {3399, {wxStyledTextCtrl, getSelection, 2}},
 {3400, {wxStyledTextCtrl, pointFromPosition, 1}},
 {3401, {wxStyledTextCtrl, scrollToLine, 1}},
 {3402, {wxStyledTextCtrl, scrollToColumn, 1}},
 {3403, {wxStyledTextCtrl, setVScrollBar, 1}},
 {3404, {wxStyledTextCtrl, setHScrollBar, 1}},
 {3405, {wxStyledTextCtrl, getLastKeydownProcessed, 0}},
 {3406, {wxStyledTextCtrl, setLastKeydownProcessed, 1}},
 {3407, {wxStyledTextCtrl, saveFile, 1}},
 {3408, {wxStyledTextCtrl, loadFile, 1}},
 {3409, {wxStyledTextCtrl, doDragOver, 3}},
 {3410, {wxStyledTextCtrl, doDropText, 3}},
 {3411, {wxStyledTextCtrl, getUseAntiAliasing, 0}},
 {3412, {wxStyledTextCtrl, addTextRaw, 1}},
 {3413, {wxStyledTextCtrl, insertTextRaw, 2}},
 {3414, {wxStyledTextCtrl, getCurLineRaw, 1}},
 {3415, {wxStyledTextCtrl, getLineRaw, 1}},
 {3416, {wxStyledTextCtrl, getSelectedTextRaw, 0}},
 {3417, {wxStyledTextCtrl, getTextRangeRaw, 2}},
 {3418, {wxStyledTextCtrl, setTextRaw, 1}},
 {3419, {wxStyledTextCtrl, getTextRaw, 0}},
 {3420, {wxStyledTextCtrl, appendTextRaw, 1}},
 {3421, {wxArtProvider, getBitmap, 2}},
 {3422, {wxArtProvider, getIcon, 2}},
 {3423, {wxTreeEvent, getKeyCode, 0}},
 {3424, {wxTreeEvent, getItem, 0}},
 {3425, {wxTreeEvent, getKeyEvent, 0}},
 {3426, {wxTreeEvent, getLabel, 0}},
 {3427, {wxTreeEvent, getOldItem, 0}},
 {3428, {wxTreeEvent, getPoint, 0}},
 {3429, {wxTreeEvent, isEditCancelled, 0}},
 {3430, {wxTreeEvent, setToolTip, 1}},
 {3431, {wxNotebookEvent, getOldSelection, 0}},
 {3432, {wxNotebookEvent, getSelection, 0}},
 {3433, {wxNotebookEvent, setOldSelection, 1}},
 {3434, {wxNotebookEvent, setSelection, 1}},
 {3435, {wxFileDataObject, new, 0}},
 {3436, {wxFileDataObject, addFile, 1}},
 {3437, {wxFileDataObject, getFilenames, 0}},
 {3438, {wxFileDataObject, 'Destroy', undefined}},
 {3439, {wxTextDataObject, new, 1}},
 {3440, {wxTextDataObject, getTextLength, 0}},
 {3441, {wxTextDataObject, getText, 0}},
 {3442, {wxTextDataObject, setText, 1}},
 {3443, {wxTextDataObject, 'Destroy', undefined}},
 {3444, {wxBitmapDataObject, new_1_1, 1}},
 {3445, {wxBitmapDataObject, new_1_0, 1}},
 {3446, {wxBitmapDataObject, getBitmap, 0}},
 {3447, {wxBitmapDataObject, setBitmap, 1}},
 {3448, {wxBitmapDataObject, 'Destroy', undefined}},
 {3450, {wxClipboard, new, 0}},
 {3451, {wxClipboard, destruct, 0}},
 {3452, {wxClipboard, addData, 1}},
 {3453, {wxClipboard, clear, 0}},
 {3454, {wxClipboard, close, 0}},
 {3455, {wxClipboard, flush, 0}},
 {3456, {wxClipboard, getData, 1}},
 {3457, {wxClipboard, isOpened, 0}},
 {3458, {wxClipboard, open, 0}},
 {3459, {wxClipboard, setData, 1}},
 {3461, {wxClipboard, usePrimarySelection, 1}},
 {3462, {wxClipboard, isSupported, 1}},
 {3463, {wxClipboard, get, 0}},
 {3464, {wxSpinEvent, getPosition, 0}},
 {3465, {wxSpinEvent, setPosition, 1}},
 {3466, {wxSplitterWindow, new_0, 0}},
 {3467, {wxSplitterWindow, new_2, 2}},
 {3468, {wxSplitterWindow, destruct, 0}},
 {3469, {wxSplitterWindow, create, 2}},
 {3470, {wxSplitterWindow, getMinimumPaneSize, 0}},
 {3471, {wxSplitterWindow, getSashGravity, 0}},
 {3472, {wxSplitterWindow, getSashPosition, 0}},
 {3473, {wxSplitterWindow, getSplitMode, 0}},
 {3474, {wxSplitterWindow, getWindow1, 0}},
 {3475, {wxSplitterWindow, getWindow2, 0}},
 {3476, {wxSplitterWindow, initialize, 1}},
 {3477, {wxSplitterWindow, isSplit, 0}},
 {3478, {wxSplitterWindow, replaceWindow, 2}},
 {3479, {wxSplitterWindow, setSashGravity, 1}},
 {3480, {wxSplitterWindow, setSashPosition, 2}},
 {3481, {wxSplitterWindow, setSashSize, 1}},
 {3482, {wxSplitterWindow, setMinimumPaneSize, 1}},
 {3483, {wxSplitterWindow, setSplitMode, 1}},
 {3484, {wxSplitterWindow, splitHorizontally, 3}},
 {3485, {wxSplitterWindow, splitVertically, 3}},
 {3486, {wxSplitterWindow, unsplit, 1}},
 {3487, {wxSplitterWindow, updateSize, 0}},
 {3488, {wxSplitterEvent, getSashPosition, 0}},
 {3489, {wxSplitterEvent, getX, 0}},
 {3490, {wxSplitterEvent, getY, 0}},
 {3491, {wxSplitterEvent, getWindowBeingRemoved, 0}},
 {3492, {wxSplitterEvent, setSashPosition, 1}},
 {3493, {wxHtmlWindow, new_0, 0}},
 {3494, {wxHtmlWindow, new_2, 2}},
 {3495, {wxHtmlWindow, appendToPage, 1}},
 {3496, {wxHtmlWindow, getOpenedAnchor, 0}},
 {3497, {wxHtmlWindow, getOpenedPage, 0}},
 {3498, {wxHtmlWindow, getOpenedPageTitle, 0}},
 {3499, {wxHtmlWindow, getRelatedFrame, 0}},
 {3500, {wxHtmlWindow, historyBack, 0}},
 {3501, {wxHtmlWindow, historyCanBack, 0}},
 {3502, {wxHtmlWindow, historyCanForward, 0}},
 {3503, {wxHtmlWindow, historyClear, 0}},
 {3504, {wxHtmlWindow, historyForward, 0}},
 {3505, {wxHtmlWindow, loadFile, 1}},
 {3506, {wxHtmlWindow, loadPage, 1}},
 {3507, {wxHtmlWindow, selectAll, 0}},
 {3508, {wxHtmlWindow, selectionToText, 0}},
 {3509, {wxHtmlWindow, selectLine, 1}},
 {3510, {wxHtmlWindow, selectWord, 1}},
 {3511, {wxHtmlWindow, setBorders, 1}},
 {3512, {wxHtmlWindow, setFonts, 3}},
 {3513, {wxHtmlWindow, setPage, 1}},
 {3514, {wxHtmlWindow, setRelatedFrame, 2}},
 {3515, {wxHtmlWindow, setRelatedStatusBar, 1}},
 {3516, {wxHtmlWindow, toText, 0}},
 {3517, {wxHtmlWindow, 'Destroy', undefined}},
 {3518, {wxHtmlLinkEvent, getLinkInfo, 0}},
 {3519, {wxSystemSettings, getColour, 1}},
 {3520, {wxSystemSettings, getFont, 1}},
 {3521, {wxSystemSettings, getMetric, 2}},
 {3522, {wxSystemSettings, getScreenType, 0}},
 {3523, {wxSystemOptions, getOption, 1}},
 {3524, {wxSystemOptions, getOptionInt, 1}},
 {3525, {wxSystemOptions, hasOption, 1}},
 {3526, {wxSystemOptions, isFalse, 1}},
 {3527, {wxSystemOptions, setOption_2_1, 2}},
 {3528, {wxSystemOptions, setOption_2_0, 2}},
 {3529, {wxAuiNotebookEvent, setSelection, 1}},
 {3530, {wxAuiNotebookEvent, getSelection, 0}},
 {3531, {wxAuiNotebookEvent, setOldSelection, 1}},
 {3532, {wxAuiNotebookEvent, getOldSelection, 0}},
 {3533, {wxAuiNotebookEvent, setDragSource, 1}},
 {3534, {wxAuiNotebookEvent, getDragSource, 0}},
 {3535, {wxAuiManagerEvent, setManager, 1}},
 {3536, {wxAuiManagerEvent, getManager, 0}},
 {3537, {wxAuiManagerEvent, setPane, 1}},
 {3538, {wxAuiManagerEvent, getPane, 0}},
 {3539, {wxAuiManagerEvent, setButton, 1}},
 {3540, {wxAuiManagerEvent, getButton, 0}},
 {3541, {wxAuiManagerEvent, setDC, 1}},
 {3542, {wxAuiManagerEvent, getDC, 0}},
 {3543, {wxAuiManagerEvent, veto, 1}},
 {3544, {wxAuiManagerEvent, getVeto, 0}},
 {3545, {wxAuiManagerEvent, setCanVeto, 1}},
 {3546, {wxAuiManagerEvent, canVeto, 0}},
 {3547, {wxLogNull, new, 0}},
 {3548, {wxLogNull, 'Destroy', undefined}},
 {3549, {wxTaskBarIcon, new, 0}},
 {3550, {wxTaskBarIcon, destruct, 0}},
 {3551, {wxTaskBarIcon, popupMenu, 1}},
 {3552, {wxTaskBarIcon, removeIcon, 0}},
 {3553, {wxTaskBarIcon, setIcon, 2}},
 {3554, {wxLocale, new_0, 0}},
 {3556, {wxLocale, new_2, 2}},
 {3557, {wxLocale, destruct, 0}},
 {3559, {wxLocale, init, 1}},
 {3560, {wxLocale, addCatalog_1, 1}},
 {3561, {wxLocale, addCatalog_3, 3}},
 {3562, {wxLocale, addCatalogLookupPathPrefix, 1}},
 {3563, {wxLocale, getCanonicalName, 0}},
 {3564, {wxLocale, getLanguage, 0}},
 {3565, {wxLocale, getLanguageName, 1}},
 {3566, {wxLocale, getLocale, 0}},
 {3567, {wxLocale, getName, 0}},
 {3568, {wxLocale, getString_2, 2}},
 {3569, {wxLocale, getString_4, 4}},
 {3570, {wxLocale, getHeaderValue, 2}},
 {3571, {wxLocale, getSysName, 0}},
 {3572, {wxLocale, getSystemEncoding, 0}},
 {3573, {wxLocale, getSystemEncodingName, 0}},
 {3574, {wxLocale, getSystemLanguage, 0}},
 {3575, {wxLocale, isLoaded, 1}},
 {3576, {wxLocale, isOk, 0}},
 {3577, {wxActivateEvent, getActive, 0}},
 {3579, {wxPopupWindow, new_2, 2}},
 {3580, {wxPopupWindow, new_0, 0}},
 {3582, {wxPopupWindow, destruct, 0}},
 {3583, {wxPopupWindow, create, 2}},
 {3584, {wxPopupWindow, position, 2}},
 {3585, {wxPopupTransientWindow, new_0, 0}},
 {3586, {wxPopupTransientWindow, new_2, 2}},
 {3587, {wxPopupTransientWindow, destruct, 0}},
 {3588, {wxPopupTransientWindow, popup, 1}},
 {3589, {wxPopupTransientWindow, dismiss, 0}},
 {3590, {wxOverlay, new, 0}},
 {3591, {wxOverlay, destruct, 0}},
 {3592, {wxOverlay, reset, 0}},
 {3593, {wxDCOverlay, new_6, 6}},
 {3594, {wxDCOverlay, new_2, 2}},
 {3595, {wxDCOverlay, destruct, 0}},
 {3596, {wxDCOverlay, clear, 0}},
 {3597, {wxDropFilesEvent, getPosition, 0}},
 {3598, {wxDropFilesEvent, getNumberOfFiles, 0}},
 {3599, {wxDropFilesEvent, getFiles, 0}},
 {-1, {mod, func, -1}}
].

